@@ -11,7 +11,9 @@
 /**
  * Validates the "add a user" form
  *
- * @return boolean  whether the form is validated or not
+ * @param theForm
+ *
+ * @return {bool} whether the form is validated or not
  */
 function checkAddUser (theForm) {
     if (theForm.elements.hostname.value === '') {
@@ -29,6 +31,131 @@ function checkAddUser (theForm) {
     return Functions.checkPassword($(theForm));
 }
 
+/**
+ * Export privileges modal handler
+ *
+ * @param {object} data
+ *
+ * @param {JQuery} msgbox
+ *
+ */
+function exportPrivilegesModalHandler (data, msgbox) {
+    if (typeof data !== 'undefined' && data.success === true) {
+        var modal = $('#exportPrivilegesModal');
+        // Remove any previous privilege modal data, if any
+        modal.find('.modal-body').first().html('');
+        $('#exportPrivilegesModalLabel').first().html('Loading');
+        modal.modal('show');
+        modal.on('shown.bs.modal', function () {
+            modal.find('.modal-body').first().html(data.message);
+            $('#exportPrivilegesModalLabel').first().html(data.title);
+            Functions.ajaxRemoveMessage(msgbox);
+            // Attach syntax highlighted editor to export dialog
+            Functions.getSqlEditor(modal.find('textarea'));
+        });
+        return;
+    }
+    Functions.ajaxShowMessage(data.error, false);
+}
+
+/**
+ * @implements EventListener
+ */
+const EditUserGroup = {
+    /**
+     * @param {MouseEvent} event
+     */
+    handleEvent: function (event) {
+        const editUserGroupModal = document.getElementById('editUserGroupModal');
+        const button = event.relatedTarget;
+        const username = button.getAttribute('data-username');
+
+        $.get(
+            'index.php?route=/server/user-groups/edit-form',
+            {
+                'username': username,
+                'server': CommonParams.get('server')
+            },
+            data => {
+                if (typeof data === 'undefined' || data.success !== true) {
+                    Functions.ajaxShowMessage(data.error, false, 'error');
+
+                    return;
+                }
+
+                const modal = bootstrap.Modal.getInstance(editUserGroupModal);
+                const modalBody = editUserGroupModal.querySelector('.modal-body');
+                const saveButton = editUserGroupModal.querySelector('#editUserGroupModalSaveButton');
+
+                modalBody.innerHTML = data.message;
+
+                saveButton.addEventListener('click', () => {
+                    const form = $(editUserGroupModal.querySelector('#changeUserGroupForm'));
+
+                    $.post(
+                        'index.php?route=/server/privileges',
+                        form.serialize() + CommonParams.get('arg_separator') + 'ajax_request=1',
+                        data => {
+                            if (typeof data === 'undefined' || data.success !== true) {
+                                Functions.ajaxShowMessage(data.error, false, 'error');
+
+                                return;
+                            }
+
+                            const userGroup = form.serializeArray().find(el => el.name === 'userGroup').value;
+                            // button -> td -> tr -> td.usrGroup
+                            const userGroupTableCell = button.parentElement.parentElement.querySelector('.usrGroup');
+                            userGroupTableCell.textContent = userGroup;
+                        }
+                    );
+
+                    modal.hide();
+                });
+            }
+        );
+    }
+};
+
+/**
+ * @implements EventListener
+ */
+const AccountLocking = {
+    handleEvent: function () {
+        const button = this;
+        const isLocked = button.dataset.isLocked === 'true';
+        const url = isLocked
+            ? 'index.php?route=/server/privileges/account-unlock'
+            : 'index.php?route=/server/privileges/account-lock';
+        const params = {
+            'username': button.dataset.userName,
+            'hostname': button.dataset.hostName,
+            'ajax_request': true,
+            'server': CommonParams.get('server'),
+        };
+
+        $.post(url, params, data => {
+            if (data.success === false) {
+                Functions.ajaxShowMessage(data.error);
+                return;
+            }
+
+            if (isLocked) {
+                const lockIcon = Functions.getImage('s_lock', Messages.strLock, {}).toString();
+                button.innerHTML = '<span class="text-nowrap">' + lockIcon + ' ' + Messages.strLock + '</span>';
+                button.title = Messages.strLockAccount;
+                button.dataset.isLocked = 'false';
+            } else {
+                const unlockIcon = Functions.getImage('s_unlock', Messages.strUnlock, {}).toString();
+                button.innerHTML = '<span class="text-nowrap">' + unlockIcon + ' ' + Messages.strUnlock + '</span>';
+                button.title = Messages.strUnlockAccount;
+                button.dataset.isLocked = 'true';
+            }
+
+            Functions.ajaxShowMessage(data.message);
+        });
+    }
+};
+
 /**
  * AJAX scripts for /server/privileges page.
  *
@@ -51,9 +178,15 @@ function checkAddUser (theForm) {
 AJAX.registerTeardown('server/privileges.js', function () {
     $('#fieldset_add_user_login').off('change', 'input[name=\'username\']');
     $(document).off('click', '#deleteUserCard .btn.ajax');
-    $(document).off('click', 'a.edit_user_group_anchor.ajax');
+
+    const editUserGroupModal = document.getElementById('editUserGroupModal');
+    if (editUserGroupModal) {
+        editUserGroupModal.removeEventListener('show.bs.modal', EditUserGroup);
+    }
+
     $(document).off('click', 'button.mult_submit[value=export]');
     $(document).off('click', 'a.export_user_anchor.ajax');
+    $('button.jsAccountLocking').off('click');
     $('#dropUsersDbCheckbox').off('click');
     $(document).off('click', '.checkall_box');
     $(document).off('change', '#checkbox_SSL_priv');
@@ -165,9 +298,13 @@ AJAX.registerOnload('server/privileges.js', function () {
                         var thisUserInitial = $(this).find('input:checkbox').val().charAt(0).toUpperCase();
                         $(this).remove();
 
-                        // If this is the last user with this_user_initial, remove the link from #initials_table
+                        // If this is the last user with thisUserInitial, remove the link from #userAccountsPagination
                         if ($('#userRightsTable').find('input:checkbox[value^="' + thisUserInitial + '"], input:checkbox[value^="' + thisUserInitial.toLowerCase() + '"]').length === 0) {
-                            $('#initials_table').find('td > a:contains(' + thisUserInitial + ')').parent('td').html(thisUserInitial);
+                            $('#userAccountsPagination')
+                                .find('.page-item > .page-link:contains(' + thisUserInitial + ')')
+                                .parent('.page-item')
+                                .addClass('disabled')
+                                .html('<a class="page-link" href="#" tabindex="-1" aria-disabled="true">' + thisUserInitial + '</a>');
                         }
 
                         // Re-check the classes of each row
@@ -189,73 +326,10 @@ AJAX.registerOnload('server/privileges.js', function () {
         });
     }); // end Revoke User
 
-    $(document).on('click', 'a.edit_user_group_anchor.ajax', function (event) {
-        event.preventDefault();
-        $(this).parents('tr').addClass('current_row');
-        var $msg = Functions.ajaxShowMessage();
-        $.get(
-            $(this).attr('href'),
-            {
-                'ajax_request': true,
-                'edit_user_group_dialog': true
-            },
-            function (data) {
-                if (typeof data !== 'undefined' && data.success === true) {
-                    Functions.ajaxRemoveMessage($msg);
-                    var buttonOptions = {};
-                    buttonOptions[Messages.strGo] = function () {
-                        var usrGroup = $('#changeUserGroupDialog')
-                            .find('select[name="userGroup"]')
-                            .val();
-                        var $message = Functions.ajaxShowMessage();
-                        var argsep = CommonParams.get('arg_separator');
-                        $.post(
-                            'index.php?route=/server/privileges',
-                            $('#changeUserGroupDialog').find('form').serialize() + argsep + 'ajax_request=1',
-                            function (data) {
-                                Functions.ajaxRemoveMessage($message);
-                                if (typeof data !== 'undefined' && data.success === true) {
-                                    $('#usersForm')
-                                        .find('.current_row')
-                                        .removeClass('current_row')
-                                        .find('.usrGroup')
-                                        .text(usrGroup);
-                                } else {
-                                    Functions.ajaxShowMessage(data.error, false);
-                                    $('#usersForm')
-                                        .find('.current_row')
-                                        .removeClass('current_row');
-                                }
-                            }
-                        );
-                        $(this).dialog('close');
-                    };
-                    buttonOptions[Messages.strClose] = function () {
-                        $(this).dialog('close');
-                    };
-                    var $dialog = $('<div></div>')
-                        .attr('id', 'changeUserGroupDialog')
-                        .append(data.message)
-                        .dialog({
-                            width: 500,
-                            minWidth: 300,
-                            modal: true,
-                            buttons: buttonOptions,
-                            title: $('legend', $(data.message)).text(),
-                            close: function () {
-                                $(this).remove();
-                            }
-                        });
-                    $dialog.find('legend').remove();
-                } else {
-                    Functions.ajaxShowMessage(data.error, false);
-                    $('#usersForm')
-                        .find('.current_row')
-                        .removeClass('current_row');
-                }
-            }
-        );
-    });
+    const editUserGroupModal = document.getElementById('editUserGroupModal');
+    if (editUserGroupModal) {
+        editUserGroupModal.addEventListener('show.bs.modal', EditUserGroup);
+    }
 
     /**
      * AJAX handler for 'Export Privileges'
@@ -271,73 +345,29 @@ AJAX.registerOnload('server/privileges.js', function () {
             Functions.ajaxShowMessage(Messages.strNoAccountSelected, 2000, 'success');
             return;
         }
-        var $msgbox = Functions.ajaxShowMessage();
-        var buttonOptions = {};
-        buttonOptions[Messages.strClose] = function () {
-            $(this).dialog('close');
-        };
+        var msgbox = Functions.ajaxShowMessage();
         var argsep = CommonParams.get('arg_separator');
         var serverId = CommonParams.get('server');
         var selectedUsers = $('#usersForm input[name*=\'selected_usr\']:checkbox').serialize();
         var postStr = selectedUsers + '&submit_mult=export' + argsep + 'ajax_request=true&server=' + serverId;
-        $.post(
-            $(this.form).prop('action'),
-            postStr,
-            function (data) {
-                if (typeof data !== 'undefined' && data.success === true) {
-                    var $ajaxDialog = $('<div></div>')
-                        .append(data.message)
-                        .dialog({
-                            title: data.title,
-                            width: 500,
-                            buttons: buttonOptions,
-                            close: function () {
-                                $(this).remove();
-                            }
-                        });
-                    Functions.ajaxRemoveMessage($msgbox);
-                    // Attach syntax highlighted editor to export dialog
-                    Functions.getSqlEditor($ajaxDialog.find('textarea'));
-                } else {
-                    Functions.ajaxShowMessage(data.error, false);
-                }
-            }
-        ); // end $.post
+
+        $.post($(this.form).prop('action'), postStr, function (data) {
+            exportPrivilegesModalHandler(data, msgbox);
+        }); // end $.post
     });
     // if exporting non-ajax, highlight anyways
     Functions.getSqlEditor($('textarea.export'));
 
     $(document).on('click', 'a.export_user_anchor.ajax', function (event) {
         event.preventDefault();
-        var $msgbox = Functions.ajaxShowMessage();
-        /**
-         * @var button_options  Object containing options for jQueryUI dialog buttons
-         */
-        var buttonOptions = {};
-        buttonOptions[Messages.strClose] = function () {
-            $(this).dialog('close');
-        };
+        var msgbox = Functions.ajaxShowMessage();
         $.get($(this).attr('href'), { 'ajax_request': true }, function (data) {
-            if (typeof data !== 'undefined' && data.success === true) {
-                var $ajaxDialog = $('<div></div>')
-                    .append(data.message)
-                    .dialog({
-                        title: data.title,
-                        width: 500,
-                        buttons: buttonOptions,
-                        close: function () {
-                            $(this).remove();
-                        }
-                    });
-                Functions.ajaxRemoveMessage($msgbox);
-                // Attach syntax highlighted editor to export dialog
-                Functions.getSqlEditor($ajaxDialog.find('textarea'));
-            } else {
-                Functions.ajaxShowMessage(data.error, false);
-            }
+            exportPrivilegesModalHandler(data, msgbox);
         }); // end $.get
     }); // end export privileges
 
+    $('button.jsAccountLocking').on('click', AccountLocking.handleEvent);
+
     $(document).on('change', 'input[name="ssl_type"]', function () {
         var $div = $('#specified_div');
         if ($('#ssl_type_SPECIFIED').is(':checked')) {
@@ -426,6 +456,25 @@ AJAX.registerOnload('server/privileges.js', function () {
         addOrUpdateSubmenu();
     }
 
+    /**
+     * Select all privileges
+     *
+     * @param {HTMLElement} e
+     * @return {void}
+     */
+    var tableSelectAll = function (e) {
+        const method = e.target.getAttribute('data-select-target');
+        var options = $(method).first().children();
+        options.each(function (_, obj) {
+            obj.selected = true;
+        });
+    };
+
+    $('#select_priv_all').on('click', tableSelectAll);
+    $('#insert_priv_all').on('click', tableSelectAll);
+    $('#update_priv_all').on('click', tableSelectAll);
+    $('#references_priv_all').on('click', tableSelectAll);
+
     var windowWidth = $(window).width();
     $('.jsresponsive').css('max-width', (windowWidth - 35) + 'px');
 
