@@ -21,16 +21,31 @@ var chartSize;
 var monitorSettings;
 
 function serverResponseError () {
-    var btns = {};
-    btns[Messages.strReloadPage] = function () {
-        window.location.reload();
+    var btns = {
+        [Messages.strReloadPage]: {
+            text: Messages.strReloadPage,
+            class: 'btn btn-primary',
+            click: function () {
+                window.location.reload();
+            },
+        },
     };
-    $('#emptyDialog').dialog({ title: Messages.strRefreshFailed });
+    $('#emptyDialog').dialog({
+        classes: {
+            'ui-dialog-titlebar-close': 'btn-close'
+        },
+        title: Messages.strRefreshFailed
+    });
     $('#emptyDialog').html(
         Functions.getImage('s_attention') +
         Messages.strInvalidResponseExplanation
     );
-    $('#emptyDialog').dialog({ buttons: btns });
+    $('#emptyDialog').dialog({
+        classes: {
+            'ui-dialog-titlebar-close': 'btn-close'
+        },
+        buttons: btns
+    });
 }
 
 /**
@@ -76,7 +91,6 @@ AJAX.registerOnload('server/status/monitor.js', function () {
  */
 AJAX.registerTeardown('server/status/monitor.js', function () {
     $('#emptyDialog').remove();
-    $('#addChartDialog').remove();
     $('a.popupLink').off('click');
     $('body').off('click');
 });
@@ -87,8 +101,6 @@ AJAX.registerOnload('server/status/monitor.js', function () {
     $('<div></div>')
         .attr('id', 'emptyDialog')
         .appendTo('#page_content');
-    $('#addChartDialog')
-        .appendTo('#page_content');
 
     $('a.popupLink').on('click', function () {
         var $link = $(this);
@@ -104,9 +116,7 @@ AJAX.registerOnload('server/status/monitor.js', function () {
             var $cnt = $(this);
             var pos = $cnt.offset();
             // Hide if the mouseclick is outside the popupcontent
-            if (event.pageX < pos.left ||
-                event.pageY < pos.top ||
-                event.pageX > pos.left + $cnt.outerWidth() ||
+            if (event.pageX > pos.left + $cnt.outerWidth() ||
                 event.pageY > pos.top + $cnt.outerHeight()
             ) {
                 $cnt.hide().removeClass('openedPopup');
@@ -266,15 +276,15 @@ AJAX.registerOnload('server/status/monitor.js', function () {
             'memory': {
                 title: Messages.strSystemMemory,
                 series: [{
-                    label: Messages.strTotalMemory,
-                    fill: true
-                }, {
                     dataType: 'memory',
                     label: Messages.strUsedMemory,
                     fill: true
+                }, {
+                    label: Messages.strFreeMemory,
+                    fill: true
                 }],
-                nodes: [{ dataPoints: [{ type: 'memory', name: 'MemTotal' }], valueDivisor: 1024 },
-                    { dataPoints: [{ type: 'memory', name: 'MemUsed' }], valueDivisor: 1024 }
+                nodes: [{ dataPoints: [{ type: 'memory', name: 'MemUsed' }], valueDivisor: 1024 },
+                    { dataPoints: [{ type: 'memory', name: 'MemFree' }], valueDivisor: 1024 }
                 ],
                 maxYLabel: 0
             },
@@ -282,14 +292,14 @@ AJAX.registerOnload('server/status/monitor.js', function () {
             'swap': {
                 title: Messages.strSystemSwap,
                 series: [{
-                    label: Messages.strTotalSwap,
-                    fill: true
-                }, {
                     label: Messages.strUsedSwap,
                     fill: true
+                }, {
+                    label: Messages.strFreeSwap,
+                    fill: true
                 }],
-                nodes: [{ dataPoints: [{ type: 'memory', name: 'SwapTotal' }] },
-                    { dataPoints: [{ type: 'memory', name: 'SwapUsed' }] }
+                nodes: [{ dataPoints: [{ type: 'memory', name: 'SwapUsed' }], valueDivisor: 1024 },
+                    { dataPoints: [{ type: 'memory', name: 'SwapFree' }], valueDivisor: 1024 }
                 ],
                 maxYLabel: 0
             }
@@ -535,13 +545,12 @@ AJAX.registerOnload('server/status/monitor.js', function () {
 
     $('a[href="#addNewChart"]').on('click', function (event) {
         event.preventDefault();
-        var dlgButtons = { };
 
-        dlgButtons[Messages.strAddChart] = function () {
+        $('#addChartButton').on('click', function () {
             var type = $('input[name="chartType"]:checked').val();
 
             if (type === 'preset') {
-                newChart = presetCharts[$('#addChartDialog').find('select[name="presetCharts"]').prop('value')];
+                newChart = presetCharts[$('#addChartModal').find('select[name="presetCharts"]').prop('value')];
             } else {
                 // If user builds their own chart, it's being set/updated
                 // each time they add a series
@@ -560,17 +569,17 @@ AJAX.registerOnload('server/status/monitor.js', function () {
 
             saveMonitor(); // Save settings
 
-            $(this).dialog('close');
-        };
+            $('#closeModalButton').off('click');
+        });
 
-        dlgButtons[Messages.strClose] = function () {
+        $('#closeModalButton').on('click', function () {
             newChart = null;
             $('span#clearSeriesLink').hide();
             $('#seriesPreview').html('');
-            $(this).dialog('close');
-        };
+            $('#closeModalButton').off('click');
+        });
 
-        var $presetList = $('#addChartDialog').find('select[name="presetCharts"]');
+        var $presetList = $('#addChartModal').find('select[name="presetCharts"]');
         if ($presetList.html().length === 0) {
             $.each(presetCharts, function (key, value) {
                 $presetList.append('<option value="' + key + '">' + value.title + '</option>');
@@ -598,11 +607,7 @@ AJAX.registerOnload('server/status/monitor.js', function () {
             });
         }
 
-        $('#addChartDialog').dialog({
-            width: 'auto',
-            height: 'auto',
-            buttons: dlgButtons
-        });
+        $('#addChartModal').modal('show');
 
         $('#seriesPreview').html('<i>' + Messages.strNone + '</i>');
 
@@ -646,13 +651,27 @@ AJAX.registerOnload('server/status/monitor.js', function () {
 
     $('a[href="#importMonitorConfig"]').on('click', function (event) {
         event.preventDefault();
-        $('#emptyDialog').dialog({ title: Messages.strImportDialogTitle });
-        $('#emptyDialog').html(Messages.strImportDialogMessage + ':<br><form>' +
+        $('#emptyDialog').dialog({
+            classes: {
+                'ui-dialog-titlebar-close': 'btn-close'
+            },
+            title: Messages.strImportDialogTitle
+        });
+        $('#emptyDialog').html(Messages.strImportDialogMessage + '<br><form>' +
             '<input type="file" name="file" id="import_file"> </form>');
 
-        var dlgBtns = {};
+        var dlgBtns = {
+            [Messages.strImport]: {
+                text: Messages.strImport,
+                class: 'btn btn-primary',
+            },
+            [Messages.strCancel]: {
+                text: Messages.strCancel,
+                class: 'btn btn-secondary',
+            },
+        };
 
-        dlgBtns[Messages.strImport] = function () {
+        dlgBtns[Messages.strImport].click = function () {
             var input = $('#emptyDialog').find('#import_file')[0];
             var reader = new FileReader();
 
@@ -700,11 +719,14 @@ AJAX.registerOnload('server/status/monitor.js', function () {
             reader.readAsText(input.files[0]);
         };
 
-        dlgBtns[Messages.strCancel] = function () {
+        dlgBtns[Messages.strCancel].click = function () {
             $(this).dialog('close');
         };
 
         $('#emptyDialog').dialog({
+            classes: {
+                'ui-dialog-titlebar-close': 'btn-close'
+            },
             width: 'auto',
             height: 'auto',
             buttons: dlgBtns
@@ -741,11 +763,19 @@ AJAX.registerOnload('server/status/monitor.js', function () {
         event.preventDefault();
 
         var $dialog = $('#monitorInstructionsDialog');
-        var dlgBtns = {};
-        dlgBtns[Messages.strClose] = function () {
-            $(this).dialog('close');
+        var dlgBtns = {
+            [Messages.strClose]: {
+                text: Messages.strClose,
+                class: 'btn btn-primary',
+                click: function () {
+                    $(this).dialog('close');
+                }
+            },
         };
         $dialog.dialog({
+            classes: {
+                'ui-dialog-titlebar-close': 'btn-close'
+            },
             width: '60%',
             height: 'auto',
             buttons: dlgBtns
@@ -1014,15 +1044,28 @@ AJAX.registerOnload('server/status/monitor.js', function () {
                 && typeof window.localStorage.monitorVersion !== 'undefined'
                 && monitorProtocolVersion !== window.localStorage.monitorVersion
             ) {
-                $('#emptyDialog').dialog({ title: Messages.strIncompatibleMonitorConfig });
+                $('#emptyDialog').dialog({
+                    classes: {
+                        'ui-dialog-titlebar-close': 'btn-close'
+                    },
+                    title: Messages.strIncompatibleMonitorConfig
+                });
                 $('#emptyDialog').html(Messages.strIncompatibleMonitorConfigDescription);
 
-                var dlgBtns = {};
-                dlgBtns[Messages.strClose] = function () {
-                    $(this).dialog('close');
+                var dlgBtns = {
+                    [Messages.strClose]: {
+                        text: Messages.strClose,
+                        class: 'btn btn-primary',
+                        click: function () {
+                            $(this).dialog('close');
+                        }
+                    },
                 };
 
                 $('#emptyDialog').dialog({
+                    classes: {
+                        'ui-dialog-titlebar-close': 'btn-close'
+                    },
                     width: 400,
                     buttons: dlgBtns
                 });
@@ -1116,7 +1159,7 @@ AJAX.registerOnload('server/status/monitor.js', function () {
         var windowWidth = $(window).width();
 
         if (windowWidth > 768) {
-            wdt = (panelWidth - monitorSettings.columns * chartSpacing.width) / monitorSettings.columns;
+            wdt = (panelWidth - monitorSettings.columns * Math.abs(chartSpacing.width)) / monitorSettings.columns;
         }
 
         chartSize = {
@@ -1285,14 +1328,14 @@ AJAX.registerOnload('server/status/monitor.js', function () {
                         width: '1em',
                         height: '1em',
                         background: chartObj.chart.seriesColors[i]
-                    }).addClass('floatleft')
+                    }).addClass('float-start')
                 ).append(
                     $('<div>').text(
                         chartObj.chart.series[i].label
-                    ).addClass('floatleft')
+                    ).addClass('float-start')
                 ).append(
                     $('<div class="clearfloat">')
-                ).addClass('floatleft')
+                ).addClass('float-start')
             );
         }
         $('#gridchart' + runtime.chartAI)
@@ -1312,6 +1355,7 @@ AJAX.registerOnload('server/status/monitor.js', function () {
                 $('#selection_box').remove();
             }
             var selectionBox = $('<div id="selection_box" >');
+            // eslint-disable-next-line compat/compat
             $(document.body).append(selectionBox);
             selectionStartX = ev.pageX;
             selectionStartY = ev.pageY;
@@ -1360,6 +1404,7 @@ AJAX.registerOnload('server/status/monitor.js', function () {
             drawTimeSpan = false;
         });
 
+        // eslint-disable-next-line compat/compat
         $(document.body).on('mouseup', function () {
             if ($('#selection_box').length) {
                 $('#selection_box').remove();
@@ -1379,19 +1424,31 @@ AJAX.registerOnload('server/status/monitor.js', function () {
         $dateStart.prop('readonly', true);
         $dateEnd.prop('readonly', true);
 
-        var dlgBtns = { };
+        var dlgBtns = {
+            [Messages.strFromSlowLog]: {
+                text: Messages.strFromSlowLog,
+                class: 'btn btn-secondary',
+            },
+            [Messages.strFromGeneralLog]: {
+                text: Messages.strFromGeneralLog,
+                class: 'btn btn-secondary',
+            },
+        };
 
-        dlgBtns[Messages.strFromSlowLog] = function () {
+        dlgBtns[Messages.strFromSlowLog].click = function () {
             loadLog('slow', min, max);
             $(this).dialog('close');
         };
 
-        dlgBtns[Messages.strFromGeneralLog] = function () {
+        dlgBtns[Messages.strFromGeneralLog].click = function () {
             loadLog('general', min, max);
             $(this).dialog('close');
         };
 
         $logAnalyseDialog.dialog({
+            classes: {
+                'ui-dialog-titlebar-close': 'btn-close'
+            },
             width: 'auto',
             height: 'auto',
             buttons: dlgBtns
@@ -1645,13 +1702,24 @@ AJAX.registerOnload('server/status/monitor.js', function () {
             opts.limitTypes = false;
         }
 
-        $('#emptyDialog').dialog({ title: Messages.strAnalysingLogsTitle });
+        $('#emptyDialog').dialog({
+            classes: {
+                'ui-dialog-titlebar-close': 'btn-close'
+            },
+            title: Messages.strAnalysingLogsTitle
+        });
         $('#emptyDialog').html(Messages.strAnalysingLogs +
                                 ' <img class="ajaxIcon" src="' + themeImagePath +
                                 'ajax_clock_small.gif" alt="">');
-        var dlgBtns = {};
 
-        dlgBtns[Messages.strCancelRequest] = function () {
+        var dlgBtns = {
+            [Messages.strCancelRequest]: {
+                text: Messages.strCancelRequest,
+                class: 'btn btn-primary',
+            },
+        };
+
+        dlgBtns[Messages.strCancelRequest].click = function () {
             if (logRequest !== null) {
                 logRequest.abort();
             }
@@ -1660,6 +1728,9 @@ AJAX.registerOnload('server/status/monitor.js', function () {
         };
 
         $('#emptyDialog').dialog({
+            classes: {
+                'ui-dialog-titlebar-close': 'btn-close'
+            },
             width: 'auto',
             height: 'auto',
             buttons: dlgBtns
@@ -1681,7 +1752,12 @@ AJAX.registerOnload('server/status/monitor.js', function () {
             },
             function (data) {
                 var logData;
-                var dlgBtns = {};
+                var dlgBtns = {
+                    [Messages.strClose]: {
+                        text: Messages.strClose,
+                        class: 'btn btn-primary',
+                    },
+                };
                 if (typeof data !== 'undefined' && data.success === true) {
                     logData = data.message;
                 } else {
@@ -1689,10 +1765,15 @@ AJAX.registerOnload('server/status/monitor.js', function () {
                 }
 
                 if (logData.rows.length === 0) {
-                    $('#emptyDialog').dialog({ title: Messages.strNoDataFoundTitle });
+                    $('#emptyDialog').dialog({
+                        classes: {
+                            'ui-dialog-titlebar-close': 'btn-close'
+                        },
+                        title: Messages.strNoDataFoundTitle,
+                    });
                     $('#emptyDialog').html('<p>' + Messages.strNoDataFound + '</p>');
 
-                    dlgBtns[Messages.strClose] = function () {
+                    dlgBtns[Messages.strClose].click = function () {
                         $(this).dialog('close');
                     };
 
@@ -1703,7 +1784,12 @@ AJAX.registerOnload('server/status/monitor.js', function () {
                 runtime.logDataCols = buildLogTable(logData, opts.removeVariables);
 
                 /* Show some stats in the dialog */
-                $('#emptyDialog').dialog({ title: Messages.strLoadingLogs });
+                $('#emptyDialog').dialog({
+                    classes: {
+                        'ui-dialog-titlebar-close': 'btn-close'
+                    },
+                    title: Messages.strLoadingLogs
+                });
                 $('#emptyDialog').html('<p>' + Messages.strLogDataLoaded + '</p>');
                 $.each(logData.sum, function (key, value) {
                     var newKey = key.charAt(0).toUpperCase() + key.slice(1).toLowerCase();
@@ -1716,7 +1802,7 @@ AJAX.registerOnload('server/status/monitor.js', function () {
                 /* Add filter options if more than a bunch of rows there to filter */
                 if (logData.numRows > 12) {
                     $('#logTable').prepend(
-                        '<fieldset id="logDataFilter">' +
+                        '<fieldset class="pma-fieldset" id="logDataFilter">' +
                         '    <legend>' + Messages.strFiltersForLogTable + '</legend>' +
                         '    <div class="formelement">' +
                         '        <label for="filterQueryText">' + Messages.strFilterByWordRegexp + '</label>' +
@@ -1741,22 +1827,27 @@ AJAX.registerOnload('server/status/monitor.js', function () {
                     }
                 }
 
-                dlgBtns[Messages.strJumpToTable] = function () {
-                    $(this).dialog('close');
-                    $(document).scrollTop($('#logTable').offset().top);
+                dlgBtns[Messages.strJumpToTable] = {
+                    text: Messages.strJumpToTable,
+                    class: 'btn btn-secondary',
+                    click: function () {
+                        $(this).dialog('close');
+                        $(document).scrollTop($('#logTable').offset().top);
+                    },
                 };
 
                 $('#emptyDialog').dialog('option', 'buttons', dlgBtns);
             }
         );
 
-        /* Handles the actions performed when the user uses any of the
+        /**
+         * Handles the actions performed when the user uses any of the
          * log table filters which are the filter by name and grouping
          * with ignoring data in WHERE clauses
          *
-         * @param boolean Should be true when the users enabled or disabled
+         * @param {boolean} varFilterChange Should be true when the users enabled or disabled
          *                to group queries ignoring data in WHERE clauses
-        */
+         */
         function filterQueries (varFilterChange) {
             var textFilter;
             var val = $('#filterQueryText').val();
@@ -1807,7 +1898,7 @@ AJAX.registerOnload('server/status/monitor.js', function () {
             };
 
             // We just assume the sql text is always in the second last column, and that the total count is right of it
-            $('#logTable').find('table tbody tr').children('td').eq(runtime.logDataCols.length - 2).each(function () {
+            $('#logTable').find('table tbody tr td.queryCell').each(function () {
                 var $t = $(this);
                 // If query is a SELECT and user enabled or disabled to group
                 // queries ignoring data in where statements, we
@@ -1903,8 +1994,8 @@ AJAX.registerOnload('server/status/monitor.js', function () {
             // Display some stats at the bottom of the table
             $('#logTable').find('table tfoot tr')
                 .html('<th colspan="' + (runtime.logDataCols.length - 1) + '">' +
-                      Messages.strSumRows + ' ' + rowSum + '<span class="floatright">' +
-                      Messages.strTotal + '</span></th><th class="right">' + totalSum + '</th>');
+                      Messages.strSumRows + ' ' + rowSum + '<span class="float-end">' +
+                      Messages.strTotal + '</span></th><th class="text-end">' + totalSum + '</th>');
         }
     }
 
@@ -1939,7 +2030,7 @@ AJAX.registerOnload('server/status/monitor.js', function () {
     function buildLogTable (data, groupInserts) {
         var rows = data.rows;
         var cols = [];
-        var $table = $('<table class="pma-table sortable"></table>');
+        var $table = $('<table class="table table-striped table-hover align-middle sortable"></table>');
         var $tBody;
         var $tRow;
         var $tCell;
@@ -1961,7 +2052,7 @@ AJAX.registerOnload('server/status/monitor.js', function () {
             if (i === 0) {
                 $.each(rows[0], tempPushKey);
                 $table.append('<thead>' +
-                              '<tr><th class="nowrap">' + cols.join('</th><th class="nowrap">') + '</th></tr>' +
+                              '<tr><th class="text-nowrap">' + cols.join('</th><th class="text-nowrap">') + '</th></tr>' +
                               '</thead>'
                 );
 
@@ -1972,7 +2063,7 @@ AJAX.registerOnload('server/status/monitor.js', function () {
             for (var j = 0, ll = cols.length; j < ll; j++) {
                 // Assuming the query column is the second last
                 if (j === cols.length - 2 && rows[i][cols[j]].match(/^SELECT/i)) {
-                    $tRow.append($tCell = $('<td class="linkElem">' + formatValue(cols[j], rows[i][cols[j]]) + '</td>'));
+                    $tRow.append($tCell = $('<td class="linkElem queryCell">' + formatValue(cols[j], rows[i][cols[j]]) + '</td>'));
                     $tCell.on('click', openQueryAnalyzer);
                 } else {
                     $tRow.append('<td>' + formatValue(cols[j], rows[i][cols[j]]) + '</td>');
@@ -1984,8 +2075,8 @@ AJAX.registerOnload('server/status/monitor.js', function () {
 
         $table.append('<tfoot>' +
                     '<tr><th colspan="' + (cols.length - 1) + '">' + Messages.strSumRows +
-                    ' ' + data.numRows + '<span class="floatright">' + Messages.strTotal +
-                    '</span></th><th class="right">' + data.sum.TOTAL + '</th></tr></tfoot>');
+                    ' ' + data.numRows + '<span class="float-end">' + Messages.strTotal +
+                    '</span></th><th class="text-end">' + data.sum.TOTAL + '</th></tr></tfoot>');
 
         // Append a tooltip to the count column, if there exist one
         if ($('#logTable').find('tr').first().find('th').last().text().indexOf('#') > -1) {
@@ -2033,16 +2124,28 @@ AJAX.registerOnload('server/status/monitor.js', function () {
         }
 
         var profilingChart = null;
-        var dlgBtns = {};
+        var dlgBtns = {
+            [Messages.strAnalyzeQuery]: {
+                text: Messages.strAnalyzeQuery,
+                class: 'btn btn-primary',
+            },
+            [Messages.strClose]: {
+                text: Messages.strClose,
+                class: 'btn btn-secondary',
+            },
+        };
 
-        dlgBtns[Messages.strAnalyzeQuery] = function () {
+        dlgBtns[Messages.strAnalyzeQuery].click = function () {
             profilingChart = loadQueryAnalysis(rowData);
         };
-        dlgBtns[Messages.strClose] = function () {
+        dlgBtns[Messages.strClose].click = function () {
             $(this).dialog('close');
         };
 
         $('#queryAnalyzerDialog').dialog({
+            classes: {
+                'ui-dialog-titlebar-close': 'btn-close'
+            },
             width: 'auto',
             height: 'auto',
             resizable: false,
@@ -2092,7 +2195,7 @@ AJAX.registerOnload('server/status/monitor.js', function () {
             var totalTime = 0;
             // Float sux, I'll use table :(
             $('#queryAnalyzerDialog').find('div.placeHolder')
-                .html('<table class="pma-table" width="100%" border="0"><tr><td class="explain"></td><td class="chart"></td></tr></table>');
+                .html('<table class="table table-borderless"><tr><td class="explain"></td><td class="chart"></td></tr></table>');
 
             var explain = '<b>' + Messages.strExplainOutput + '</b> ' + $('#explain_docu').html();
             if (data.explain.length > 1) {
@@ -2111,10 +2214,10 @@ AJAX.registerOnload('server/status/monitor.js', function () {
                 var newValue = (value === null) ? 'null' : Functions.escapeHtml(value);
 
                 if (key === 'type' && newValue.toLowerCase() === 'all') {
-                    newValue = '<span class="attention">' + newValue + '</span>';
+                    newValue = '<span class="text-danger">' + newValue + '</span>';
                 }
                 if (key === 'Extra') {
-                    newValue = newValue.replace(/(using (temporary|filesort))/gi, '<span class="attention">$1</span>');
+                    newValue = newValue.replace(/(using (temporary|filesort))/gi, '<span class="text-danger">$1</span>');
                 }
                 explain += key + ': ' + newValue + '<br>';
             };
@@ -2137,7 +2240,7 @@ AJAX.registerOnload('server/status/monitor.js', function () {
 
             if (data.profiling) {
                 var chartData = [];
-                var numberTable = '<table class="pma-table queryNums"><thead><tr><th>' + Messages.strStatus + '</th><th>' + Messages.strTime + '</th></tr></thead><tbody>';
+                var numberTable = '<table class="table table-sm table-striped table-hover w-auto queryNums"><thead><tr><th>' + Messages.strStatus + '</th><th>' + Messages.strTime + '</th></tr></thead><tbody>';
                 var duration;
                 var otherTime = 0;
 
