@@ -7,6 +7,8 @@ declare(strict_types=1);
 
 namespace PhpMyAdmin;
 
+use function __;
+use function array_keys;
 use function asort;
 use function ceil;
 use function floor;
@@ -28,8 +30,6 @@ class BrowseForeigners
     private $repeatCells;
     /** @var bool */
     private $showAll;
-    /** @var string */
-    private $themeImage;
 
     /** @var Template */
     public $template;
@@ -39,7 +39,7 @@ class BrowseForeigners
      */
     public function __construct(Template $template)
     {
-        global $cfg, $PMA_Theme;
+        global $cfg;
 
         $this->template = $template;
 
@@ -47,41 +47,42 @@ class BrowseForeigners
         $this->maxRows = (int) $cfg['MaxRows'];
         $this->repeatCells = (int) $cfg['RepeatCells'];
         $this->showAll = (bool) $cfg['ShowAll'];
-        $this->themeImage = $PMA_Theme->getImgPath();
     }
 
     /**
      * Function to get html for one relational key
      *
-     * @param int    $horizontal_count   the current horizontal count
+     * @param int    $horizontalCount    the current horizontal count
      * @param string $header             table header
      * @param array  $keys               all the keys
      * @param int    $indexByKeyname     index by keyname
      * @param array  $descriptions       descriptions
      * @param int    $indexByDescription index by description
-     * @param string $current_value      current value on the edit form
+     * @param string $currentValue       current value on the edit form
      *
      * @return array the generated html
      */
     private function getHtmlForOneKey(
-        int $horizontal_count,
+        int $horizontalCount,
         string $header,
         array $keys,
         int $indexByKeyname,
         array $descriptions,
         int $indexByDescription,
-        string $current_value
+        string $currentValue
     ): array {
-        $horizontal_count++;
+        global $theme;
+
+        $horizontalCount++;
         $output = '';
 
         // whether the key name corresponds to the selected value in the form
         $rightKeynameIsSelected = false;
         $leftKeynameIsSelected = false;
 
-        if ($this->repeatCells > 0 && $horizontal_count > $this->repeatCells) {
+        if ($this->repeatCells > 0 && $horizontalCount > $this->repeatCells) {
             $output .= $header;
-            $horizontal_count = 0;
+            $horizontalCount = 0;
         }
 
         // key names and descriptions for the left section,
@@ -102,9 +103,9 @@ class BrowseForeigners
 
         $indexByDescription++;
 
-        if (! empty($current_value)) {
-            $rightKeynameIsSelected = $rightKeyname == $current_value;
-            $leftKeynameIsSelected = $leftKeyname == $current_value;
+        if (! empty($currentValue)) {
+            $rightKeynameIsSelected = $rightKeyname == $currentValue;
+            $leftKeynameIsSelected = $leftKeyname == $currentValue;
         }
 
         $output .= '<tr class="noclick">';
@@ -124,9 +125,9 @@ class BrowseForeigners
             'nowrap' => false,
         ]);
 
-        $output .= '<td width="20%">'
-            . '<img src="' . $this->themeImage . 'spacer.png" alt=""'
-            . ' width="1" height="1"></td>';
+        $output .= '<td width="20%"><img src="'
+            . ($theme instanceof Theme ? $theme->getImgPath('spacer.png') : '')
+            . '" alt="" width="1" height="1"></td>';
 
         $output .= $this->template->render('table/browse_foreigners/column_element', [
             'keyname' => $rightKeyname,
@@ -147,7 +148,7 @@ class BrowseForeigners
 
         return [
             $output,
-            $horizontal_count,
+            $horizontalCount,
             $indexByDescription,
         ];
     }
@@ -155,22 +156,22 @@ class BrowseForeigners
     /**
      * Function to get html for relational field selection
      *
-     * @param string      $db            current database
-     * @param string      $table         current table
-     * @param string      $field         field
-     * @param array       $foreignData   foreign column data
-     * @param string|null $fieldkey      field key
-     * @param string      $current_value current columns's value
+     * @param string      $db           current database
+     * @param string      $table        current table
+     * @param string      $field        field
+     * @param array       $foreignData  foreign column data
+     * @param string|null $fieldKey     field key
+     * @param string      $currentValue current columns's value
      */
     public function getHtmlForRelationalFieldSelection(
         string $db,
         string $table,
         string $field,
         array $foreignData,
-        ?string $fieldkey,
-        string $current_value
+        ?string $fieldKey,
+        string $currentValue
     ): string {
-        $gotopage = $this->getHtmlForGotoPage($foreignData);
+        $gotoPage = $this->getHtmlForGotoPage($foreignData);
         $foreignShowAll = $this->template->render('table/browse_foreigners/show_all', [
             'foreign_data' => $foreignData,
             'show_all' => $this->showAll,
@@ -180,35 +181,36 @@ class BrowseForeigners
         $output = '<form class="ajax" '
             . 'id="browse_foreign_form" name="browse_foreign_from" action="'
             . Url::getFromRoute('/browse-foreigners')
-            . '" method="post"><fieldset>'
+            . '" method="post"><fieldset class="row g-3 align-items-center mb-3">'
             . Url::getHiddenInputs($db, $table)
             . '<input type="hidden" name="field" value="' . htmlspecialchars($field)
             . '">'
             . '<input type="hidden" name="fieldkey" value="'
-            . (isset($fieldkey) ? htmlspecialchars($fieldkey) : '') . '">';
+            . (isset($fieldKey) ? htmlspecialchars($fieldKey) : '') . '">';
 
         if (isset($_POST['rownumber'])) {
             $output .= '<input type="hidden" name="rownumber" value="'
                 . htmlspecialchars((string) $_POST['rownumber']) . '">';
         }
-        $filter_value = (isset($_POST['foreign_filter'])
+
+        $filterValue = (isset($_POST['foreign_filter'])
             ? htmlspecialchars($_POST['foreign_filter'])
             : '');
-        $output .= '<span class="formelement">'
-            . '<label for="input_foreign_filter">' . __('Search:') . '</label>'
-            . '<input type="text" name="foreign_filter" '
+        $output .= '<div class="col-auto">'
+            . '<label class="form-label" for="input_foreign_filter">' . __('Search:') . '</label></div>'
+            . '<div class="col-auto"><input class="form-control" type="text" name="foreign_filter" '
             . 'id="input_foreign_filter" '
-            . 'value="' . $filter_value . '" data-old="' . $filter_value . '" '
-            . '>'
+            . 'value="' . $filterValue . '" data-old="' . $filterValue . '">'
+            . '</div><div class="col-auto">'
             . '<input class="btn btn-primary" type="submit" name="submit_foreign_filter" value="'
             . __('Go') . '">'
-            . '</span>'
-            . '<span class="formelement">' . $gotopage . '</span>'
-            . '<span class="formelement">' . $foreignShowAll . '</span>'
+            . '</div>'
+            . '<div class="col-auto">' . $gotoPage . '</div>'
+            . '<div class="col-auto">' . $foreignShowAll . '</div>'
             . '</fieldset>'
             . '</form>';
 
-        $output .= '<table class="pma-table" width="100%" id="browse_foreign_table">';
+        $output .= '<table class="table table-striped table-hover" id="browse_foreign_table">';
 
         if (! is_array($foreignData['disp_row'])) {
             return $output . '</tbody>'
@@ -228,7 +230,7 @@ class BrowseForeigners
             . '<tbody>' . "\n";
 
         $descriptions = [];
-        $keys   = [];
+        $keys = [];
         foreach ($foreignData['disp_row'] as $relrow) {
             if ($foreignData['foreign_display'] != false) {
                 $descriptions[] = $relrow[$foreignData['foreign_display']] ?? '';
@@ -241,28 +243,27 @@ class BrowseForeigners
 
         asort($keys);
 
-        $horizontal_count = 0;
+        $horizontalCount = 0;
         $indexByDescription = 0;
 
-        foreach ($keys as $indexByKeyname => $value) {
+        foreach (array_keys($keys) as $indexByKeyname) {
             [
                 $html,
-                $horizontal_count,
+                $horizontalCount,
                 $indexByDescription,
             ] = $this->getHtmlForOneKey(
-                $horizontal_count,
+                $horizontalCount,
                 $header,
                 $keys,
                 $indexByKeyname,
                 $descriptions,
                 $indexByDescription,
-                $current_value
+                $currentValue
             );
             $output .= $html;
         }
 
-        $output .= '</tbody>'
-            . '</table>';
+        $output .= '</tbody></table>';
 
         return $output;
     }
@@ -277,22 +278,11 @@ class BrowseForeigners
     private function getDescriptionAndTitle(string $description): array
     {
         if (mb_strlen($description) <= $this->limitChars) {
-            $description = htmlspecialchars(
-                $description
-            );
             $descriptionTitle = '';
         } else {
-            $descriptionTitle = htmlspecialchars(
-                $description
-            );
-            $description = htmlspecialchars(
-                mb_substr(
-                    $description,
-                    0,
-                    $this->limitChars
-                )
-                . '...'
-            );
+            $descriptionTitle = $description;
+            $description = mb_substr($description, 0, $this->limitChars)
+            . '...';
         }
 
         return [
@@ -308,17 +298,17 @@ class BrowseForeigners
      */
     private function getHtmlForGotoPage(?array $foreignData): string
     {
-        $gotopage = '';
+        $gotoPage = '';
         isset($_POST['pos']) ? $pos = $_POST['pos'] : $pos = 0;
         if ($foreignData === null || ! is_array($foreignData['disp_row'])) {
-            return $gotopage;
+            return $gotoPage;
         }
 
         $pageNow = (int) floor($pos / $this->maxRows) + 1;
         $nbTotalPage = (int) ceil($foreignData['the_total'] / $this->maxRows);
 
         if ($foreignData['the_total'] > $this->maxRows) {
-            $gotopage = Util::pageselector(
+            $gotoPage = Util::pageselector(
                 'pos',
                 $this->maxRows,
                 $pageNow,
@@ -332,7 +322,7 @@ class BrowseForeigners
             );
         }
 
-        return $gotopage;
+        return $gotoPage;
     }
 
     /**
@@ -345,6 +335,7 @@ class BrowseForeigners
         if (isset($foreignShowAll) && $foreignShowAll == __('Show all')) {
             return null;
         }
+
         isset($_POST['pos']) ? $pos = $_POST['pos'] : $pos = 0;
 
         return 'LIMIT ' . $pos . ', ' . $this->maxRows . ' ';
