@@ -1,20 +1,28 @@
 <?php
-/* vim: set expandtab sw=4 ts=4 sts=4: */
 /**
  * Base class for all GIS data type classes
- *
- * @package PhpMyAdmin-GIS
  */
+
 declare(strict_types=1);
 
 namespace PhpMyAdmin\Gis;
 
+use PhpMyAdmin\Image\ImageWrapper;
 use TCPDF;
 
+use function explode;
+use function floatval;
+use function mb_strripos;
+use function mb_substr;
+use function mt_getrandmax;
+use function preg_match;
+use function random_int;
+use function sprintf;
+use function str_replace;
+use function trim;
+
 /**
  * Base class for all GIS data type classes.
- *
- * @package PhpMyAdmin-GIS
  */
 abstract class GisGeometry
 {
@@ -27,7 +35,6 @@ abstract class GisGeometry
      * @param array  $scale_data data related to scaling
      *
      * @return string the code related to a row in the GIS dataset
-     * @access public
      */
     abstract public function prepareRowAsSvg($spatial, $label, $color, array $scale_data);
 
@@ -38,18 +45,14 @@ abstract class GisGeometry
      * @param string|null $label      Label for the GIS POLYGON object
      * @param string      $color      Color for the GIS POLYGON object
      * @param array       $scale_data Array containing data related to scaling
-     * @param resource    $image      Image object
-     *
-     * @return resource the modified image object
-     * @access public
      */
     abstract public function prepareRowAsPng(
         $spatial,
         ?string $label,
         $color,
         array $scale_data,
-        $image
-    );
+        ImageWrapper $image
+    ): ImageWrapper;
 
     /**
      * Adds to the TCPDF instance, the data related to a row in the GIS dataset.
@@ -61,7 +64,6 @@ abstract class GisGeometry
      * @param TCPDF       $pdf        TCPDF instance
      *
      * @return TCPDF the modified TCPDF instance
-     * @access public
      */
     abstract public function prepareRowAsPdf(
         $spatial,
@@ -78,15 +80,14 @@ abstract class GisGeometry
      * @param string $spatial    GIS data object
      * @param int    $srid       spatial reference ID
      * @param string $label      label for the GIS data object
-     * @param string $color      color for the GIS data object
+     * @param array  $color      color for the GIS data object
      * @param array  $scale_data array containing data related to scaling
      *
      * @return string the JavaScript related to a row in the GIS dataset
-     * @access public
      */
     abstract public function prepareRowAsOl(
         $spatial,
-        $srid,
+        int $srid,
         $label,
         $color,
         array $scale_data
@@ -98,43 +99,43 @@ abstract class GisGeometry
      * @param string $spatial spatial data of a row
      *
      * @return array array containing the min, max values for x and y coordinates
-     * @access public
      */
     abstract public function scaleRow($spatial);
 
     /**
      * Generates the WKT with the set of parameters passed by the GIS editor.
      *
-     * @param array  $gis_data GIS data
-     * @param int    $index    index into the parameter object
-     * @param string $empty    value for empty points
+     * @param array       $gis_data GIS data
+     * @param int         $index    index into the parameter object
+     * @param string|null $empty    value for empty points
      *
      * @return string WKT with the set of parameters passed by the GIS editor
-     * @access public
      */
     abstract public function generateWkt(array $gis_data, $index, $empty = '');
 
     /**
      * Returns OpenLayers.Bounds object that correspond to the bounds of GIS data.
      *
-     * @param string $srid       spatial reference ID
-     * @param array  $scale_data data related to scaling
+     * @param int   $srid       spatial reference ID
+     * @param array $scale_data data related to scaling
      *
      * @return string OpenLayers.Bounds object that
      *                correspond to the bounds of GIS data
-     * @access protected
      */
-    protected function getBoundsForOl($srid, array $scale_data)
+    protected function getBoundsForOl(int $srid, array $scale_data)
     {
-        return 'bound = new OpenLayers.Bounds(); '
-        . 'bound.extend(new OpenLayers.LonLat('
-        . $scale_data['minX'] . ', ' . $scale_data['minY']
-        . ').transform(new OpenLayers.Projection("EPSG:'
-        . intval($srid) . '"), map.getProjectionObject())); '
-        . 'bound.extend(new OpenLayers.LonLat('
-        . $scale_data['maxX'] . ', ' . $scale_data['maxY']
-        . ').transform(new OpenLayers.Projection("EPSG:'
-        . intval($srid) . '"), map.getProjectionObject()));';
+        return sprintf(
+            'var minLoc = [%s, %s];'
+            . 'var maxLoc = [%s, %s];'
+            . 'var ext = ol.extent.boundingExtent([minLoc, maxLoc]);'
+            . 'ext = ol.proj.transformExtent(ext, ol.proj.get("EPSG:%s"), ol.proj.get(\'EPSG:3857\'));'
+            . 'map.getView().fit(ext, map.getSize());',
+            $scale_data['minX'],
+            $scale_data['minY'],
+            $scale_data['maxX'],
+            $scale_data['maxY'],
+            $srid
+        );
     }
 
     /**
@@ -144,31 +145,35 @@ abstract class GisGeometry
      * @param array  $min_max   existing min, max values
      *
      * @return array the updated min, max values
-     * @access protected
      */
     protected function setMinMax($point_set, array $min_max)
     {
         // Separate each point
-        $points = explode(",", $point_set);
+        $points = explode(',', $point_set);
 
         foreach ($points as $point) {
             // Extract coordinates of the point
-            $cordinates = explode(" ", $point);
+            $cordinates = explode(' ', $point);
 
             $x = (float) $cordinates[0];
             if (! isset($min_max['maxX']) || $x > $min_max['maxX']) {
                 $min_max['maxX'] = $x;
             }
+
             if (! isset($min_max['minX']) || $x < $min_max['minX']) {
                 $min_max['minX'] = $x;
             }
+
             $y = (float) $cordinates[1];
             if (! isset($min_max['maxY']) || $y > $min_max['maxY']) {
                 $min_max['maxY'] = $y;
             }
-            if (! isset($min_max['minY']) || $y < $min_max['minY']) {
-                $min_max['minY'] = $y;
+
+            if (isset($min_max['minY']) && $y >= $min_max['minY']) {
+                continue;
             }
+
+            $min_max['minY'] = $y;
         }
 
         return $min_max;
@@ -182,20 +187,18 @@ abstract class GisGeometry
      * @param string $value value of the GIS column
      *
      * @return array parameters for the GIS editor from the value of the GIS column
-     * @access protected
      */
-    protected function generateParams($value)
+    public function generateParams($value)
     {
-        $geom_types = '(POINT|MULTIPOINT|LINESTRING|MULTILINESTRING'
-            . '|POLYGON|MULTIPOLYGON|GEOMETRYCOLLECTION)';
+        $geom_types = '(POINT|MULTIPOINT|LINESTRING|MULTILINESTRING|POLYGON|MULTIPOLYGON|GEOMETRYCOLLECTION)';
         $srid = 0;
         $wkt = '';
 
         if (preg_match("/^'" . $geom_types . "\(.*\)',[0-9]*$/i", $value)) {
-            $last_comma = mb_strripos($value, ",");
-            $srid = trim(mb_substr($value, $last_comma + 1));
+            $last_comma = mb_strripos($value, ',');
+            $srid = (int) trim(mb_substr($value, $last_comma + 1));
             $wkt = trim(mb_substr($value, 1, $last_comma - 2));
-        } elseif (preg_match("/^" . $geom_types . "\(.*\)$/i", $value)) {
+        } elseif (preg_match('/^' . $geom_types . '\(.*\)$/i', $value)) {
             $wkt = $value;
         }
 
@@ -210,34 +213,30 @@ abstract class GisGeometry
      *
      * @param string     $point_set  string of comma separated points
      * @param array|null $scale_data data related to scaling
-     * @param boolean    $linear     if true, as a 1D array, else as a 2D array
+     * @param bool       $linear     if true, as a 1D array, else as a 2D array
      *
      * @return array scaled points
-     * @access protected
      */
-    protected function extractPoints($point_set, $scale_data, $linear = false)
+    protected function extractPoints($point_set, $scale_data, $linear = false): array
     {
         $points_arr = [];
 
         // Separate each point
-        $points = explode(",", $point_set);
+        $points = explode(',', $point_set);
 
         foreach ($points as $point) {
             $point = str_replace(['(', ')'], '', $point);
             // Extract coordinates of the point
-            $cordinates = explode(" ", $point);
+            $coordinates = explode(' ', $point);
 
-            if (isset($cordinates[0]) && trim($cordinates[0]) != ''
-                && isset($cordinates[1])
-                && trim($cordinates[1]) != ''
-            ) {
+            if (isset($coordinates[0], $coordinates[1]) && trim($coordinates[0]) != '' && trim($coordinates[1]) != '') {
                 if ($scale_data != null) {
-                    $x = ($cordinates[0] - $scale_data['x']) * $scale_data['scale'];
+                    $x = ($coordinates[0] - $scale_data['x']) * $scale_data['scale'];
                     $y = $scale_data['height']
-                        - ($cordinates[1] - $scale_data['y']) * $scale_data['scale'];
+                        - ($coordinates[1] - $scale_data['y']) * $scale_data['scale'];
                 } else {
-                    $x = floatval(trim($cordinates[0]));
-                    $y = floatval(trim($cordinates[1]));
+                    $x = floatval(trim($coordinates[0]));
+                    $y = floatval(trim($coordinates[1]));
                 }
             } else {
                 $x = 0;
@@ -261,102 +260,81 @@ abstract class GisGeometry
     /**
      * Generates JavaScript for adding an array of polygons to OpenLayers.
      *
-     * @param array  $polygons x and y coordinates for each polygon
-     * @param string $srid     spatial reference id
+     * @param array $polygons x and y coordinates for each polygon
+     * @param int   $srid     spatial reference id
      *
      * @return string JavaScript for adding an array of polygons to OpenLayers
-     * @access protected
      */
-    protected function getPolygonArrayForOpenLayers(array $polygons, $srid)
+    protected function getPolygonArrayForOpenLayers(array $polygons, int $srid)
     {
-        $ol_array = 'new Array(';
+        $ol_array = 'var polygonArray = [];';
         foreach ($polygons as $polygon) {
-            $rings = explode("),(", $polygon);
-            $ol_array .= $this->getPolygonForOpenLayers($rings, $srid) . ', ';
+            $rings = explode('),(', $polygon);
+            $ol_array .= $this->getPolygonForOpenLayers($rings, $srid);
+            $ol_array .= 'polygonArray.push(polygon);';
         }
 
-        $ol_array
-            = mb_substr(
-                $ol_array,
-                0,
-                mb_strlen($ol_array) - 2
-            );
-        $ol_array .= ')';
-
         return $ol_array;
     }
 
     /**
      * Generates JavaScript for adding points for OpenLayers polygon.
      *
-     * @param array  $polygon x and y coordinates for each line
-     * @param string $srid    spatial reference id
+     * @param array $polygon x and y coordinates for each line
+     * @param int   $srid    spatial reference id
      *
      * @return string JavaScript for adding points for OpenLayers polygon
-     * @access protected
      */
-    protected function getPolygonForOpenLayers(array $polygon, $srid)
+    protected function getPolygonForOpenLayers(array $polygon, int $srid)
     {
-        return 'new OpenLayers.Geometry.Polygon('
-        . $this->getLineArrayForOpenLayers($polygon, $srid, false)
-        . ')';
+        return $this->getLineArrayForOpenLayers($polygon, $srid, false)
+        . 'var polygon = new ol.geom.Polygon(arr);';
     }
 
     /**
      * Generates JavaScript for adding an array of LineString
      * or LineRing to OpenLayers.
      *
-     * @param array  $lines          x and y coordinates for each line
-     * @param string $srid           spatial reference id
-     * @param bool   $is_line_string whether it's an array of LineString
+     * @param array $lines          x and y coordinates for each line
+     * @param int   $srid           spatial reference id
+     * @param bool  $is_line_string whether it's an array of LineString
      *
      * @return string JavaScript for adding an array of LineString
      *                or LineRing to OpenLayers
-     * @access protected
      */
     protected function getLineArrayForOpenLayers(
         array $lines,
-        $srid,
+        int $srid,
         $is_line_string = true
     ) {
-        $ol_array = 'new Array(';
+        $ol_array = 'var arr = [];';
         foreach ($lines as $line) {
+            $ol_array .= 'var lineArr = [];';
             $points_arr = $this->extractPoints($line, null);
-            $ol_array .= $this->getLineForOpenLayers(
-                $points_arr,
-                $srid,
-                $is_line_string
-            );
-            $ol_array .= ', ';
+            $ol_array .= 'var line = ' . $this->getLineForOpenLayers($points_arr, $srid, $is_line_string) . ';';
+            $ol_array .= 'var coord = line.getCoordinates();';
+            $ol_array .= 'for (var i = 0; i < coord.length; i++) lineArr.push(coord[i]);';
+            $ol_array .= 'arr.push(lineArr);';
         }
 
-        $ol_array
-            = mb_substr(
-                $ol_array,
-                0,
-                mb_strlen($ol_array) - 2
-            );
-        $ol_array .= ')';
-
         return $ol_array;
     }
 
     /**
      * Generates JavaScript for adding a LineString or LineRing to OpenLayers.
      *
-     * @param array  $points_arr     x and y coordinates for each point
-     * @param string $srid           spatial reference id
-     * @param bool   $is_line_string whether it's a LineString
+     * @param array $points_arr     x and y coordinates for each point
+     * @param int   $srid           spatial reference id
+     * @param bool  $is_line_string whether it's a LineString
      *
      * @return string JavaScript for adding a LineString or LineRing to OpenLayers
-     * @access protected
      */
     protected function getLineForOpenLayers(
         array $points_arr,
-        $srid,
+        int $srid,
         $is_line_string = true
     ) {
-        return 'new OpenLayers.Geometry.'
+        return 'new ol.geom.'
         . ($is_line_string ? 'LineString' : 'LinearRing') . '('
         . $this->getPointsArrayForOpenLayers($points_arr, $srid)
         . ')';
@@ -365,43 +343,40 @@ abstract class GisGeometry
     /**
      * Generates JavaScript for adding an array of points to OpenLayers.
      *
-     * @param array  $points_arr x and y coordinates for each point
-     * @param string $srid       spatial reference id
+     * @param array $points_arr x and y coordinates for each point
+     * @param int   $srid       spatial reference id
      *
      * @return string JavaScript for adding an array of points to OpenLayers
-     * @access protected
      */
-    protected function getPointsArrayForOpenLayers(array $points_arr, $srid)
+    protected function getPointsArrayForOpenLayers(array $points_arr, int $srid)
     {
         $ol_array = 'new Array(';
         foreach ($points_arr as $point) {
-            $ol_array .= $this->getPointForOpenLayers($point, $srid) . ', ';
+            $ol_array .= $this->getPointForOpenLayers($point, $srid) . '.getCoordinates(), ';
         }
 
-        $ol_array
-            = mb_substr(
-                $ol_array,
-                0,
-                mb_strlen($ol_array) - 2
-            );
-        $ol_array .= ')';
+        $ol_array = mb_substr($ol_array, 0, -2);
 
-        return $ol_array;
+        return $ol_array . ')';
     }
 
     /**
      * Generates JavaScript for adding a point to OpenLayers.
      *
-     * @param array  $point array containing the x and y coordinates of the point
-     * @param string $srid  spatial reference id
+     * @param array $point array containing the x and y coordinates of the point
+     * @param int   $srid  spatial reference id
      *
      * @return string JavaScript for adding points to OpenLayers
-     * @access protected
      */
-    protected function getPointForOpenLayers(array $point, $srid)
+    protected function getPointForOpenLayers(array $point, int $srid)
     {
-        return '(new OpenLayers.Geometry.Point(' . $point[0] . ',' . $point[1] . '))'
-        . '.transform(new OpenLayers.Projection("EPSG:'
-        . intval($srid) . '"), map.getProjectionObject())';
+        return '(new ol.geom.Point([' . $point[0] . ',' . $point[1] . '])'
+        . '.transform(ol.proj.get("EPSG:' . $srid . '")'
+        . ', ol.proj.get(\'EPSG:3857\')))';
+    }
+
+    protected function getRandomId(): int
+    {
+        return random_int(0, mt_getrandmax());
     }
 }
