@@ -1,36 +1,40 @@
 <?php
-/* vim: set expandtab sw=4 ts=4 sts=4: */
 /**
  * SQL data types definition
- *
- * @package PhpMyAdmin
  */
+
 declare(strict_types=1);
 
 namespace PhpMyAdmin;
 
-use PhpMyAdmin\DatabaseInterface;
+use PhpMyAdmin\Query\Compatibility;
+
+use function __;
+use function _pgettext;
+use function array_diff;
+use function array_merge;
+use function array_values;
+use function htmlspecialchars;
+use function in_array;
+use function mb_strtoupper;
+use function sort;
+use function sprintf;
+use function strncasecmp;
 
 /**
  * Class holding type definitions for MySQL and MariaDB.
- *
- * @package PhpMyAdmin
  */
 class Types
 {
-    /**
-     * @var DatabaseInterface Database interface
-     */
-    private $_dbi;
+    /** @var DatabaseInterface Database interface */
+    private $dbi;
 
     /**
-     * Constructor
-     *
      * @param DatabaseInterface $dbi Database interface instance
      */
     public function __construct($dbi)
     {
-        $this->_dbi = $dbi;
+        $this->dbi = $dbi;
     }
 
     /**
@@ -52,10 +56,8 @@ class Types
      * Check whether operator is unary.
      *
      * @param string $op operator name
-     *
-     * @return boolean
      */
-    public function isUnaryOperator($op)
+    public function isUnaryOperator($op): bool
     {
         return in_array($op, $this->getUnaryOperators());
     }
@@ -97,6 +99,7 @@ class Types
             'LIKE',
             'LIKE %...%',
             'NOT LIKE',
+            'NOT LIKE %...%',
             '=',
             '!=',
             'REGEXP',
@@ -128,6 +131,7 @@ class Types
             'LIKE',
             'LIKE %...%',
             'NOT LIKE',
+            'NOT LIKE %...%',
             'IN (...)',
             'NOT IN (...)',
             'BETWEEN',
@@ -135,11 +139,30 @@ class Types
         ];
     }
 
+    /**
+     * UUID search operators
+     *
+     * @return string[]
+     */
+    public function getUUIDOperators()
+    {
+        return [
+            '=',
+            '!=',
+            'LIKE',
+            'LIKE %...%',
+            'NOT LIKE',
+            'NOT LIKE %...%',
+            'IN (...)',
+            'NOT IN (...)',
+        ];
+    }
+
     /**
      * Returns operators for given type
      *
-     * @param string  $type Type of field
-     * @param boolean $null Whether field can be NULL
+     * @param string $type Type of field
+     * @param bool   $null Whether field can be NULL
      *
      * @return string[]
      */
@@ -150,8 +173,10 @@ class Types
 
         if (strncasecmp($type, 'enum', 4) == 0) {
             $ret = array_merge($ret, $this->getEnumOperators());
-        } elseif ($class == 'CHAR') {
+        } elseif ($class === 'CHAR') {
             $ret = array_merge($ret, $this->getTextOperators());
+        } elseif ($class === 'UUID') {
+            $ret = array_merge($ret, $this->getUUIDOperators());
         } else {
             $ret = array_merge($ret, $this->getNumberOperators());
         }
@@ -166,9 +191,9 @@ class Types
     /**
      * Returns operators for given type as html options
      *
-     * @param string  $type             Type of field
-     * @param boolean $null             Whether field can be NULL
-     * @param string  $selectedOperator Option to be selected
+     * @param string $type             Type of field
+     * @param bool   $null             Whether field can be NULL
+     * @param string $selectedOperator Option to be selected
      *
      * @return string Generated Html
      */
@@ -182,6 +207,7 @@ class Types
             } else {
                 $selected = '';
             }
+
             $html .= '<option value="' . htmlspecialchars($fc) . '"'
                 . $selected . '>'
                 . htmlspecialchars($fc) . '</option>';
@@ -196,204 +222,229 @@ class Types
      * @param string $type The data type to get a description.
      *
      * @return string
-     *
      */
     public function getTypeDescription($type)
     {
         $type = mb_strtoupper($type);
         switch ($type) {
             case 'TINYINT':
-                return __(
-                    'A 1-byte integer, signed range is -128 to 127, unsigned range is ' .
-                    '0 to 255'
-                );
+                return __('A 1-byte integer, signed range is -128 to 127, unsigned range is 0 to 255');
+
             case 'SMALLINT':
-                return __(
-                    'A 2-byte integer, signed range is -32,768 to 32,767, unsigned ' .
-                    'range is 0 to 65,535'
-                );
+                return __('A 2-byte integer, signed range is -32,768 to 32,767, unsigned range is 0 to 65,535');
+
             case 'MEDIUMINT':
                 return __(
-                    'A 3-byte integer, signed range is -8,388,608 to 8,388,607, ' .
-                    'unsigned range is 0 to 16,777,215'
+                    'A 3-byte integer, signed range is -8,388,608 to 8,388,607, unsigned range is 0 to 16,777,215'
                 );
+
             case 'INT':
                 return __(
                     'A 4-byte integer, signed range is ' .
                     '-2,147,483,648 to 2,147,483,647, unsigned range is 0 to ' .
                     '4,294,967,295'
                 );
+
             case 'BIGINT':
                 return __(
                     'An 8-byte integer, signed range is -9,223,372,036,854,775,808 ' .
                     'to 9,223,372,036,854,775,807, unsigned range is 0 to ' .
                     '18,446,744,073,709,551,615'
                 );
+
             case 'DECIMAL':
                 return __(
                     'A fixed-point number (M, D) - the maximum number of digits (M) ' .
                     'is 65 (default 10), the maximum number of decimals (D) is 30 ' .
                     '(default 0)'
                 );
+
             case 'FLOAT':
                 return __(
                     'A small floating-point number, allowable values are ' .
                     '-3.402823466E+38 to -1.175494351E-38, 0, and 1.175494351E-38 to ' .
                     '3.402823466E+38'
                 );
+
             case 'DOUBLE':
                 return __(
                     'A double-precision floating-point number, allowable values are ' .
                     '-1.7976931348623157E+308 to -2.2250738585072014E-308, 0, and ' .
                     '2.2250738585072014E-308 to 1.7976931348623157E+308'
                 );
+
             case 'REAL':
-                return __(
-                    'Synonym for DOUBLE (exception: in REAL_AS_FLOAT SQL mode it is ' .
-                    'a synonym for FLOAT)'
-                );
+                return __('Synonym for DOUBLE (exception: in REAL_AS_FLOAT SQL mode it is a synonym for FLOAT)');
+
             case 'BIT':
-                return __(
-                    'A bit-field type (M), storing M of bits per value (default is 1, ' .
-                    'maximum is 64)'
-                );
+                return __('A bit-field type (M), storing M of bits per value (default is 1, maximum is 64)');
+
             case 'BOOLEAN':
                 return __(
-                    'A synonym for TINYINT(1), a value of zero is considered false, ' .
-                    'nonzero values are considered true'
+                    'A synonym for TINYINT(1), a value of zero is considered false, nonzero values are considered true'
                 );
+
             case 'SERIAL':
                 return __('An alias for BIGINT UNSIGNED NOT NULL AUTO_INCREMENT UNIQUE');
+
             case 'DATE':
                 return sprintf(
                     __('A date, supported range is %1$s to %2$s'),
                     '1000-01-01',
                     '9999-12-31'
                 );
+
             case 'DATETIME':
                 return sprintf(
                     __('A date and time combination, supported range is %1$s to %2$s'),
                     '1000-01-01 00:00:00',
                     '9999-12-31 23:59:59'
                 );
+
             case 'TIMESTAMP':
                 return __(
                     'A timestamp, range is 1970-01-01 00:00:01 UTC to 2038-01-09 ' .
                     '03:14:07 UTC, stored as the number of seconds since the epoch ' .
                     '(1970-01-01 00:00:00 UTC)'
                 );
+
             case 'TIME':
                 return sprintf(
                     __('A time, range is %1$s to %2$s'),
                     '-838:59:59',
                     '838:59:59'
                 );
+
             case 'YEAR':
                 return __(
-                    "A year in four-digit (4, default) or two-digit (2) format, the " .
-                    "allowable values are 70 (1970) to 69 (2069) or 1901 to 2155 and " .
-                    "0000"
+                    'A year in four-digit (4, default) or two-digit (2) format, the ' .
+                    'allowable values are 70 (1970) to 69 (2069) or 1901 to 2155 and ' .
+                    '0000'
                 );
+
             case 'CHAR':
                 return __(
                     'A fixed-length (0-255, default 1) string that is always ' .
                     'right-padded with spaces to the specified length when stored'
                 );
+
             case 'VARCHAR':
                 return sprintf(
                     __(
-                        'A variable-length (%s) string, the effective maximum length ' .
-                        'is subject to the maximum row size'
+                        'A variable-length (%s) string, the effective maximum length is subject to the maximum row size'
                     ),
                     '0-65,535'
                 );
+
             case 'TINYTEXT':
                 return __(
                     'A TEXT column with a maximum length of 255 (2^8 - 1) characters, ' .
                     'stored with a one-byte prefix indicating the length of the value ' .
                     'in bytes'
                 );
+
             case 'TEXT':
                 return __(
                     'A TEXT column with a maximum length of 65,535 (2^16 - 1) ' .
                     'characters, stored with a two-byte prefix indicating the length ' .
                     'of the value in bytes'
                 );
+
             case 'MEDIUMTEXT':
                 return __(
                     'A TEXT column with a maximum length of 16,777,215 (2^24 - 1) ' .
                     'characters, stored with a three-byte prefix indicating the ' .
                     'length of the value in bytes'
                 );
+
             case 'LONGTEXT':
                 return __(
                     'A TEXT column with a maximum length of 4,294,967,295 or 4GiB ' .
                     '(2^32 - 1) characters, stored with a four-byte prefix indicating ' .
                     'the length of the value in bytes'
                 );
+
             case 'BINARY':
                 return __(
-                    'Similar to the CHAR type, but stores binary byte strings rather ' .
-                    'than non-binary character strings'
+                    'Similar to the CHAR type, but stores binary byte strings rather than non-binary character strings'
                 );
+
             case 'VARBINARY':
                 return __(
                     'Similar to the VARCHAR type, but stores binary byte strings ' .
                     'rather than non-binary character strings'
                 );
+
             case 'TINYBLOB':
                 return __(
                     'A BLOB column with a maximum length of 255 (2^8 - 1) bytes, ' .
                     'stored with a one-byte prefix indicating the length of the value'
                 );
+
             case 'MEDIUMBLOB':
                 return __(
                     'A BLOB column with a maximum length of 16,777,215 (2^24 - 1) ' .
                     'bytes, stored with a three-byte prefix indicating the length of ' .
                     'the value'
                 );
+
             case 'BLOB':
                 return __(
                     'A BLOB column with a maximum length of 65,535 (2^16 - 1) bytes, ' .
                     'stored with a two-byte prefix indicating the length of the value'
                 );
+
             case 'LONGBLOB':
                 return __(
                     'A BLOB column with a maximum length of 4,294,967,295 or 4GiB ' .
                     '(2^32 - 1) bytes, stored with a four-byte prefix indicating the ' .
                     'length of the value'
                 );
+
             case 'ENUM':
                 return __(
-                    "An enumeration, chosen from the list of up to 65,535 values or " .
-                    "the special '' error value"
+                    'An enumeration, chosen from the list of up to 65,535 values or the special \'\' error value'
                 );
+
             case 'SET':
-                return __("A single value chosen from a set of up to 64 members");
+                return __('A single value chosen from a set of up to 64 members');
+
             case 'GEOMETRY':
                 return __('A type that can store a geometry of any type');
+
             case 'POINT':
                 return __('A point in 2-dimensional space');
+
             case 'LINESTRING':
                 return __('A curve with linear interpolation between points');
+
             case 'POLYGON':
                 return __('A polygon');
+
             case 'MULTIPOINT':
                 return __('A collection of points');
+
             case 'MULTILINESTRING':
-                return __(
-                    'A collection of curves with linear interpolation between points'
-                );
+                return __('A collection of curves with linear interpolation between points');
+
             case 'MULTIPOLYGON':
                 return __('A collection of polygons');
+
             case 'GEOMETRYCOLLECTION':
                 return __('A collection of geometry objects of any type');
+
             case 'JSON':
-                return __(
-                    'Stores and enables efficient access to data in JSON'
-                    . ' (JavaScript Object Notation) documents'
-                );
+                return __('Stores and enables efficient access to data in JSON (JavaScript Object Notation) documents');
+
+            case 'INET6':
+                return __('Intended for storage of IPv6 addresses, as well as IPv4 '
+                    . 'addresses assuming conventional mapping of IPv4 addresses '
+                    . 'into IPv6 addresses');
+
+            case 'UUID':
+                return __('128-bit UUID (Universally Unique Identifier)');
         }
+
         return '';
     }
 
@@ -404,7 +455,6 @@ class Types
      * @param string $type The data type to get a class.
      *
      * @return string
-     *
      */
     public function getTypeClass($type)
     {
@@ -445,6 +495,7 @@ class Types
             case 'LONGBLOB':
             case 'ENUM':
             case 'SET':
+            case 'INET6':
                 return 'CHAR';
 
             case 'GEOMETRY':
@@ -459,6 +510,9 @@ class Types
 
             case 'JSON':
                 return 'JSON';
+
+            case 'UUID':
+                return 'UUID';
         }
 
         return '';
@@ -470,12 +524,11 @@ class Types
      * @param string $class The class to get function list.
      *
      * @return string[]
-     *
      */
     public function getFunctionsClass($class)
     {
-        $isMariaDB = $this->_dbi->isMariaDB();
-        $serverVersion = $this->_dbi->getVersion();
+        $isMariaDB = $this->dbi->isMariaDB();
+        $serverVersion = $this->dbi->getVersion();
 
         switch ($class) {
             case 'CHAR':
@@ -516,12 +569,11 @@ class Types
                     'VERSION',
                 ];
 
-                if (($isMariaDB && $serverVersion < 100012)
-                || $serverVersion < 50603
-                ) {
+                if (($isMariaDB && $serverVersion < 100012) || $serverVersion < 50603) {
                     $ret = array_diff($ret, ['INET6_NTOA']);
                 }
-                return $ret;
+
+                return array_values($ret);
 
             case 'DATE':
                 return [
@@ -597,12 +649,12 @@ class Types
                     'WEEKOFYEAR',
                     'YEARWEEK',
                 ];
-                if (($isMariaDB && $serverVersion < 100012)
-                || $serverVersion < 50603
-                ) {
+
+                if (($isMariaDB && $serverVersion < 100012) || $serverVersion < 50603) {
                     $ret = array_diff($ret, ['INET6_ATON']);
                 }
-                return $ret;
+
+                return array_values($ret);
 
             case 'SPATIAL':
                 if ($serverVersion >= 50600) {
@@ -626,29 +678,30 @@ class Types
                         'ST_PolyFromWKB',
                         'ST_MPolyFromWKB',
                     ];
-                } else {
-                    return [
-                        'GeomFromText',
-                        'GeomFromWKB',
-
-                        'GeomCollFromText',
-                        'LineFromText',
-                        'MLineFromText',
-                        'PointFromText',
-                        'MPointFromText',
-                        'PolyFromText',
-                        'MPolyFromText',
-
-                        'GeomCollFromWKB',
-                        'LineFromWKB',
-                        'MLineFromWKB',
-                        'PointFromWKB',
-                        'MPointFromWKB',
-                        'PolyFromWKB',
-                        'MPolyFromWKB',
-                    ];
                 }
+
+                return [
+                    'GeomFromText',
+                    'GeomFromWKB',
+
+                    'GeomCollFromText',
+                    'LineFromText',
+                    'MLineFromText',
+                    'PointFromText',
+                    'MPointFromText',
+                    'PolyFromText',
+                    'MPolyFromText',
+
+                    'GeomCollFromWKB',
+                    'LineFromWKB',
+                    'MLineFromWKB',
+                    'PointFromWKB',
+                    'MPointFromWKB',
+                    'PolyFromWKB',
+                    'MPolyFromWKB',
+                ];
         }
+
         return [];
     }
 
@@ -658,11 +711,11 @@ class Types
      * @param string $type The data type to get function list.
      *
      * @return string[]
-     *
      */
     public function getFunctions($type)
     {
         $class = $this->getTypeClass($type);
+
         return $this->getFunctionsClass($class);
     }
 
@@ -670,7 +723,6 @@ class Types
      * Returns array of all functions available.
      *
      * @return string[]
-     *
      */
     public function getAllFunctions()
     {
@@ -678,9 +730,10 @@ class Types
             $this->getFunctionsClass('CHAR'),
             $this->getFunctionsClass('NUMBER'),
             $this->getFunctionsClass('DATE'),
-            $this->getFunctionsClass('UUID')
+            $this->getFunctionsClass('SPATIAL')
         );
         sort($ret);
+
         return $ret;
     }
 
@@ -688,17 +741,24 @@ class Types
      * Returns array of all attributes available.
      *
      * @return string[]
-     *
      */
     public function getAttributes()
     {
-        return [
+        $serverVersion = $this->dbi->getVersion();
+
+        $attributes = [
             '',
             'BINARY',
             'UNSIGNED',
             'UNSIGNED ZEROFILL',
             'on update CURRENT_TIMESTAMP',
         ];
+
+        if (Compatibility::supportsCompressedColumns($serverVersion)) {
+            $attributes[] = 'COMPRESSED=zlib';
+        }
+
+        return $attributes;
     }
 
     /**
@@ -707,13 +767,13 @@ class Types
      * VARCHAR, TINYINT, TEXT and DATE are listed first, based on
      * estimated popularity.
      *
-     * @return string[]
-     *
+     * @return array
      */
-    public function getColumns()
+    public function getColumns(): array
     {
-        $isMariaDB = $this->_dbi->isMariaDB();
-        $serverVersion = $this->_dbi->getVersion();
+        $isMariaDB = $this->dbi->isMariaDB();
+        $serverVersion = $this->dbi->getVersion();
+        $isUUIDSupported = Compatibility::isUUIDSupported($this->dbi);
 
         // most used types
         $ret = [
@@ -722,6 +782,11 @@ class Types
             'TEXT',
             'DATE',
         ];
+
+        if ($isUUIDSupported) {
+            $ret[] = 'UUID';
+        }
+
         // numeric
         $ret[_pgettext('numeric types', 'Numeric')] = [
             'TINYINT',
@@ -750,7 +815,7 @@ class Types
         ];
 
         // Text
-        $ret[_pgettext('string types', 'String')] = [
+        $stringTypes = [
             'CHAR',
             'VARCHAR',
             '-',
@@ -770,6 +835,12 @@ class Types
             'ENUM',
             'SET',
         ];
+        if ($isMariaDB && $serverVersion >= 100500) {
+            $stringTypes[] = '-';
+            $stringTypes[] = 'INET6';
+        }
+
+        $ret[_pgettext('string types', 'String')] = $stringTypes;
 
         $ret[_pgettext('spatial types', 'Spatial')] = [
             'GEOMETRY',
@@ -782,11 +853,12 @@ class Types
             'GEOMETRYCOLLECTION',
         ];
 
-        if (($isMariaDB && $serverVersion > 100207)
-            || (! $isMariaDB && $serverVersion >= 50708)) {
-            $ret['JSON'] = [
-                'JSON',
-            ];
+        if (($isMariaDB && $serverVersion > 100207) || (! $isMariaDB && $serverVersion >= 50708)) {
+            $ret['JSON'] = ['JSON'];
+        }
+
+        if ($isUUIDSupported) {
+            $ret['UUID'] = ['UUID'];
         }
 
         return $ret;
@@ -811,20 +883,20 @@ class Types
     /**
      * Returns the min and max values of a given integer type
      *
-     * @param string  $type   integer type
-     * @param boolean $signed whether signed
+     * @param string $type   integer type
+     * @param bool   $signed whether signed
      *
      * @return string[] min and max values
      */
     public function getIntegerRange($type, $signed = true)
     {
-        static $min_max_data = [
+        $min_max_data = [
             'unsigned' => [
-                'tinyint'   => [
+                'tinyint' => [
                     '0',
                     '255',
                 ],
-                'smallint'  => [
+                'smallint' => [
                     '0',
                     '65535',
                 ],
@@ -832,21 +904,21 @@ class Types
                     '0',
                     '16777215',
                 ],
-                'int'       => [
+                'int' => [
                     '0',
                     '4294967295',
                 ],
-                'bigint'    => [
+                'bigint' => [
                     '0',
                     '18446744073709551615',
                 ],
             ],
             'signed' => [
-                'tinyint'   => [
+                'tinyint' => [
                     '-128',
                     '127',
                 ],
-                'smallint'  => [
+                'smallint' => [
                     '-32768',
                     '32767',
                 ],
@@ -854,11 +926,11 @@ class Types
                     '-8388608',
                     '8388607',
                 ],
-                'int'       => [
+                'int' => [
                     '-2147483648',
                     '2147483647',
                 ],
-                'bigint'    => [
+                'bigint' => [
                     '-9223372036854775808',
                     '9223372036854775807',
                 ],
@@ -867,7 +939,8 @@ class Types
         $relevantArray = $signed
             ? $min_max_data['signed']
             : $min_max_data['unsigned'];
-        return isset($relevantArray[$type]) ? $relevantArray[$type] : [
+
+        return $relevantArray[$type] ?? [
             '',
             '',
         ];
