@@ -1,7 +1,4 @@
 <?php
-/**
- * Tests for MySQL Charsets
- */
 
 declare(strict_types=1);
 
@@ -10,7 +7,7 @@ namespace PhpMyAdmin\Tests;
 use PhpMyAdmin\Charsets;
 
 /**
- * Tests for MySQL Charsets
+ * @covers \PhpMyAdmin\Charsets
  */
 class CharsetsTest extends AbstractTestCase
 {
@@ -38,18 +35,9 @@ class CharsetsTest extends AbstractTestCase
                 'Value',
             ]
         );
-        $this->dummyDbi->addResult(
-            'SHOW SESSION VARIABLES LIKE \'character_set_server\';',
-            false
-        );
-        $this->dummyDbi->addResult(
-            'SELECT @@character_set_server;',
-            false
-        );
-        $this->dummyDbi->addResult(
-            'SHOW SESSION VARIABLES LIKE \'character_set_server\';',
-            false
-        );
+        $this->dummyDbi->addResult('SHOW SESSION VARIABLES LIKE \'character_set_server\';', false);
+        $this->dummyDbi->addResult('SELECT @@character_set_server;', false);
+        $this->dummyDbi->addResult('SHOW SESSION VARIABLES LIKE \'character_set_server\';', false);
         $this->dummyDbi->addResult(
             'SELECT @@character_set_server;',
             [
@@ -57,22 +45,13 @@ class CharsetsTest extends AbstractTestCase
             ]
         );
 
-        $charset = Charsets::getServerCharset(
-            $GLOBALS['dbi'],
-            $GLOBALS['cfg']['Server']['DisableIS']
-        );
+        $charset = Charsets::getServerCharset($GLOBALS['dbi'], $GLOBALS['cfg']['Server']['DisableIS']);
         $this->assertSame('utf8', $charset->getName());
 
-        $charset = Charsets::getServerCharset(
-            $GLOBALS['dbi'],
-            $GLOBALS['cfg']['Server']['DisableIS']
-        );
+        $charset = Charsets::getServerCharset($GLOBALS['dbi'], $GLOBALS['cfg']['Server']['DisableIS']);
         $this->assertSame('Unknown', $charset->getName());
 
-        $charset = Charsets::getServerCharset(
-            $GLOBALS['dbi'],
-            $GLOBALS['cfg']['Server']['DisableIS']
-        );
+        $charset = Charsets::getServerCharset($GLOBALS['dbi'], $GLOBALS['cfg']['Server']['DisableIS']);
         $this->assertSame('utf8', $charset->getName());
 
         $this->assertAllQueriesConsumed();
