@@ -10,26 +10,28 @@ use PhpMyAdmin\Html\Generator;
 use PhpMyAdmin\Html\MySQLDocumentation;
 use PhpMyAdmin\Index;
 use PhpMyAdmin\Message;
-use PhpMyAdmin\Response;
 use PhpMyAdmin\Table;
+use PhpMyAdmin\Table\Indexes;
 use PhpMyAdmin\Template;
 use PhpMyAdmin\Tests\AbstractTestCase;
-use PhpMyAdmin\Tests\Stubs\Response as ResponseStub;
+use PhpMyAdmin\Tests\Stubs\ResponseRenderer as ResponseStub;
 use PhpMyAdmin\Url;
+use ReflectionMethod;
+
+use function __;
 use function sprintf;
 
+/**
+ * @covers \PhpMyAdmin\Controllers\Table\IndexesController
+ */
 class IndexesControllerTest extends AbstractTestCase
 {
     /**
      * Setup function for test cases
-     *
-     * @access protected
      */
     protected function setUp(): void
     {
         parent::setUp();
-        parent::defineVersionConstants();
-        parent::loadDefaultConfig();
         parent::setTheme();
 
         /**
@@ -42,7 +44,7 @@ class IndexesControllerTest extends AbstractTestCase
         $GLOBALS['PMA_PHP_SELF'] = 'index.php';
         $GLOBALS['cfg']['Server']['pmadb'] = '';
         $GLOBALS['cfg']['Server']['DisableIS'] = false;
-        $GLOBALS['url_params'] = [
+        $GLOBALS['urlParams'] = [
             'db' => 'db',
             'server' => 1,
         ];
@@ -77,54 +79,6 @@ class IndexesControllerTest extends AbstractTestCase
         //$_SESSION
     }
 
-    /**
-     * Tests for doSaveDataAction() method
-     */
-    public function testDoSaveDataAction(): void
-    {
-        $sql_query = 'ALTER TABLE `db`.`table` DROP PRIMARY KEY, ADD UNIQUE ;';
-
-        $table = $this->getMockBuilder(Table::class)
-            ->disableOriginalConstructor()
-            ->getMock();
-        $table->expects($this->any())->method('getSqlQueryForIndexCreateOrEdit')
-            ->will($this->returnValue($sql_query));
-
-        $GLOBALS['dbi']->expects($this->any())->method('getTable')
-            ->will($this->returnValue($table));
-
-        $response = new ResponseStub();
-        $index = new Index();
-
-        $ctrl = new IndexesController(
-            $response,
-            new Template(),
-            $GLOBALS['db'],
-            $GLOBALS['table'],
-            $GLOBALS['dbi']
-        );
-
-        // Preview SQL
-        $_POST['preview_sql'] = true;
-        $ctrl->doSaveData($index, false);
-        $jsonArray = $response->getJSONResult();
-        $this->assertArrayHasKey('sql_data', $jsonArray);
-        $this->assertStringContainsString(
-            $sql_query,
-            $jsonArray['sql_data']
-        );
-
-        // Alter success
-        $response->clear();
-        Response::getInstance()->setAjax(true);
-        unset($_POST['preview_sql']);
-        $ctrl->doSaveData($index, false);
-        $jsonArray = $response->getJSONResult();
-        $this->assertArrayHasKey('index_table', $jsonArray);
-        $this->assertArrayHasKey('message', $jsonArray);
-        Response::getInstance()->setAjax(false);
-    }
-
     /**
      * Tests for displayFormAction()
      */
@@ -145,18 +99,23 @@ class IndexesControllerTest extends AbstractTestCase
 
         $response = new ResponseStub();
         $index = new Index();
+        $template = new Template();
+
+        $method = new ReflectionMethod(IndexesController::class, 'displayForm');
+        $method->setAccessible(true);
 
         $ctrl = new IndexesController(
             $response,
-            new Template(),
+            $template,
             $GLOBALS['db'],
             $GLOBALS['table'],
-            $GLOBALS['dbi']
+            $GLOBALS['dbi'],
+            new Indexes($response, $template, $GLOBALS['dbi'])
         );
 
         $_POST['create_index'] = true;
         $_POST['added_fields'] = 3;
-        $ctrl->displayForm($index);
+        $method->invoke($ctrl, $index);
         $html = $response->getHTMLResult();
 
         //Url::getHiddenInputs
@@ -174,15 +133,11 @@ class IndexesControllerTest extends AbstractTestCase
         $doc_html = Generator::showHint(
             Message::notice(
                 __(
-                    '"PRIMARY" <b>must</b> be the name of'
-                    . ' and <b>only of</b> a primary key!'
+                    '"PRIMARY" <b>must</b> be the name of and <b>only of</b> a primary key!'
                 )
             )->getMessage()
         );
-        $this->assertStringContainsString(
-            $doc_html,
-            $html
-        );
+        $this->assertStringContainsString($doc_html, $html);
 
         $this->assertStringContainsString(
             MySQLDocumentation::show('ALTER_TABLE'),
@@ -195,13 +150,7 @@ class IndexesControllerTest extends AbstractTestCase
         );
 
         //$field_name & $field_type
-        $this->assertStringContainsString(
-            'field_name',
-            $html
-        );
-        $this->assertStringContainsString(
-            'field_type',
-            $html
-        );
+        $this->assertStringContainsString('field_name', $html);
+        $this->assertStringContainsString('field_type', $html);
     }
 }
