@@ -4,15 +4,20 @@ declare(strict_types=1);
 
 namespace PhpMyAdmin\Tests\Controllers\Table;
 
+use Generator;
+use PhpMyAdmin\ConfigStorage\Relation;
 use PhpMyAdmin\Controllers\Table\RelationController;
 use PhpMyAdmin\DatabaseInterface;
-use PhpMyAdmin\Relation;
 use PhpMyAdmin\Table;
 use PhpMyAdmin\Template;
 use PhpMyAdmin\Tests\AbstractTestCase;
-use PhpMyAdmin\Tests\Stubs\Response as ResponseStub;
+use PhpMyAdmin\Tests\Stubs\DummyResult;
+use PhpMyAdmin\Tests\Stubs\ResponseRenderer as ResponseStub;
 use stdClass;
 
+/**
+ * @covers \PhpMyAdmin\Controllers\Table\RelationController
+ */
 class RelationControllerTest extends AbstractTestCase
 {
     /** @var ResponseStub */
@@ -27,8 +32,6 @@ class RelationControllerTest extends AbstractTestCase
     protected function setUp(): void
     {
         parent::setUp();
-        parent::defineVersionConstants();
-        parent::loadDefaultConfig();
         parent::setTheme();
 
         $GLOBALS['server'] = 0;
@@ -94,16 +97,13 @@ class RelationControllerTest extends AbstractTestCase
             $this->template,
             $GLOBALS['db'],
             $GLOBALS['table'],
-            new Relation($GLOBALS['dbi'], $this->template),
+            new Relation($GLOBALS['dbi']),
             $GLOBALS['dbi']
         );
 
         $ctrl->getDropdownValueForTable();
         $json = $this->response->getJSONResult();
-        $this->assertEquals(
-            $viewColumns,
-            $json['columns']
-        );
+        $this->assertEquals($viewColumns, $json['columns']);
     }
 
     /**
@@ -132,16 +132,13 @@ class RelationControllerTest extends AbstractTestCase
             $this->template,
             $GLOBALS['db'],
             $GLOBALS['table'],
-            new Relation($GLOBALS['dbi'], $this->template),
+            new Relation($GLOBALS['dbi']),
             $GLOBALS['dbi']
         );
 
         $ctrl->getDropdownValueForTable();
         $json = $this->response->getJSONResult();
-        $this->assertEquals(
-            $indexedColumns,
-            $json['columns']
-        );
+        $this->assertEquals($indexedColumns, $json['columns']);
     }
 
     /**
@@ -151,32 +148,29 @@ class RelationControllerTest extends AbstractTestCase
      */
     public function testGetDropdownValueForDbActionOne(): void
     {
-        $GLOBALS['dbi']->expects($this->any())
-            ->method('fetchArray')
-            ->will(
-                $this->returnCallback(
-                    static function () {
-                        static $count = 0;
-                        if ($count == 0) {
-                            $count++;
+        $resultStub = $this->createMock(DummyResult::class);
 
-                            return [
-                                'Engine' => 'InnoDB',
-                                'Name' => 'table',
-                            ];
-                        }
+        $GLOBALS['dbi']->expects($this->exactly(1))
+            ->method('query')
+            ->will($this->returnValue($resultStub));
 
-                        return null;
-                    }
-                )
-            );
+        $resultStub->expects($this->any())
+            ->method('getIterator')
+            ->will($this->returnCallback(static function (): Generator {
+                yield from [
+                    [
+                        'Engine' => 'InnoDB',
+                        'Name' => 'table',
+                    ],
+                ];
+            }));
 
         $ctrl = new RelationController(
             $this->response,
             $this->template,
             $GLOBALS['db'],
             $GLOBALS['table'],
-            new Relation($GLOBALS['dbi'], $this->template),
+            new Relation($GLOBALS['dbi']),
             $GLOBALS['dbi']
         );
 
@@ -196,29 +190,22 @@ class RelationControllerTest extends AbstractTestCase
      */
     public function testGetDropdownValueForDbActionTwo(): void
     {
-        $GLOBALS['dbi']->expects($this->any())
-            ->method('fetchArray')
-            ->will(
-                $this->returnCallback(
-                    static function () {
-                        static $count = 0;
-                        if ($count == 0) {
-                            $count++;
+        $resultStub = $this->createMock(DummyResult::class);
 
-                            return ['table'];
-                        }
+        $GLOBALS['dbi']->expects($this->exactly(1))
+            ->method('query')
+            ->will($this->returnValue($resultStub));
 
-                        return null;
-                    }
-                )
-            );
+        $resultStub->expects($this->any())
+            ->method('fetchAllColumn')
+            ->will($this->returnValue(['table']));
 
         $ctrl = new RelationController(
             $this->response,
             $this->template,
             $GLOBALS['db'],
             $GLOBALS['table'],
-            new Relation($GLOBALS['dbi'], $this->template),
+            new Relation($GLOBALS['dbi']),
             $GLOBALS['dbi']
         );
 
