@@ -1,23 +1,21 @@
 <?php
-/**
- * Test for faked database access
- */
 
 declare(strict_types=1);
 
 namespace PhpMyAdmin\Tests;
 
+use PhpMyAdmin\ConfigStorage\Relation;
 use PhpMyAdmin\Database\DatabaseList;
 use PhpMyAdmin\DatabaseInterface;
+use PhpMyAdmin\Dbal\ResultInterface;
 use PhpMyAdmin\Query\Utilities;
-use PhpMyAdmin\Relation;
+use PhpMyAdmin\SqlParser\Context;
 use PhpMyAdmin\SystemDatabase;
-use PhpMyAdmin\Tests\Stubs\DbiDummy;
 use PhpMyAdmin\Utils\SessionCache;
 use stdClass;
 
 /**
- * Tests basic functionality of dummy dbi driver
+ * @covers \PhpMyAdmin\DatabaseInterface
  */
 class DatabaseInterfaceTest extends AbstractTestCase
 {
@@ -27,11 +25,20 @@ class DatabaseInterfaceTest extends AbstractTestCase
     protected function setUp(): void
     {
         parent::setUp();
-        parent::loadDefaultConfig();
-        parent::defineVersionConstants();
+        parent::setGlobalDbi();
         $GLOBALS['server'] = 0;
-        $extension = new DbiDummy();
-        $this->dbi = new DatabaseInterface($extension);
+    }
+
+    /**
+     * Tear down function for mockResponse method
+     */
+    protected function tearDown(): void
+    {
+        parent::tearDown();
+
+        unset($GLOBALS['lang']);
+        unset($GLOBALS['cfg']['Server']['SessionTimeZone']);
+        Context::load();
     }
 
     /**
@@ -47,7 +54,6 @@ class DatabaseInterfaceTest extends AbstractTestCase
     public function testGetCurrentUser($value, string $string, array $expected, bool $needsSecondCall): void
     {
         SessionCache::remove('mysql_cur_user');
-        parent::setGlobalDbi();
 
         $this->dummyDbi->addResult('SELECT CURRENT_USER();', $value);
         if ($needsSecondCall) {
@@ -110,34 +116,21 @@ class DatabaseInterfaceTest extends AbstractTestCase
      */
     public function testPMAGetColumnMap(): void
     {
-        $extension = $this->getMockBuilder(DbiDummy::class)
-            ->disableOriginalConstructor()
-            ->getMock();
-
-        $extension->expects($this->any())
-            ->method('realQuery')
-            ->will($this->returnValue(true));
-
-        $meta1 = new stdClass();
-        $meta1->table = 'meta1_table';
-        $meta1->name = 'meta1_name';
-
-        $meta2 = new stdClass();
-        $meta2->table = 'meta2_table';
-        $meta2->name = 'meta2_name';
-
-        $extension->expects($this->any())
-            ->method('getFieldsMeta')
-            ->will(
-                $this->returnValue(
-                    [
-                        $meta1,
-                        $meta2,
-                    ]
-                )
-            );
-
-        $dbi = new DatabaseInterface($extension);
+        $this->dummyDbi->addResult(
+            'PMA_sql_query',
+            [true],
+            [],
+            [
+                (object) [
+                    'table' => 'meta1_table',
+                    'name' => 'meta1_name',
+                ],
+                (object) [
+                    'table' => 'meta2_table',
+                    'name' => 'meta2_name',
+                ],
+            ]
+        );
 
         $sql_query = 'PMA_sql_query';
         $view_columns = [
@@ -145,10 +138,7 @@ class DatabaseInterfaceTest extends AbstractTestCase
             'view_columns2',
         ];
 
-        $column_map = $dbi->getColumnMapFromSql(
-            $sql_query,
-            $view_columns
-        );
+        $column_map = $this->dbi->getColumnMapFromSql($sql_query, $view_columns);
 
         $this->assertEquals(
             [
@@ -166,6 +156,8 @@ class DatabaseInterfaceTest extends AbstractTestCase
             ],
             $column_map[1]
         );
+
+        $this->assertAllQueriesConsumed();
     }
 
     /**
@@ -189,10 +181,97 @@ class DatabaseInterfaceTest extends AbstractTestCase
         );
         $GLOBALS['db'] = '';
         $GLOBALS['cfg']['Server']['only_db'] = [];
-        $this->dbi->postConnectControl();
+        $this->dbi->postConnectControl(new Relation($this->dbi));
         $this->assertInstanceOf(DatabaseList::class, $GLOBALS['dblist']);
     }
 
+    /**
+     * Tests for DBI::postConnect() method.
+     * should not call setVersion method if cannot fetch version
+     */
+    public function testPostConnectShouldNotCallSetVersionIfNoVersion(): void
+    {
+        $GLOBALS['lang'] = 'en';
+        $GLOBALS['cfg']['Server']['SessionTimeZone'] = '';
+
+        $mock = $this->getMockBuilder(DatabaseInterface::class)
+            ->disableOriginalConstructor()
+            ->onlyMethods(['fetchSingleRow', 'query', 'setVersion'])
+            ->getMock();
+
+        $mock->expects($this->once())
+            ->method('fetchSingleRow')
+            ->will($this->returnValue(null));
+
+        $mock->expects($this->never())->method('setVersion');
+
+        $mock->postConnect();
+    }
+
+    /**
+     * Tests for DBI::postConnect() method.
+     * should call setVersion method if $version has value
+     */
+    public function testPostConnectShouldCallSetVersionOnce(): void
+    {
+        $GLOBALS['lang'] = 'en';
+        $GLOBALS['cfg']['Server']['SessionTimeZone'] = '';
+        $versionQueryResult = [
+            '@@version' => '10.20.7-MariaDB-1:10.9.3+maria~ubu2204',
+            '@@version_comment' => 'mariadb.org binary distribution',
+        ];
+
+        $mock = $this->getMockBuilder(DatabaseInterface::class)
+            ->disableOriginalConstructor()
+            ->onlyMethods(['fetchSingleRow', 'query', 'setVersion'])
+            ->getMock();
+
+        $mock->expects($this->once())
+            ->method('fetchSingleRow')
+            ->will($this->returnValue($versionQueryResult));
+
+        $mock->expects($this->once())->method('setVersion')->with($versionQueryResult);
+
+        $mock->postConnect();
+    }
+
+    /**
+     * Tests for DBI::postConnect() method.
+     * should set version int, isMariaDB and isPercona
+     *
+     * @param array $version    Database version
+     * @param int   $versionInt Database version as integer
+     * @param bool  $isMariaDb  True if mariadb
+     * @param bool  $isPercona  True if percona
+     * @phpstan-param array<array-key, mixed> $version
+     *
+     * @dataProvider provideDatabaseVersionData
+     */
+    public function testPostConnectShouldSetVersion(
+        array $version,
+        int $versionInt,
+        bool $isMariaDb,
+        bool $isPercona
+    ): void {
+        $GLOBALS['lang'] = 'en';
+        $GLOBALS['cfg']['Server']['SessionTimeZone'] = '';
+
+        $mock = $this->getMockBuilder(DatabaseInterface::class)
+            ->disableOriginalConstructor()
+            ->onlyMethods(['fetchSingleRow', 'query'])
+            ->getMock();
+
+        $mock->expects($this->once())
+            ->method('fetchSingleRow')
+            ->will($this->returnValue($version));
+
+        $mock->postConnect();
+
+        $this->assertEquals($mock->getVersion(), $versionInt);
+        $this->assertEquals($mock->isMariaDB(), $isMariaDb);
+        $this->assertEquals($mock->isPercona(), $isPercona);
+    }
+
     /**
      * Test for getDbCollation
      */
@@ -288,7 +367,6 @@ class DatabaseInterfaceTest extends AbstractTestCase
     public function testIsAmazonRdsData(array $value, bool $expected): void
     {
         SessionCache::remove('is_amazon_rds');
-        parent::setGlobalDbi();
 
         $this->dummyDbi->addResult('SELECT @@basedir', $value);
 
@@ -376,486 +454,154 @@ class DatabaseInterfaceTest extends AbstractTestCase
     }
 
     /**
-     * Tests for DBI::setCollationl() method.
+     * Tests for DBI::setCollation() method.
      */
     public function testSetCollation(): void
     {
-        $extension = $this->getMockBuilder(DbiDummy::class)
-            ->disableOriginalConstructor()
-            ->getMock();
-        $extension->expects($this->any())->method('escapeString')
-            ->will($this->returnArgument(1));
-
-        $extension->expects($this->exactly(4))
-            ->method('realQuery')
-            ->withConsecutive(
-                ["SET collation_connection = 'utf8_czech_ci';"],
-                ["SET collation_connection = 'utf8mb4_bin_ci';"],
-                ["SET collation_connection = 'utf8_czech_ci';"],
-                ["SET collation_connection = 'utf8_bin_ci';"]
-            )
-            ->willReturnOnConsecutiveCalls(
-                true,
-                true,
-                true,
-                true
-            );
-
-        $dbi = new DatabaseInterface($extension);
+        $this->dummyDbi->addResult('SET collation_connection = \'utf8_czech_ci\';', [true]);
+        $this->dummyDbi->addResult('SET collation_connection = \'utf8mb4_bin_ci\';', [true]);
+        $this->dummyDbi->addResult('SET collation_connection = \'utf8_czech_ci\';', [true]);
+        $this->dummyDbi->addResult('SET collation_connection = \'utf8_bin_ci\';', [true]);
 
         $GLOBALS['charset_connection'] = 'utf8mb4';
-        $dbi->setCollation('utf8_czech_ci');
-        $dbi->setCollation('utf8mb4_bin_ci');
+        $this->dbi->setCollation('utf8_czech_ci');
+        $this->dbi->setCollation('utf8mb4_bin_ci');
         $GLOBALS['charset_connection'] = 'utf8';
-        $dbi->setCollation('utf8_czech_ci');
-        $dbi->setCollation('utf8mb4_bin_ci');
+        $this->dbi->setCollation('utf8_czech_ci');
+        $this->dbi->setCollation('utf8mb4_bin_ci');
+
+        $this->assertAllQueriesConsumed();
+    }
+
+    public function testGetTablesFull(): void
+    {
+        $GLOBALS['cfg']['Server']['DisableIS'] = true;
+
+        $expected = [
+            'test_table' => [
+                'Name' => 'test_table',
+                'Engine' => 'InnoDB',
+                'Version' => '10',
+                'Row_format' => 'Dynamic',
+                'Rows' => '3',
+                'Avg_row_length' => '5461',
+                'Data_length' => '16384',
+                'Max_data_length' => '0',
+                'Index_length' => '0',
+                'Data_free' => '0',
+                'Auto_increment' => '4',
+                'Create_time' => '2011-12-13 14:15:16',
+                'Update_time' => null,
+                'Check_time' => null,
+                'Collation' => 'utf8mb4_general_ci',
+                'Checksum' => null,
+                'Create_options' => '',
+                'Comment' => '',
+                'Max_index_length' => '0',
+                'Temporary' => 'N',
+                'Type' => 'InnoDB',
+                'TABLE_SCHEMA' => 'test_db',
+                'TABLE_NAME' => 'test_table',
+                'ENGINE' => 'InnoDB',
+                'VERSION' => '10',
+                'ROW_FORMAT' => 'Dynamic',
+                'TABLE_ROWS' => '3',
+                'AVG_ROW_LENGTH' => '5461',
+                'DATA_LENGTH' => '16384',
+                'MAX_DATA_LENGTH' => '0',
+                'INDEX_LENGTH' => '0',
+                'DATA_FREE' => '0',
+                'AUTO_INCREMENT' => '4',
+                'CREATE_TIME' => '2011-12-13 14:15:16',
+                'UPDATE_TIME' => null,
+                'CHECK_TIME' => null,
+                'TABLE_COLLATION' => 'utf8mb4_general_ci',
+                'CHECKSUM' => null,
+                'CREATE_OPTIONS' => '',
+                'TABLE_COMMENT' => '',
+                'TABLE_TYPE' => 'BASE TABLE',
+            ],
+        ];
+
+        $actual = $this->dbi->getTablesFull('test_db');
+        $this->assertEquals($expected, $actual);
+    }
+
+    public function testGetTablesFullWithInformationSchema(): void
+    {
+        $GLOBALS['cfg']['Server']['DisableIS'] = false;
+
+        $expected = [
+            'test_table' => [
+                'TABLE_CATALOG' => 'def',
+                'TABLE_SCHEMA' => 'test_db',
+                'TABLE_NAME' => 'test_table',
+                'TABLE_TYPE' => 'BASE TABLE',
+                'ENGINE' => 'InnoDB',
+                'VERSION' => '10',
+                'ROW_FORMAT' => 'Dynamic',
+                'TABLE_ROWS' => '3',
+                'AVG_ROW_LENGTH' => '5461',
+                'DATA_LENGTH' => '16384',
+                'MAX_DATA_LENGTH' => '0',
+                'INDEX_LENGTH' => '0',
+                'DATA_FREE' => '0',
+                'AUTO_INCREMENT' => '4',
+                'CREATE_TIME' => '2011-12-13 14:15:16',
+                'UPDATE_TIME' => null,
+                'CHECK_TIME' => null,
+                'TABLE_COLLATION' => 'utf8mb4_general_ci',
+                'CHECKSUM' => null,
+                'CREATE_OPTIONS' => '',
+                'TABLE_COMMENT' => '',
+                'MAX_INDEX_LENGTH' => '0',
+                'TEMPORARY' => 'N',
+                'Db' => 'test_db',
+                'Name' => 'test_table',
+                'Engine' => 'InnoDB',
+                'Type' => 'InnoDB',
+                'Version' => '10',
+                'Row_format' => 'Dynamic',
+                'Rows' => '3',
+                'Avg_row_length' => '5461',
+                'Data_length' => '16384',
+                'Max_data_length' => '0',
+                'Index_length' => '0',
+                'Data_free' => '0',
+                'Auto_increment' => '4',
+                'Create_time' => '2011-12-13 14:15:16',
+                'Update_time' => null,
+                'Check_time' => null,
+                'Collation' => 'utf8mb4_general_ci',
+                'Checksum' => null,
+                'Create_options' => '',
+                'Comment' => '',
+            ],
+        ];
+
+        $actual = $this->dbi->getTablesFull('test_db');
+        $this->assertEquals($expected, $actual);
     }
 
     /**
-     * Tests for DBI::getForeignKeyConstrains() method.
+     * Test for queryAsControlUser
      */
-    public function testGetForeignKeyConstrains(): void
+    public function testQueryAsControlUser(): void
     {
-        $this->assertEquals([
-            [
-                'TABLE_NAME' => 'table2',
-                'COLUMN_NAME' => 'idtable2',
-                'REFERENCED_TABLE_NAME' => 'table1',
-                'REFERENCED_COLUMN_NAME' => 'idtable1',
-            ],
-        ], $this->dbi->getForeignKeyConstrains('test', ['table1', 'table2']));
-    }
+        $sql = 'insert into PMA_bookmark A,B values(1, 2)';
+        $this->dummyDbi->addResult($sql, [true]);
+        $this->dummyDbi->addResult($sql, [true]);
+        $this->dummyDbi->addResult('Invalid query', false);
 
-    public function testInitRelationParamsCacheDefaultDbNameDbDoesNotExist(): void
-    {
-        parent::setGlobalDbi();
-
-        $GLOBALS['db'] = '';
-        $GLOBALS['server'] = 0;
-
-        $this->dummyDbi->removeDefaultResults();
-        $this->dummyDbi->addResult(
-            'SHOW TABLES FROM `phpmyadmin`;',
-            false
+        $this->assertInstanceOf(
+            ResultInterface::class,
+            $this->dbi->queryAsControlUser($sql)
         );
-
-        $this->dbi->initRelationParamsCache();
-
-        $this->assertAllQueriesConsumed();
-    }
-
-    public function testInitRelationParamsCacheDefaultDbNameDbExistsServerZero(): void
-    {
-        parent::setGlobalDbi();
-
-        $GLOBALS['db'] = '';
-        $GLOBALS['server'] = 0;
-
-        $this->dummyDbi->removeDefaultResults();
-        $this->dummyDbi->addResult(
-            'SHOW TABLES FROM `phpmyadmin`;',
-            [
-                ['pma__userconfig'],
-            ],
-            ['Tables_in_phpmyadmin']
+        $this->assertInstanceOf(
+            ResultInterface::class,
+            $this->dbi->tryQueryAsControlUser($sql)
         );
-
-        $this->dbi->initRelationParamsCache();
-
-        $this->assertArrayHasKey('relation', $_SESSION, 'The cache is expected to be filled');
-
-        // Should all be false for server = 0
-        $this->assertSame([
-            'PMA_VERSION' => $_SESSION['relation'][$GLOBALS['server']]['PMA_VERSION'],
-            'relwork' => false,
-            'displaywork' => false,
-            'bookmarkwork' => false,
-            'pdfwork' => false,
-            'commwork' => false,
-            'mimework' => false,
-            'historywork' => false,
-            'recentwork' => false,
-            'favoritework' => false,
-            'uiprefswork' => false,
-            'trackingwork' => false,
-            'userconfigwork' => false,
-            'menuswork' => false,
-            'navwork' => false,
-            'savedsearcheswork' => false,
-            'centralcolumnswork' => false,
-            'designersettingswork' => false,
-            'exporttemplateswork' => false,
-            'allworks' => false,
-            'user' => null,
-            'db' => null,
-        ], $_SESSION['relation'][$GLOBALS['server']]);
-
-        $this->assertSame([
-            'userconfig' => 'pma__userconfig',
-            'pmadb' => false,// This is the expected value for server = 0
-        ], $GLOBALS['cfg']['Server']);
-        $this->assertAllQueriesConsumed();
-    }
-
-    public function testInitRelationParamsCacheDefaultDbNameDbExistsFirstServer(): void
-    {
-        parent::setGlobalDbi();
-
-        $GLOBALS['db'] = '';
-        $GLOBALS['server'] = 1;
-        $GLOBALS['cfg']['Server']['user'] = '';
-        $GLOBALS['cfg']['Server']['pmadb'] = '';
-        $GLOBALS['cfg']['Server']['bookmarktable'] = '';
-        $GLOBALS['cfg']['Server']['relation'] = '';
-        $GLOBALS['cfg']['Server']['table_info'] = '';
-        $GLOBALS['cfg']['Server']['table_coords'] = '';
-        $GLOBALS['cfg']['Server']['column_info'] = '';
-        $GLOBALS['cfg']['Server']['pdf_pages'] = '';
-        $GLOBALS['cfg']['Server']['history'] = '';
-        $GLOBALS['cfg']['Server']['recent'] = '';
-        $GLOBALS['cfg']['Server']['favorite'] = '';
-        $GLOBALS['cfg']['Server']['table_uiprefs'] = '';
-        $GLOBALS['cfg']['Server']['tracking'] = '';
-        $GLOBALS['cfg']['Server']['userconfig'] = '';
-        $GLOBALS['cfg']['Server']['users'] = '';
-        $GLOBALS['cfg']['Server']['usergroups'] = '';
-        $GLOBALS['cfg']['Server']['navigationhiding'] = '';
-        $GLOBALS['cfg']['Server']['savedsearches'] = '';
-        $GLOBALS['cfg']['Server']['central_columns'] = '';
-        $GLOBALS['cfg']['Server']['designer_settings'] = '';
-        $GLOBALS['cfg']['Server']['export_templates'] = '';
-
-        $this->dummyDbi->removeDefaultResults();
-        $this->dummyDbi->addResult(
-            'SHOW TABLES FROM `phpmyadmin`;',
-            [
-                ['pma__userconfig'],
-            ],
-            ['Tables_in_phpmyadmin']
-        );
-
-        $this->dummyDbi->addResult(
-            'SHOW TABLES FROM `phpmyadmin`',
-            [
-                ['pma__userconfig'],
-            ],
-            ['Tables_in_phpmyadmin']
-        );
-
-        $this->dummyDbi->addResult(
-            'SELECT NULL FROM `pma__userconfig` LIMIT 0',
-            [
-                ['NULL'],
-            ],
-            ['NULL']
-        );
-
-        $this->dbi->initRelationParamsCache();
-
-        $this->assertArrayHasKey('relation', $_SESSION, 'The cache is expected to be filled');
-
-        // Should all be false for server = 0
-        $this->assertSame([
-            'PMA_VERSION' => $_SESSION['relation'][$GLOBALS['server']]['PMA_VERSION'],
-            'relwork' => false,
-            'displaywork' => false,
-            'bookmarkwork' => false,
-            'pdfwork' => false,
-            'commwork' => false,
-            'mimework' => false,
-            'historywork' => false,
-            'recentwork' => false,
-            'favoritework' => false,
-            'uiprefswork' => false,
-            'trackingwork' => false,
-            'userconfigwork' => true,
-            'menuswork' => false,
-            'navwork' => false,
-            'savedsearcheswork' => false,
-            'centralcolumnswork' => false,
-            'designersettingswork' => false,
-            'exporttemplateswork' => false,
-            'allworks' => false,
-            'user' => '',
-            'db' => 'phpmyadmin',
-            'userconfig' => 'pma__userconfig',
-        ], $_SESSION['relation'][$GLOBALS['server']]);
-
-        $this->assertSame([
-            'user' => '',
-            'pmadb' => 'phpmyadmin',
-            'bookmarktable' => '',
-            'relation' => '',
-            'table_info' => '',
-            'table_coords' => '',
-            'column_info' => '',
-            'pdf_pages' => '',
-            'history' => '',
-            'recent' => '',
-            'favorite' => '',
-            'table_uiprefs' => '',
-            'tracking' => '',
-            'userconfig' => 'pma__userconfig',
-            'users' => '',
-            'usergroups' => '',
-            'navigationhiding' => '',
-            'savedsearches' => '',
-            'central_columns' => '',
-            'designer_settings' => '',
-            'export_templates' => '',
-        ], $GLOBALS['cfg']['Server']);
-
-        $this->assertAllQueriesConsumed();
-    }
-
-    public function testInitRelationParamsCacheDefaultDbNameDbExistsFirstServerNotWorkingTable(): void
-    {
-        parent::setGlobalDbi();
-
-        $GLOBALS['db'] = '';
-        $GLOBALS['server'] = 1;
-        $GLOBALS['cfg']['Server']['user'] = '';
-        $GLOBALS['cfg']['Server']['pmadb'] = '';
-        $GLOBALS['cfg']['Server']['bookmarktable'] = '';
-        $GLOBALS['cfg']['Server']['relation'] = '';
-        $GLOBALS['cfg']['Server']['table_info'] = '';
-        $GLOBALS['cfg']['Server']['table_coords'] = '';
-        $GLOBALS['cfg']['Server']['column_info'] = '';
-        $GLOBALS['cfg']['Server']['pdf_pages'] = '';
-        $GLOBALS['cfg']['Server']['history'] = '';
-        $GLOBALS['cfg']['Server']['recent'] = '';
-        $GLOBALS['cfg']['Server']['favorite'] = '';
-        $GLOBALS['cfg']['Server']['table_uiprefs'] = '';
-        $GLOBALS['cfg']['Server']['tracking'] = '';
-        $GLOBALS['cfg']['Server']['userconfig'] = '';
-        $GLOBALS['cfg']['Server']['users'] = '';
-        $GLOBALS['cfg']['Server']['usergroups'] = '';
-        $GLOBALS['cfg']['Server']['navigationhiding'] = '';
-        $GLOBALS['cfg']['Server']['savedsearches'] = '';
-        $GLOBALS['cfg']['Server']['central_columns'] = '';
-        $GLOBALS['cfg']['Server']['designer_settings'] = '';
-        $GLOBALS['cfg']['Server']['export_templates'] = '';
-
-        $this->dummyDbi->removeDefaultResults();
-        $this->dummyDbi->addResult(
-            'SHOW TABLES FROM `phpmyadmin`;',
-            [
-                ['pma__userconfig'],
-            ],
-            ['Tables_in_phpmyadmin']
-        );
-
-        $this->dummyDbi->addResult(
-            'SHOW TABLES FROM `phpmyadmin`',
-            [
-                ['pma__userconfig'],
-            ],
-            ['Tables_in_phpmyadmin']
-        );
-
-        $this->dummyDbi->addResult(
-            'SELECT NULL FROM `pma__userconfig` LIMIT 0',
-            false
-        );
-
-        $this->dbi->initRelationParamsCache();
-
-        $this->assertArrayHasKey('relation', $_SESSION, 'The cache is expected to be filled');
-
-        $this->assertSame([
-            'PMA_VERSION' => $_SESSION['relation'][$GLOBALS['server']]['PMA_VERSION'],
-            'relwork' => false,
-            'displaywork' => false,
-            'bookmarkwork' => false,
-            'pdfwork' => false,
-            'commwork' => false,
-            'mimework' => false,
-            'historywork' => false,
-            'recentwork' => false,
-            'favoritework' => false,
-            'uiprefswork' => false,
-            'trackingwork' => false,
-            'userconfigwork' => false,// Expected value for not working table
-            'menuswork' => false,
-            'navwork' => false,
-            'savedsearcheswork' => false,
-            'centralcolumnswork' => false,
-            'designersettingswork' => false,
-            'exporttemplateswork' => false,
-            'allworks' => false,
-            'user' => '',
-            'db' => 'phpmyadmin',
-            'userconfig' => 'pma__userconfig',
-        ], $_SESSION['relation'][$GLOBALS['server']]);
-
-        $this->assertSame([
-            'user' => '',
-            'pmadb' => 'phpmyadmin',
-            'bookmarktable' => '',
-            'relation' => '',
-            'table_info' => '',
-            'table_coords' => '',
-            'column_info' => '',
-            'pdf_pages' => '',
-            'history' => '',
-            'recent' => '',
-            'favorite' => '',
-            'table_uiprefs' => '',
-            'tracking' => '',
-            'userconfig' => 'pma__userconfig',
-            'users' => '',
-            'usergroups' => '',
-            'navigationhiding' => '',
-            'savedsearches' => '',
-            'central_columns' => '',
-            'designer_settings' => '',
-            'export_templates' => '',
-        ], $GLOBALS['cfg']['Server']);
-
-        $this->assertAllQueriesConsumed();
-    }
-
-    public function testInitRelationParamsCacheDefaultDbNameDbExistsFirstServerOverride(): void
-    {
-        parent::setGlobalDbi();
-
-        $GLOBALS['db'] = '';
-        $GLOBALS['server'] = 1;
-        $GLOBALS['cfg']['Server']['user'] = '';
-        $GLOBALS['cfg']['Server']['pmadb'] = 'PMA-storage';
-        $GLOBALS['cfg']['Server']['bookmarktable'] = '';
-        $GLOBALS['cfg']['Server']['relation'] = '';
-        $GLOBALS['cfg']['Server']['table_info'] = '';
-        $GLOBALS['cfg']['Server']['table_coords'] = '';
-        $GLOBALS['cfg']['Server']['column_info'] = '';
-        $GLOBALS['cfg']['Server']['pdf_pages'] = '';
-        $GLOBALS['cfg']['Server']['history'] = '';
-        $GLOBALS['cfg']['Server']['recent'] = '';
-        $GLOBALS['cfg']['Server']['favorite'] = '';
-        $GLOBALS['cfg']['Server']['table_uiprefs'] = '';
-        $GLOBALS['cfg']['Server']['tracking'] = '';
-        $GLOBALS['cfg']['Server']['userconfig'] = 'pma__userconfig_custom';
-        $GLOBALS['cfg']['Server']['users'] = '';
-        $GLOBALS['cfg']['Server']['usergroups'] = '';
-        $GLOBALS['cfg']['Server']['navigationhiding'] = '';
-        $GLOBALS['cfg']['Server']['savedsearches'] = '';
-        $GLOBALS['cfg']['Server']['central_columns'] = '';
-        $GLOBALS['cfg']['Server']['designer_settings'] = '';
-        $GLOBALS['cfg']['Server']['export_templates'] = '';
-
-        $this->dummyDbi->removeDefaultResults();
-        $this->dummyDbi->addResult(
-            'SHOW TABLES FROM `PMA-storage`;',
-            [
-                [
-                    'pma__userconfig_custom',
-                    'pma__usergroups',
-                ],
-            ],
-            ['Tables_in_PMA-storage']
-        );
-
-        $this->dummyDbi->addResult(
-            'SHOW TABLES FROM `PMA-storage`',
-            [
-                [
-                    'pma__userconfig_custom',
-                    'pma__usergroups',
-                ],
-            ],
-            ['Tables_in_PMA-storage']
-        );
-
-        $this->dummyDbi->addResult(
-            'SELECT NULL FROM `pma__userconfig_custom` LIMIT 0',
-            [
-                ['NULL'],
-            ],
-            ['NULL']
-        );
-
-        $this->dbi->initRelationParamsCache();
-
-        $this->assertArrayHasKey(
-            'relation',
-            $_SESSION,
-            'The cache is expected to be filled because the custom override'
-            . 'was undertood (pma__userconfig vs pma__userconfig_custom)'
-        );
-
-        $this->assertAllQueriesConsumed();
-
-        $this->dummyDbi->addResult(
-            'SHOW TABLES FROM `PMA-storage`',
-            [
-                [
-                    'pma__userconfig_custom',
-                    'pma__usergroups',
-                ],
-            ],
-            ['Tables_in_PMA-storage']
-        );
-
-        $this->dummyDbi->addResult(
-            'SELECT NULL FROM `pma__userconfig_custom` LIMIT 0',
-            [
-                ['NULL'],
-            ],
-            ['NULL']
-        );
-
-        $relationData = (new Relation($this->dbi))->checkRelationsParam();
-        $this->assertSame([
-            'PMA_VERSION' => $relationData['PMA_VERSION'],
-            'relwork' => false,
-            'displaywork' => false,
-            'bookmarkwork' => false,
-            'pdfwork' => false,
-            'commwork' => false,
-            'mimework' => false,
-            'historywork' => false,
-            'recentwork' => false,
-            'favoritework' => false,
-            'uiprefswork' => false,
-            'trackingwork' => false,
-            'userconfigwork' => true,
-            'menuswork' => false,
-            'navwork' => false,
-            'savedsearcheswork' => false,
-            'centralcolumnswork' => false,
-            'designersettingswork' => false,
-            'exporttemplateswork' => false,
-            'allworks' => false,
-            'user' => '',
-            'db' => 'PMA-storage',
-            'userconfig' => 'pma__userconfig_custom',
-        ], $relationData);
-
-        $this->assertSame([
-            'user' => '',
-            'pmadb' => 'PMA-storage',
-            'bookmarktable' => '',
-            'relation' => '',
-            'table_info' => '',
-            'table_coords' => '',
-            'column_info' => '',
-            'pdf_pages' => '',
-            'history' => '',
-            'recent' => '',
-            'favorite' => '',
-            'table_uiprefs' => '',
-            'tracking' => '',
-            'userconfig' => 'pma__userconfig_custom',
-            'users' => '',
-            'usergroups' => '',
-            'navigationhiding' => '',
-            'savedsearches' => '',
-            'central_columns' => '',
-            'designer_settings' => '',
-            'export_templates' => '',
-        ], $GLOBALS['cfg']['Server']);
-
-        $this->assertAllQueriesConsumed();
+        $this->assertFalse($this->dbi->tryQueryAsControlUser('Invalid query'));
     }
 
     public function testGetDatabasesFullDisabledISAndSortIntColumn(): void
@@ -1014,6 +760,10 @@ class DatabaseInterfaceTest extends AbstractTestCase
                 'Comment',
             ]
         );
+        $this->dummyDbi->addSelectDb('');
+        $this->dummyDbi->addSelectDb('');
+        $this->dummyDbi->addSelectDb('db1');
+        $this->dummyDbi->addSelectDb('db2');
 
         $databaseList = $this->dbi->getDatabasesFull(
             null,
@@ -1052,4 +802,77 @@ class DatabaseInterfaceTest extends AbstractTestCase
 
         $this->assertAllQueriesConsumed();
     }
+
+    /**
+     * Tests for setVersion method.
+     *
+     * @param array $version    Database version
+     * @param int   $versionInt Database version as integer
+     * @param bool  $isMariaDb  True if mariadb
+     * @param bool  $isPercona  True if percona
+     * @phpstan-param array<array-key, mixed> $version
+     *
+     * @dataProvider provideDatabaseVersionData
+     */
+    public function testSetVersion(
+        array $version,
+        int $versionInt,
+        bool $isMariaDb,
+        bool $isPercona
+    ): void {
+        $this->dbi->setVersion($version);
+
+        $this->assertEquals($versionInt, $this->dbi->getVersion());
+        $this->assertEquals($isMariaDb, $this->dbi->isMariaDB());
+        $this->assertEquals($isPercona, $this->dbi->isPercona());
+        $this->assertEquals($version['@@version'], $this->dbi->getVersionString());
+    }
+
+    /**
+     * Data provider for setVersion() tests.
+     *
+     * @return array
+     * @psalm-return array<int, array{array<array-key, mixed>, int, bool, bool}>
+     */
+    public function provideDatabaseVersionData(): array
+    {
+        return [
+            [
+                [
+                    '@@version' => '6.1.0',
+                    '@@version_comment' => "Percona Server (GPL), Release '11', Revision 'c1y2gr1df4a'",
+                ],
+                60100,
+                false,
+                true,
+            ],
+            [
+                [
+                    '@@version' => '10.01.40-MariaDB-1:10.01.40+maria~ubu2204',
+                    '@@version_comment' => 'mariadb.org binary distribution',
+                ],
+                100140,
+                true,
+                false,
+            ],
+            [
+                [
+                    '@@version' => '7.10.3',
+                    '@@version_comment' => 'MySQL Community Server (GPL)',
+                ],
+                71003,
+                false,
+                false,
+            ],
+            [
+                [
+                    '@@version' => '5.5.0',
+                    '@@version_comment' => '',
+                ],
+                50500,
+                false,
+                false,
+            ],
+        ];
+    }
 }
