@@ -1,37 +1,27 @@
 <?php
-/**
- * Tests for PMA_StorageEngine_memory
- *
- * @package PhpMyAdmin-test
- */
+
 declare(strict_types=1);
 
 namespace PhpMyAdmin\Tests\Engines;
 
 use PhpMyAdmin\Engines\Memory;
-use PhpMyAdmin\Tests\PmaTestCase;
+use PhpMyAdmin\Tests\AbstractTestCase;
 
 /**
- * Tests for PhpMyAdmin\Engines\Memory
- *
- * @package PhpMyAdmin-test
+ * @covers \PhpMyAdmin\Engines\Memory
  */
-class MemoryTest extends PmaTestCase
+class MemoryTest extends AbstractTestCase
 {
-    /**
-     * @access protected
-     */
+    /** @var Memory */
     protected $object;
 
     /**
      * Sets up the fixture, for example, opens a network connection.
      * This method is called before a test is executed.
-     *
-     * @access protected
-     * @return void
      */
     protected function setUp(): void
     {
+        parent::setUp();
         $GLOBALS['server'] = 0;
         $this->object = new Memory('memory');
     }
@@ -39,28 +29,22 @@ class MemoryTest extends PmaTestCase
     /**
      * Tears down the fixture, for example, closes a network connection.
      * This method is called after a test is executed.
-     *
-     * @access protected
-     * @return void
      */
     protected function tearDown(): void
     {
+        parent::tearDown();
         unset($this->object);
     }
 
     /**
      * Test for getVariables
-     *
-     * @return void
      */
-    public function testGetVariables()
+    public function testGetVariables(): void
     {
         $this->assertEquals(
             $this->object->getVariables(),
             [
-                'max_heap_table_size' => [
-                    'type'  => 1,
-                ],
+                'max_heap_table_size' => ['type' => 1],
             ]
         );
     }
