@@ -5,24 +5,22 @@ declare(strict_types=1);
 namespace PhpMyAdmin\Tests\Gis;
 
 use PhpMyAdmin\Gis\GisPolygon;
+use PhpMyAdmin\Image\ImageWrapper;
 use TCPDF;
-use function function_exists;
-use function imagecreatetruecolor;
+
 use function preg_match;
 
+/**
+ * @covers \PhpMyAdmin\Gis\GisPolygon
+ */
 class GisPolygonTest extends GisGeomTestCase
 {
-    /**
-     * @var    GisPolygon
-     * @access protected
-     */
+    /** @var    GisPolygon */
     protected $object;
 
     /**
      * Sets up the fixture, for example, opens a network connection.
      * This method is called before a test is executed.
-     *
-     * @access protected
      */
     protected function setUp(): void
     {
@@ -33,8 +31,6 @@ class GisPolygonTest extends GisGeomTestCase
     /**
      * Tears down the fixture, for example, closes a network connection.
      * This method is called after a test is executed.
-     *
-     * @access protected
      */
     protected function tearDown(): void
     {
@@ -177,8 +173,7 @@ class GisPolygonTest extends GisGeomTestCase
 
         return [
             [
-                "'POLYGON((35 10,10 20,15 40,45 45,35 10),"
-                    . "(20 30,35 32,30 20,20 30))',124",
+                '\'POLYGON((35 10,10 20,15 40,45 45,35 10),(20 30,35 32,30 20,20 30))\',124',
                 null,
                 [
                     'srid' => '124',
@@ -366,13 +361,9 @@ class GisPolygonTest extends GisGeomTestCase
      */
     public function testGetPointOnSurface(array $ring): void
     {
-        $this->assertEquals(
-            $this->object->isPointInsidePolygon(
-                $this->object->getPointOnSurface($ring),
-                $ring
-            ),
-            true
-        );
+        $point = $this->object->getPointOnSurface($ring);
+        $this->assertIsArray($point);
+        $this->assertTrue($this->object->isPointInsidePolygon($point, $ring));
     }
 
     /**
@@ -414,8 +405,7 @@ class GisPolygonTest extends GisGeomTestCase
                 ],
             ],
             [
-                'POLYGON((35 10,10 20,15 40,45 45,35 10),'
-                    . '(20 30,35 32,30 20,20 30)))',
+                'POLYGON((35 10,10 20,15 40,45 45,35 10),(20 30,35 32,30 20,20 30)))',
                 [
                     'minX' => 10,
                     'maxX' => 45,
@@ -427,58 +417,21 @@ class GisPolygonTest extends GisGeomTestCase
     }
 
     /**
-     * test case for prepareRowAsPng()
-     *
-     * @param string   $spatial    GIS POLYGON object
-     * @param string   $label      label for the GIS POLYGON object
-     * @param string   $fill_color color for the GIS POLYGON object
-     * @param array    $scale_data array containing data related to scaling
-     * @param resource $image      image object
-     *
-     * @dataProvider providerForPrepareRowAsPng
+     * @requires extension gd
      */
-    public function testPrepareRowAsPng(
-        string $spatial,
-        string $label,
-        string $fill_color,
-        array $scale_data,
-        $image
-    ): void {
+    public function testPrepareRowAsPng(): void
+    {
+        $image = ImageWrapper::create(120, 150);
+        $this->assertNotNull($image);
         $return = $this->object->prepareRowAsPng(
-            $spatial,
-            $label,
-            $fill_color,
-            $scale_data,
+            'POLYGON((123 0,23 30,17 63,123 0))',
+            'image',
+            '#B02EE0',
+            ['x' => 12, 'y' => 69, 'scale' => 2, 'height' => 150],
             $image
         );
-        $this->assertImage($return);
-    }
-
-    /**
-     * data provider for testPrepareRowAsPng() test case
-     *
-     * @return array test data for testPrepareRowAsPng() test case
-     */
-    public function providerForPrepareRowAsPng(): array
-    {
-        if (! function_exists('imagecreatetruecolor')) {
-            $this->markTestSkipped('GD extension missing!');
-        }
-
-        return [
-            [
-                'POLYGON((123 0,23 30,17 63,123 0))',
-                'image',
-                '#B02EE0',
-                [
-                    'x' => 12,
-                    'y' => 69,
-                    'scale' => 2,
-                    'height' => 150,
-                ],
-                imagecreatetruecolor(120, 150),
-            ],
-        ];
+        $this->assertEquals(120, $return->width());
+        $this->assertEquals(150, $return->height());
     }
 
     /**
@@ -499,14 +452,8 @@ class GisPolygonTest extends GisGeomTestCase
         array $scale_data,
         TCPDF $pdf
     ): void {
-        $return = $this->object->prepareRowAsPdf(
-            $spatial,
-            $label,
-            $fill_color,
-            $scale_data,
-            $pdf
-        );
-        $this->assertInstanceOf('TCPDF', $return);
+        $return = $this->object->prepareRowAsPdf($spatial, $label, $fill_color, $scale_data, $pdf);
+        $this->assertInstanceOf(TCPDF::class, $return);
     }
 
     /**
@@ -550,12 +497,7 @@ class GisPolygonTest extends GisGeomTestCase
         array $scaleData,
         string $output
     ): void {
-        $string = $this->object->prepareRowAsSvg(
-            $spatial,
-            $label,
-            $fillColor,
-            $scaleData
-        );
+        $string = $this->object->prepareRowAsSvg($spatial, $label, $fillColor, $scaleData);
         $this->assertEquals(1, preg_match($output, $string));
     }
 
