@@ -5,10 +5,17 @@ declare(strict_types=1);
 namespace PhpMyAdmin\Tests;
 
 use PhpMyAdmin\LanguageManager;
+
+use function _ngettext;
 use function count;
+use function file_exists;
 use function is_readable;
 use function strtolower;
 
+/**
+ * @covers \PhpMyAdmin\Language
+ * @covers \PhpMyAdmin\LanguageManager
+ */
 class LanguageTest extends AbstractTestCase
 {
     /** @var LanguageManager */
@@ -24,6 +31,7 @@ class LanguageTest extends AbstractTestCase
         if (! is_readable($loc)) {
             $this->markTestSkipped('Missing compiled locales.');
         }
+
         $this->manager = new LanguageManager();
     }
 
@@ -31,7 +39,12 @@ class LanguageTest extends AbstractTestCase
     {
         parent::tearDown();
         // Ensure we have English locale after tests
-        $this->manager->getLanguage('en')->activate();
+        $lang = $this->manager->getLanguage('en');
+        if ($lang === false) {
+            return;
+        }
+
+        $lang->activate();
     }
 
     /**
@@ -39,13 +52,13 @@ class LanguageTest extends AbstractTestCase
      */
     public function testAvailable(): void
     {
-        $GLOBALS['PMA_Config']->set('FilterLanguages', 'cs|en$');
+        $GLOBALS['config']->set('FilterLanguages', 'cs|en$');
 
         $langs = $this->manager->availableLocales();
 
         $this->assertCount(2, $langs);
         $this->assertContains('cs', $langs);
-        $GLOBALS['PMA_Config']->set('FilterLanguages', '');
+        $GLOBALS['config']->set('FilterLanguages', '');
     }
 
     /**
@@ -53,7 +66,7 @@ class LanguageTest extends AbstractTestCase
      */
     public function testAllAvailable(): void
     {
-        $GLOBALS['PMA_Config']->set('FilterLanguages', '');
+        $GLOBALS['config']->set('FilterLanguages', '');
 
         $langs = $this->manager->availableLocales();
 
@@ -95,7 +108,7 @@ class LanguageTest extends AbstractTestCase
      */
     public function testMySQLLocale(): void
     {
-        $GLOBALS['PMA_Config']->set('FilterLanguages', '');
+        $GLOBALS['config']->set('FilterLanguages', '');
         $czech = $this->manager->getLanguage('cs');
         $this->assertNotFalse($czech);
         $this->assertEquals('cs_CZ', $czech->getMySQLLocale());
@@ -119,9 +132,9 @@ class LanguageTest extends AbstractTestCase
      */
     public function testGet(): void
     {
-        $GLOBALS['PMA_Config']->set('FilterLanguages', '');
+        $GLOBALS['config']->set('FilterLanguages', '');
         $lang = $this->manager->getLanguage('cs');
-        $this->assertNotEquals(false, $lang);
+        $this->assertNotFalse($lang);
         $this->assertEquals('Czech', $lang->getEnglishName());
         $this->assertEquals('Čeština', $lang->getNativeName());
         $lang = $this->manager->getLanguage('nonexisting');
@@ -138,7 +151,7 @@ class LanguageTest extends AbstractTestCase
      * @param string $accept  Value for HTTP Accept-Language header
      * @param string $agent   Value for HTTP User-Agent header
      * @param string $default Value for default language
-     * @param string $expect  Expected language name
+     * @param string $expect  Expected language code
      *
      * @dataProvider selectDataProvider
      */
@@ -152,127 +165,64 @@ class LanguageTest extends AbstractTestCase
         string $default,
         string $expect
     ): void {
-        $GLOBALS['PMA_Config']->set('FilterLanguages', '');
-        $GLOBALS['PMA_Config']->set('Lang', $lang);
-        $GLOBALS['PMA_Config']->set('is_https', false);
+        if ($expect !== 'en' && ! file_exists(LOCALE_PATH . '/' . $expect . '/LC_MESSAGES/phpmyadmin.mo')) {
+            // This could happen after removing incomplete .mo files.
+            $this->markTestSkipped('Locale file does not exists: ' . $expect);
+        }
+
+        $GLOBALS['config']->set('FilterLanguages', '');
+        $GLOBALS['config']->set('Lang', $lang);
+        $GLOBALS['config']->set('is_https', false);
         $_POST['lang'] = $post;
         $_GET['lang'] = $get;
         $_COOKIE['pma_lang'] = $cookie;
         $_SERVER['HTTP_ACCEPT_LANGUAGE'] = $accept;
         $_SERVER['HTTP_USER_AGENT'] = $agent;
-        $GLOBALS['PMA_Config']->set('DefaultLang', $default);
+        $GLOBALS['config']->set('DefaultLang', $default);
 
         $lang = $this->manager->selectLanguage();
 
-        $this->assertEquals($expect, $lang->getEnglishName());
+        $this->assertEquals($expect, $lang->getCode());
 
-        $GLOBALS['PMA_Config']->set('Lang', '');
+        $GLOBALS['config']->set('Lang', '');
         $_POST['lang'] = '';
         $_GET['lang'] = '';
         $_COOKIE['pma_lang'] = '';
         $_SERVER['HTTP_ACCEPT_LANGUAGE'] = '';
         $_SERVER['HTTP_USER_AGENT'] = '';
-        $GLOBALS['PMA_Config']->set('DefaultLang', 'en');
+        $GLOBALS['config']->set('DefaultLang', 'en');
     }
 
     /**
      * Data provider for language selection test.
      *
-     * @return array Test parameters.
+     * @return string[][]
      */
     public function selectDataProvider(): array
     {
         return [
-            [
-                'cs',
-                'en',
-                '',
-                '',
-                '',
-                '',
-                '',
-                'Czech',
-            ],
-            [
-                '',
-                'cs',
-                '',
-                '',
-                '',
-                '',
-                '',
-                'Czech',
-            ],
-            [
-                '',
-                'cs',
-                'en',
-                '',
-                '',
-                '',
-                '',
-                'Czech',
-            ],
-            [
-                '',
-                '',
-                'cs',
-                '',
-                '',
-                '',
-                '',
-                'Czech',
-            ],
-            [
-                '',
-                '',
-                '',
-                'cs',
-                '',
-                '',
-                '',
-                'Czech',
-            ],
-            [
-                '',
-                '',
-                '',
-                '',
-                'cs,en-US;q=0.7,en;q=0.3',
-                '',
-                '',
-                'Czech',
-            ],
-            [
-                '',
-                '',
-                '',
-                '',
-                '',
-                'Mozilla/5.0 (Linux; U; Android 2.2.2; tr-tr; GM FOX)',
-                '',
-                'Turkish',
-            ],
-            [
-                '',
-                '',
-                '',
-                '',
-                '',
-                '',
-                'cs',
-                'Czech',
-            ],
-            [
-                '',
-                '',
-                '',
-                '',
-                '',
-                '',
-                '',
-                'English',
-            ],
+            ['cs', 'en', '', '', '', '', '', 'cs'],
+            ['', 'cs', '', '', '', '', '', 'cs'],
+            ['', 'cs', 'en', '', '', '', '', 'cs'],
+            ['', '', 'cs', '', '', '', '', 'cs'],
+            ['', '', '', 'cs', '', '', '', 'cs'],
+            ['', '', '', '', 'cs,en-US;q=0.7,en;q=0.3', '', '', 'cs'],
+            ['', '', '', '', '', 'Mozilla/5.0 (Linux; U; Android 2.2.2; tr-tr; GM FOX)', '', 'tr'],
+            ['', '', '', '', '', '', 'cs', 'cs'],
+            ['', '', '', '', '', '', '', 'en'],
+            ['', '', '', '', 'pt;q=0.8,en-US;q=0.5,en;q=0.3', '', 'en', 'pt'],
+            ['', '', '', '', 'pt-PT,pt;q=0.8,en-US;q=0.5,en;q=0.3', '', 'en', 'pt'],
+            ['', '', '', '', 'pt-BR,pt;q=0.8,en-US;q=0.5,en;q=0.3', '', 'en', 'pt_BR'],
+            ['', '', '', '', 'ar;q=0.8,en-US;q=0.5,en;q=0.3', '', 'en', 'ar'],
+            ['', '', '', '', 'ar-AE,ar;q=0.8,en-US;q=0.5,en;q=0.3', '', 'en', 'ar'],
+            ['', '', '', '', 'ar-LY,ar;q=0.8,en-US;q=0.5,en;q=0.3', '', 'en', 'ar_LY'],
+            ['', '', '', '', 'en,pt;q=0.5', '', 'pt', 'en'],
+            ['', '', '', '', 'en-GB,en;q=0.7,pt;q=0.3', '', 'pt', 'en_GB'],
+            ['', '', '', '', 'en-US,en;q=0.7,pt;q=0.3', '', 'pt', 'en'],
+            ['', '', '', '', 'zh,en;q=0.5', '', 'en', 'zh_CN'],
+            ['', '', '', '', 'zh-CN,zh;q=0.7,en;q=0.3', '', 'en', 'zh_CN'],
+            ['', '', '', '', 'zh-HK,zh;q=0.7,en;q=0.3', '', 'en', 'zh_TW'],
+            ['', '', '', '', 'zh-TW,zh;q=0.7,en;q=0.3', '', 'en', 'zh_TW'],
         ];
     }
 
@@ -286,9 +236,11 @@ class LanguageTest extends AbstractTestCase
      */
     public function testGettext(string $locale): void
     {
-        $GLOBALS['PMA_Config']->set('FilterLanguages', '');
+        $GLOBALS['config']->set('FilterLanguages', '');
         /* We should be able to set the language */
-        $this->manager->getLanguage($locale)->activate();
+        $lang = $this->manager->getLanguage($locale);
+        $this->assertNotFalse($lang);
+        $lang->activate();
 
         /* Grab some texts */
         $this->assertStringContainsString('%s', _ngettext('%s table', '%s tables', 10));
