@@ -7,6 +7,9 @@ namespace PhpMyAdmin\Tests;
 use PhpMyAdmin\Core;
 use PhpMyAdmin\Menu;
 
+/**
+ * @covers \PhpMyAdmin\Menu
+ */
 class MenuTest extends AbstractTestCase
 {
     /**
@@ -15,9 +18,7 @@ class MenuTest extends AbstractTestCase
     protected function setUp(): void
     {
         parent::setUp();
-        parent::defineVersionConstants();
         parent::setTheme();
-        parent::loadDefaultConfig();
 
         $GLOBALS['cfg']['Server']['DisableIS'] = false;
         $GLOBALS['server'] = 0;
@@ -33,7 +34,7 @@ class MenuTest extends AbstractTestCase
      */
     public function testServer(): void
     {
-        $menu = new Menu('', '');
+        $menu = new Menu($this->dbi, '', '');
         $this->assertStringContainsString(
             'floating_menubar',
             $menu->getDisplay()
@@ -45,7 +46,7 @@ class MenuTest extends AbstractTestCase
      */
     public function testDatabase(): void
     {
-        $menu = new Menu('pma_test', '');
+        $menu = new Menu($this->dbi, 'pma_test', '');
         $this->assertStringContainsString(
             'floating_menubar',
             $menu->getDisplay()
@@ -57,7 +58,7 @@ class MenuTest extends AbstractTestCase
      */
     public function testTable(): void
     {
-        $menu = new Menu('pma_test', 'table1');
+        $menu = new Menu($this->dbi, 'pma_test', 'table1');
         $this->assertStringContainsString(
             'floating_menubar',
             $menu->getDisplay()
@@ -69,7 +70,7 @@ class MenuTest extends AbstractTestCase
      */
     public function testSetTable(): void
     {
-        $menu = new Menu('pma_test', '');
+        $menu = new Menu($this->dbi, 'pma_test', '');
         $menu->setTable('table1');
         $this->assertStringContainsString(
             'table1',
