@@ -7,13 +7,10 @@ namespace PhpMyAdmin\Tests\Navigation;
 use PhpMyAdmin\Navigation\NavigationTree;
 use PhpMyAdmin\Template;
 use PhpMyAdmin\Tests\AbstractTestCase;
-use PhpMyAdmin\Url;
-use ReflectionMethod;
-use function str_repeat;
-use function parse_url;
-use function parse_str;
-use function htmlspecialchars_decode;
 
+/**
+ * @covers \PhpMyAdmin\Navigation\NavigationTree
+ */
 class NavigationTreeTest extends AbstractTestCase
 {
     /** @var NavigationTree */
@@ -21,8 +18,6 @@ class NavigationTreeTest extends AbstractTestCase
 
     /**
      * Sets up the fixture.
-     *
-     * @access protected
      */
     protected function setUp(): void
     {
@@ -31,27 +26,22 @@ class NavigationTreeTest extends AbstractTestCase
         parent::setGlobalConfig();
         parent::setTheme();
         $GLOBALS['server'] = 1;
-        $GLOBALS['PMA_Config']->enableBc();
         $GLOBALS['cfg']['Server']['host'] = 'localhost';
         $GLOBALS['cfg']['Server']['user'] = 'user';
         $GLOBALS['cfg']['Server']['pmadb'] = '';
         $GLOBALS['cfg']['Server']['DisableIS'] = false;
-        $GLOBALS['cfgRelation']['db'] = 'pmadb';
-        $GLOBALS['cfgRelation']['navigationhiding'] = 'navigationhiding';
         $GLOBALS['cfg']['NavigationTreeEnableGrouping'] = true;
-        $GLOBALS['cfg']['ShowDatabasesNavigationAsTree']  = true;
+        $GLOBALS['cfg']['ShowDatabasesNavigationAsTree'] = true;
 
         $GLOBALS['db'] = 'db';
         $GLOBALS['table'] = '';
         $GLOBALS['PMA_PHP_SELF'] = '';
 
-        $this->object = new NavigationTree(new Template(), $GLOBALS['dbi']);
+        $this->object = new NavigationTree(new Template(), $this->dbi);
     }
 
     /**
      * Tears down the fixture.
-     *
-     * @access protected
      */
     protected function tearDown(): void
     {
@@ -87,36 +77,33 @@ class NavigationTreeTest extends AbstractTestCase
         $this->assertStringContainsString('pma_navigation_select_database', $result);
     }
 
-    /**
-     * @return void
-     */
-    public function testEncryptQueryParams()
+    public function testDatabaseGrouping(): void
     {
-        global $PMA_Config;
+        $GLOBALS['db'] = '';
+        $GLOBALS['cfg']['NavigationTreeDbSeparator'] = '__';
 
-        $_SESSION = [];
-        $PMA_Config->set('URLQueryEncryption', false);
-        $PMA_Config->set('URLQueryEncryptionSecretKey', str_repeat('a', 32));
+        // phpcs:disable Generic.Files.LineLength.TooLong
+        $this->dummyDbi->addResult(
+            'SELECT `SCHEMA_NAME` FROM `INFORMATION_SCHEMA`.`SCHEMATA`, (SELECT DB_first_level FROM ( SELECT DISTINCT SUBSTRING_INDEX(SCHEMA_NAME, \'__\', 1) DB_first_level FROM INFORMATION_SCHEMA.SCHEMATA WHERE TRUE ) t ORDER BY DB_first_level ASC LIMIT 0, 100) t2 WHERE TRUE AND 1 = LOCATE(CONCAT(DB_first_level, \'__\'), CONCAT(SCHEMA_NAME, \'__\')) ORDER BY SCHEMA_NAME ASC',
+            [['functions__a'], ['functions__b']],
+            ['SCHEMA_NAME']
+        );
+        $this->dummyDbi->addResult(
+            'SELECT COUNT(*) FROM ( SELECT DISTINCT SUBSTRING_INDEX(SCHEMA_NAME, \'__\', 1) DB_first_level FROM INFORMATION_SCHEMA.SCHEMATA WHERE TRUE ) t',
+            [['2']]
+        );
+        $this->dummyDbi->addResult(
+            'SELECT COUNT(*) FROM ( SELECT DISTINCT SUBSTRING_INDEX(SCHEMA_NAME, \'__\', 1) DB_first_level FROM INFORMATION_SCHEMA.SCHEMATA WHERE TRUE ) t',
+            [['2']]
+        );
+        // phpcs:enable
 
-        $method = new ReflectionMethod($this->object, 'encryptQueryParams');
-        $method->setAccessible(true);
-
-        $link = 'tbl_structure.php?server=1&amp;db=test_db&amp;table=test_table&amp;pos=0';
-
-        $actual = $method->invoke($this->object, $link);
-        $this->assertEquals($link, $actual);
-
-        $PMA_Config->set('URLQueryEncryption', true);
-
-        $actual = $method->invoke($this->object, $link);
-        $this->assertStringStartsWith('tbl_structure.php?server=1&amp;pos=0&amp;eq=', $actual);
-
-        $url = parse_url($actual);
-        parse_str(htmlspecialchars_decode($url['query']), $query);
-
-        $this->assertRegExp('/^[a-zA-Z0-9-_=]+$/', $query['eq']);
-        $decrypted = Url::decryptQuery($query['eq']);
-        $this->assertJson($decrypted);
-        $this->assertSame('{"db":"test_db","table":"test_table"}', $decrypted);
+        $object = new NavigationTree(new Template(), $this->dbi);
+        $result = $object->renderState();
+        $this->assertStringContainsString('<li class="first navGroup">', $result);
+        $this->assertStringContainsString('functions' . "\n", $result);
+        $this->assertStringContainsString('<div class="list_container" style="display: none;">', $result);
+        $this->assertStringContainsString('functions__a', $result);
+        $this->assertStringContainsString('functions__b', $result);
     }
 }
