@@ -6,8 +6,10 @@ namespace PhpMyAdmin\Tests\Navigation\Nodes;
 
 use PhpMyAdmin\Navigation\NodeFactory;
 use PhpMyAdmin\Tests\AbstractTestCase;
-use PhpMyAdmin\Url;
 
+/**
+ * @covers \PhpMyAdmin\Navigation\Nodes\NodeEventContainer
+ */
 class NodeEventContainerTest extends AbstractTestCase
 {
     /**
@@ -16,7 +18,6 @@ class NodeEventContainerTest extends AbstractTestCase
     protected function setUp(): void
     {
         parent::setUp();
-        parent::loadDefaultConfig();
         $GLOBALS['server'] = 0;
     }
 
@@ -26,14 +27,14 @@ class NodeEventContainerTest extends AbstractTestCase
     public function testConstructor(): void
     {
         $parent = NodeFactory::getInstance('NodeEventContainer');
-        $this->assertArrayHasKey(
-            'text',
+        $this->assertIsArray($parent->links);
+        $this->assertEquals(
+            [
+                'text' => ['route' => '/database/events', 'params' => ['db' => null]],
+                'icon' => ['route' => '/database/events', 'params' => ['db' => null]],
+            ],
             $parent->links
         );
-        $this->assertStringContainsString(
-            Url::getFromRoute('/database/events'),
-            $parent->links['text']
-        );
         $this->assertEquals('events', $parent->realName);
     }
 }
