@@ -1,38 +1,44 @@
 <?php
-/* vim: set expandtab sw=4 ts=4 sts=4: */
-/**
- * tests for PhpMyAdmin\Plugins\Export\ExportHtmlword class
- *
- * @package PhpMyAdmin-test
- */
+
 declare(strict_types=1);
 
 namespace PhpMyAdmin\Tests\Plugins\Export;
 
+use PhpMyAdmin\ConfigStorage\Relation;
+use PhpMyAdmin\ConfigStorage\RelationParameters;
 use PhpMyAdmin\DatabaseInterface;
 use PhpMyAdmin\Plugins\Export\ExportHtmlword;
-use PhpMyAdmin\Relation;
-use PhpMyAdmin\Tests\PmaTestCase;
+use PhpMyAdmin\Properties\Options\Groups\OptionsPropertyMainGroup;
+use PhpMyAdmin\Properties\Options\Groups\OptionsPropertyRootGroup;
+use PhpMyAdmin\Properties\Options\Items\BoolPropertyItem;
+use PhpMyAdmin\Properties\Options\Items\RadioPropertyItem;
+use PhpMyAdmin\Properties\Options\Items\TextPropertyItem;
+use PhpMyAdmin\Properties\Plugins\ExportPluginProperties;
+use PhpMyAdmin\Tests\AbstractTestCase;
+use PhpMyAdmin\Tests\Stubs\DummyResult;
 use ReflectionMethod;
 use ReflectionProperty;
 
+use function __;
+use function array_shift;
+use function ob_get_clean;
+use function ob_start;
+
 /**
- * tests for PhpMyAdmin\Plugins\Export\ExportHtmlword class
- *
- * @package PhpMyAdmin-test
+ * @covers \PhpMyAdmin\Plugins\Export\ExportHtmlword
  * @group medium
  */
-class ExportHtmlwordTest extends PmaTestCase
+class ExportHtmlwordTest extends AbstractTestCase
 {
+    /** @var ExportHtmlword */
     protected $object;
 
     /**
      * Configures global environment.
-     *
-     * @return void
      */
     protected function setUp(): void
     {
+        parent::setUp();
         $GLOBALS['server'] = 0;
         $this->object = new ExportHtmlword();
         $GLOBALS['output_kanji_conversion'] = false;
@@ -40,37 +46,34 @@ class ExportHtmlwordTest extends PmaTestCase
         $GLOBALS['buffer_needed'] = false;
         $GLOBALS['asfile'] = true;
         $GLOBALS['save_on_server'] = false;
+        $GLOBALS['db'] = '';
+        $GLOBALS['table'] = '';
+        $GLOBALS['lang'] = '';
+        $GLOBALS['text_dir'] = '';
+        $GLOBALS['PMA_PHP_SELF'] = '';
+        $GLOBALS['cfg']['Server']['DisableIS'] = true;
     }
 
     /**
      * tearDown for test cases
-     *
-     * @return void
      */
     protected function tearDown(): void
     {
+        parent::tearDown();
         unset($this->object);
     }
 
-    /**
-     * Test for PhpMyAdmin\Plugins\Export\ExportHtmlword::setProperties
-     *
-     * @return void
-     */
-    public function testSetProperties()
+    public function testSetProperties(): void
     {
-        $method = new ReflectionMethod('PhpMyAdmin\Plugins\Export\ExportHtmlword', 'setProperties');
+        $method = new ReflectionMethod(ExportHtmlword::class, 'setProperties');
         $method->setAccessible(true);
         $method->invoke($this->object, null);
 
-        $attrProperties = new ReflectionProperty('PhpMyAdmin\Plugins\Export\ExportHtmlword', 'properties');
+        $attrProperties = new ReflectionProperty(ExportHtmlword::class, 'properties');
         $attrProperties->setAccessible(true);
         $properties = $attrProperties->getValue($this->object);
 
-        $this->assertInstanceOf(
-            'PhpMyAdmin\Properties\Plugins\ExportPluginProperties',
-            $properties
-        );
+        $this->assertInstanceOf(ExportPluginProperties::class, $properties);
 
         $this->assertEquals(
             'Microsoft Word 2000',
@@ -98,10 +101,7 @@ class ExportHtmlwordTest extends PmaTestCase
 
         $options = $properties->getOptions();
 
-        $this->assertInstanceOf(
-            'PhpMyAdmin\Properties\Options\Groups\OptionsPropertyRootGroup',
-            $options
-        );
+        $this->assertInstanceOf(OptionsPropertyRootGroup::class, $options);
 
         $this->assertEquals(
             'Format Specific Options',
@@ -111,10 +111,7 @@ class ExportHtmlwordTest extends PmaTestCase
         $generalOptionsArray = $options->getProperties();
         $generalOptions = $generalOptionsArray[0];
 
-        $this->assertInstanceOf(
-            'PhpMyAdmin\Properties\Options\Groups\OptionsPropertyMainGroup',
-            $generalOptions
-        );
+        $this->assertInstanceOf(OptionsPropertyMainGroup::class, $generalOptions);
 
         $this->assertEquals(
             'dump_what',
@@ -130,10 +127,7 @@ class ExportHtmlwordTest extends PmaTestCase
 
         $property = array_shift($generalProperties);
 
-        $this->assertInstanceOf(
-            'PhpMyAdmin\Properties\Options\Items\RadioPropertyItem',
-            $property
-        );
+        $this->assertInstanceOf(RadioPropertyItem::class, $property);
 
         $this->assertEquals(
             'structure_or_data',
@@ -151,10 +145,7 @@ class ExportHtmlwordTest extends PmaTestCase
 
         $generalOptions = $generalOptionsArray[1];
 
-        $this->assertInstanceOf(
-            'PhpMyAdmin\Properties\Options\Groups\OptionsPropertyMainGroup',
-            $generalOptions
-        );
+        $this->assertInstanceOf(OptionsPropertyMainGroup::class, $generalOptions);
 
         $this->assertEquals(
             'dump_what',
@@ -175,10 +166,7 @@ class ExportHtmlwordTest extends PmaTestCase
 
         $property = array_shift($generalProperties);
 
-        $this->assertInstanceOf(
-            'PhpMyAdmin\Properties\Options\Items\TextPropertyItem',
-            $property
-        );
+        $this->assertInstanceOf(TextPropertyItem::class, $property);
 
         $this->assertEquals(
             'null',
@@ -192,10 +180,7 @@ class ExportHtmlwordTest extends PmaTestCase
 
         $property = array_shift($generalProperties);
 
-        $this->assertInstanceOf(
-            'PhpMyAdmin\Properties\Options\Items\BoolPropertyItem',
-            $property
-        );
+        $this->assertInstanceOf(BoolPropertyItem::class, $property);
 
         $this->assertEquals(
             'columns',
@@ -208,19 +193,13 @@ class ExportHtmlwordTest extends PmaTestCase
         );
     }
 
-    /**
-     * Test for PhpMyAdmin\Plugins\Export\ExportHtmlword::exportHeader
-     *
-     * @return void
-     */
-    public function testExportHeader()
+    public function testExportHeader(): void
     {
         ob_start();
         $this->object->exportHeader();
         $result = ob_get_clean();
 
-        $expected
-            = '<html xmlns:o="urn:schemas-microsoft-com:office:office"
+        $expected = '<html xmlns:o="urn:schemas-microsoft-com:office:office"
             xmlns:x="urn:schemas-microsoft-com:office:word"
             xmlns="http://www.w3.org/TR/REC-html40">
 
@@ -233,10 +212,7 @@ class ExportHtmlwordTest extends PmaTestCase
             </head>
             <body>';
 
-        $this->assertEquals(
-            $expected,
-            $result
-        );
+        $this->assertEquals($expected, $result);
 
         // case 2
 
@@ -245,8 +221,7 @@ class ExportHtmlwordTest extends PmaTestCase
         $this->object->exportHeader();
         $result = ob_get_clean();
 
-        $expected
-            = '<html xmlns:o="urn:schemas-microsoft-com:office:office"
+        $expected = '<html xmlns:o="urn:schemas-microsoft-com:office:office"
             xmlns:x="urn:schemas-microsoft-com:office:word"
             xmlns="http://www.w3.org/TR/REC-html40">
 
@@ -259,18 +234,10 @@ class ExportHtmlwordTest extends PmaTestCase
             </head>
             <body>';
 
-        $this->assertEquals(
-            $expected,
-            $result
-        );
+        $this->assertEquals($expected, $result);
     }
 
-    /**
-     * Test for PhpMyAdmin\Plugins\Export\ExportHtmlword::exportFooter
-     *
-     * @return void
-     */
-    public function testExportFooter()
+    public function testExportFooter(): void
     {
         ob_start();
         $this->assertTrue(
@@ -278,18 +245,10 @@ class ExportHtmlwordTest extends PmaTestCase
         );
         $result = ob_get_clean();
 
-        $this->assertEquals(
-            '</body></html>',
-            $result
-        );
+        $this->assertEquals('</body></html>', $result);
     }
 
-    /**
-     * Test for PhpMyAdmin\Plugins\Export\ExportHtmlword::exportDBHeader
-     *
-     * @return void
-     */
-    public function testExportDBHeader()
+    public function testExportDBHeader(): void
     {
         ob_start();
         $this->assertTrue(
@@ -297,74 +256,26 @@ class ExportHtmlwordTest extends PmaTestCase
         );
         $result = ob_get_clean();
 
-        $this->assertEquals(
-            '<h1>Database d&quot;b</h1>',
-            $result
-        );
+        $this->assertEquals('<h1>Database d&quot;b</h1>', $result);
     }
 
-    /**
-     * Test for PhpMyAdmin\Plugins\Export\ExportHtmlword::exportDBFooter
-     *
-     * @return void
-     */
-    public function testExportDBFooter()
+    public function testExportDBFooter(): void
     {
         $this->assertTrue(
             $this->object->exportDBFooter('testDB')
         );
     }
 
-    /**
-     * Test for PhpMyAdmin\Plugins\Export\ExportHtmlword::exportDBCreate
-     *
-     * @return void
-     */
-    public function testExportDBCreate()
+    public function testExportDBCreate(): void
     {
         $this->assertTrue(
             $this->object->exportDBCreate('testDB', 'database')
         );
     }
 
-    /**
-     * Test for PhpMyAdmin\Plugins\Export\ExportHtmlword::exportData
-     *
-     * @return void
-     */
-    public function testExportData()
+    public function testExportData(): void
     {
         // case 1
-
-        $dbi = $this->getMockBuilder('PhpMyAdmin\DatabaseInterface')
-            ->disableOriginalConstructor()
-            ->getMock();
-
-        $dbi->expects($this->once())
-            ->method('query')
-            ->with('test', DatabaseInterface::CONNECT_USER, DatabaseInterface::QUERY_UNBUFFERED)
-            ->will($this->returnValue(true));
-
-        $dbi->expects($this->once())
-            ->method('numFields')
-            ->with(true)
-            ->will($this->returnValue(5));
-
-        $dbi->expects($this->any())
-            ->method('fieldName')
-            ->will($this->returnValue("foo\\bar"));
-
-        $dbi->expects($this->at(7))
-            ->method('fetchRow')
-            ->with(true)
-            ->will($this->returnValue([null, '0', 'test', false]));
-
-        $dbi->expects($this->at(8))
-            ->method('fetchRow')
-            ->with(true)
-            ->will($this->returnValue(null));
-        $GLOBALS['dbi'] = $dbi;
-
         $GLOBALS['htmlword_columns'] = true;
         $GLOBALS['what'] = 'UT';
         $GLOBALS['UT_null'] = 'customNull';
@@ -375,41 +286,36 @@ class ExportHtmlwordTest extends PmaTestCase
         $GLOBALS['save_on_server'] = false;
 
         ob_start();
-        $this->assertTrue(
-            $this->object->exportData(
-                'testDB',
-                'testTable',
-                "\n",
-                'example.com',
-                'test'
-            )
-        );
-        $result = htmlspecialchars_decode(ob_get_clean());
+        $this->assertTrue($this->object->exportData(
+            'test_db',
+            'test_table',
+            "\n",
+            'localhost',
+            'SELECT * FROM `test_db`.`test_table`;'
+        ));
+        $result = ob_get_clean();
 
         $this->assertEquals(
-            '<h2>Dumping data for table testTable</h2>' .
-            '<table class="width100" cellspacing="1"><tr class="print-category">' .
-            '<td class="print"><strong>foobar</strong></td>' .
-            '<td class="print"><strong>foobar</strong></td>' .
-            '<td class="print"><strong>foobar</strong></td>' .
-            '<td class="print"><strong>foobar</strong></td>' .
-            '<td class="print"><strong>foobar</strong></td>' .
-            '</tr><tr class="print-category"><td class="print">' .
-            'customNull</td><td class="print">0</td><td class="print">test</td>' .
-            '<td class="print"></td><td class="print">customNull</td></tr></table>',
+            '<h2>Dumping data for table test_table</h2>'
+            . '<table width="100%" cellspacing="1"><tr class="print-category">'
+            . '<td class="print"><strong>id</strong></td>'
+            . '<td class="print"><strong>name</strong></td>'
+            . '<td class="print"><strong>datetimefield</strong></td>'
+            . '</tr><tr class="print-category">'
+            . '<td class="print">1</td><td class="print">abcd</td><td class="print">2011-01-20 02:00:02</td>'
+            . '</tr><tr class="print-category">'
+            . '<td class="print">2</td><td class="print">foo</td><td class="print">2010-01-20 02:00:02</td>'
+            . '</tr><tr class="print-category">'
+            . '<td class="print">3</td><td class="print">Abcd</td><td class="print">2012-01-20 02:00:02</td>'
+            . '</tr></table>',
             $result
         );
     }
 
-    /**
-     * Test for PhpMyAdmin\Plugins\Export\ExportHtmlword::getTableDefStandIn
-     *
-     * @return void
-     */
-    public function testGetTableDefStandIn()
+    public function testGetTableDefStandIn(): void
     {
-        $this->object = $this->getMockBuilder('PhpMyAdmin\Plugins\Export\ExportHtmlword')
-            ->setMethods(['formatOneColumnDefinition'])
+        $this->object = $this->getMockBuilder(ExportHtmlword::class)
+            ->onlyMethods(['formatOneColumnDefinition'])
             ->getMock();
 
         // case 1
@@ -425,7 +331,7 @@ class ExportHtmlwordTest extends PmaTestCase
             ],
         ];
 
-        $dbi = $this->getMockBuilder('PhpMyAdmin\DatabaseInterface')
+        $dbi = $this->getMockBuilder(DatabaseInterface::class)
             ->disableOriginalConstructor()
             ->getMock();
 
@@ -447,7 +353,7 @@ class ExportHtmlwordTest extends PmaTestCase
             ->will($this->returnValue(1));
 
         $this->assertEquals(
-            '<table class="width100" cellspacing="1">' .
+            '<table width="100%" cellspacing="1">' .
             '<tr class="print-category"><th class="print">Column</th>' .
             '<td class="print"><strong>Type</strong></td>' .
             '<td class="print"><strong>Null</strong></td>' .
@@ -457,15 +363,10 @@ class ExportHtmlwordTest extends PmaTestCase
         );
     }
 
-    /**
-     * Test for PhpMyAdmin\Plugins\Export\ExportHtmlword::getTableDef
-     *
-     * @return void
-     */
-    public function testGetTableDef()
+    public function testGetTableDef(): void
     {
-        $this->object = $this->getMockBuilder('PhpMyAdmin\Plugins\Export\ExportHtmlword')
-            ->setMethods(['formatOneColumnDefinition'])
+        $this->object = $this->getMockBuilder(ExportHtmlword::class)
+            ->onlyMethods(['formatOneColumnDefinition'])
             ->getMock();
 
         $keys = [
@@ -481,7 +382,9 @@ class ExportHtmlwordTest extends PmaTestCase
 
         // case 1
 
-        $dbi = $this->getMockBuilder('PhpMyAdmin\DatabaseInterface')
+        $resultStub = $this->createMock(DummyResult::class);
+
+        $dbi = $this->getMockBuilder(DatabaseInterface::class)
             ->disableOriginalConstructor()
             ->getMock();
 
@@ -503,31 +406,24 @@ class ExportHtmlwordTest extends PmaTestCase
             ->with('database', '')
             ->will($this->returnValue($keys));
 
-        $columns = [
-            'Field' => 'fieldname',
-        ];
+        $columns = ['Field' => 'fieldname'];
         $dbi->expects($this->once())
             ->method('getColumns')
             ->with('database', '')
             ->will($this->returnValue([$columns]));
 
-        $dbi->expects($this->any())
-            ->method('query')
-            ->will($this->returnValue(true));
+        $dbi->expects($this->once())
+            ->method('tryQueryAsControlUser')
+            ->will($this->returnValue($resultStub));
 
-        $dbi->expects($this->any())
+        $resultStub->expects($this->once())
             ->method('numRows')
             ->will($this->returnValue(1));
 
-        $dbi->expects($this->any())
+        $resultStub->expects($this->once())
             ->method('fetchAssoc')
-            ->will(
-                $this->returnValue(
-                    [
-                        'comment' => ['fieldname' => 'testComment'],
-                    ]
-                )
-            );
+            ->will($this->returnValue(['comment' => 'testComment']));
+
         $dbi->expects($this->any())->method('escapeString')
             ->will($this->returnArgument(0));
 
@@ -539,40 +435,35 @@ class ExportHtmlwordTest extends PmaTestCase
             ->with($columns, ['name1'])
             ->will($this->returnValue(1));
 
-        $GLOBALS['cfgRelation']['relation'] = true;
-        $_SESSION['relation'][0] = [
-            'PMA_VERSION' => PMA_VERSION,
+        $_SESSION['relation'] = [];
+        $_SESSION['relation'][$GLOBALS['server']] = RelationParameters::fromArray([
             'relwork' => true,
             'commwork' => true,
             'mimework' => true,
             'db' => 'database',
             'relation' => 'rel',
             'column_info' => 'col',
-        ];
+        ])->toArray();
 
-        $result = $this->object->getTableDef(
-            'database',
-            '',
-            true,
-            true,
-            true
-        );
+        $result = $this->object->getTableDef('database', '', true, true, true);
 
         $this->assertEquals(
-            '<table class="width100" cellspacing="1">' .
+            '<table width="100%" cellspacing="1">' .
             '<tr class="print-category"><th class="print">Column</th>' .
             '<td class="print"><strong>Type</strong></td>' .
             '<td class="print"><strong>Null</strong></td>' .
             '<td class="print"><strong>Default</strong></td>' .
             '<td class="print"><strong>Comments</strong></td>' .
-            '<td class="print"><strong>Media (MIME) type</strong></td></tr>' .
+            '<td class="print"><strong>Media type</strong></td></tr>' .
             '1<td class="print"></td><td class="print">Test&lt;</td></tr></table>',
             $result
         );
 
         // case 2
 
-        $dbi = $this->getMockBuilder('PhpMyAdmin\DatabaseInterface')
+        $resultStub = $this->createMock(DummyResult::class);
+
+        $dbi = $this->getMockBuilder(DatabaseInterface::class)
             ->disableOriginalConstructor()
             ->getMock();
 
@@ -599,70 +490,50 @@ class ExportHtmlwordTest extends PmaTestCase
             ->with('database', '')
             ->will($this->returnValue($keys));
 
-        $columns = [
-            'Field' => 'fieldname',
-        ];
+        $columns = ['Field' => 'fieldname'];
 
         $dbi->expects($this->once())
             ->method('getColumns')
             ->with('database', '')
             ->will($this->returnValue([$columns]));
 
-        $dbi->expects($this->any())
-            ->method('query')
-            ->will($this->returnValue(true));
+        $dbi->expects($this->once())
+            ->method('tryQueryAsControlUser')
+            ->will($this->returnValue($resultStub));
 
-        $dbi->expects($this->any())
+        $resultStub->expects($this->once())
             ->method('numRows')
             ->will($this->returnValue(1));
 
-        $dbi->expects($this->any())
+        $resultStub->expects($this->once())
             ->method('fetchAssoc')
-            ->will(
-                $this->returnValue(
-                    [
-                        'comment' => ['field' => 'testComment'],
-                    ]
-                )
-            );
+            ->will($this->returnValue(['comment' => 'testComment']));
+
         $dbi->expects($this->any())->method('escapeString')
             ->will($this->returnArgument(0));
 
         $GLOBALS['dbi'] = $dbi;
         $this->object->relation = new Relation($dbi);
 
-        $GLOBALS['cfgRelation']['relation'] = true;
-        $_SESSION['relation'][0] = [
-            'PMA_VERSION' => PMA_VERSION,
+        $_SESSION['relation'] = [];
+        $_SESSION['relation'][$GLOBALS['server']] = RelationParameters::fromArray([
             'relwork' => true,
             'commwork' => true,
             'mimework' => true,
             'db' => 'database',
             'relation' => 'rel',
             'column_info' => 'col',
-        ];
+        ])->toArray();
 
-        $result = $this->object->getTableDef(
-            'database',
-            '',
-            true,
-            true,
-            true
-        );
+        $result = $this->object->getTableDef('database', '', true, true, true);
 
-        $this->assertStringContainsString(
-            '<td class="print">ftable (ffield)</td>',
-            $result
-        );
+        $this->assertStringContainsString('<td class="print">ftable (ffield)</td>', $result);
 
-        $this->assertStringContainsString(
-            '<td class="print"></td><td class="print"></td>',
-            $result
-        );
+        $this->assertStringContainsString('<td class="print"></td><td class="print"></td>', $result);
 
-         // case 3
+        // case 3
 
-        $dbi = $this->getMockBuilder('PhpMyAdmin\DatabaseInterface')
+        $dbi = $this->getMockBuilder(DatabaseInterface::class)
             ->disableOriginalConstructor()
             ->getMock();
 
@@ -671,58 +542,32 @@ class ExportHtmlwordTest extends PmaTestCase
             ->with('database', '')
             ->will($this->returnValue($keys));
 
-        $columns = [
-            'Field' => 'fieldname',
-        ];
+        $columns = ['Field' => 'fieldname'];
 
         $dbi->expects($this->once())
             ->method('getColumns')
             ->with('database', '')
             ->will($this->returnValue([$columns]));
 
-        $dbi->expects($this->any())
-            ->method('query')
-            ->will($this->returnValue(true));
+        $dbi->expects($this->never())
+            ->method('tryQuery');
 
-        $dbi->expects($this->any())
-            ->method('numRows')
-            ->will($this->returnValue(1));
-
-        $dbi->expects($this->any())
-            ->method('fetchAssoc')
-            ->will(
-                $this->returnValue(
-                    [
-                        'comment' => ['field' => 'testComment'],
-                    ]
-                )
-            );
         $dbi->expects($this->any())->method('escapeString')
             ->will($this->returnArgument(0));
 
         $GLOBALS['dbi'] = $dbi;
 
-        $GLOBALS['cfgRelation']['relation'] = true;
-        $_SESSION['relation'][0] = [
-            'PMA_VERSION' => PMA_VERSION,
-            'relwork' => false,
-            'commwork' => false,
-            'mimework' => false,
+        $_SESSION['relation'] = [];
+        $_SESSION['relation'][$GLOBALS['server']] = RelationParameters::fromArray([
             'db' => 'database',
             'relation' => 'rel',
             'column_info' => 'col',
-        ];
+        ])->toArray();
 
-        $result = $this->object->getTableDef(
-            'database',
-            '',
-            false,
-            false,
-            false
-        );
+        $result = $this->object->getTableDef('database', '', false, false, false);
 
         $this->assertEquals(
-            '<table class="width100" cellspacing="1">' .
+            '<table width="100%" cellspacing="1">' .
             '<tr class="print-category"><th class="print">Column</th>' .
             '<td class="print"><strong>Type</strong></td>' .
             '<td class="print"><strong>Null</strong></td>' .
@@ -731,14 +576,9 @@ class ExportHtmlwordTest extends PmaTestCase
         );
     }
 
-    /**
-     * Test for PhpMyAdmin\Plugins\Export\ExportHtmlword::getTriggers
-     *
-     * @return void
-     */
-    public function testGetTriggers()
+    public function testGetTriggers(): void
     {
-        $dbi = $this->getMockBuilder('PhpMyAdmin\DatabaseInterface')
+        $dbi = $this->getMockBuilder(DatabaseInterface::class)
             ->disableOriginalConstructor()
             ->getMock();
 
@@ -758,7 +598,7 @@ class ExportHtmlwordTest extends PmaTestCase
 
         $GLOBALS['dbi'] = $dbi;
 
-        $method = new ReflectionMethod('PhpMyAdmin\Plugins\Export\ExportHtmlword', 'getTriggers');
+        $method = new ReflectionMethod(ExportHtmlword::class, 'getTriggers');
         $method->setAccessible(true);
         $result = $method->invoke($this->object, 'database', 'table');
 
@@ -771,133 +611,121 @@ class ExportHtmlwordTest extends PmaTestCase
         );
     }
 
-    /**
-     * Test for PhpMyAdmin\Plugins\Export\ExportHtmlword::exportStructure
-     *
-     * @return void
-     */
-    public function testExportStructure()
+    public function testExportStructure(): void
     {
-
-        $dbi = $this->getMockBuilder('PhpMyAdmin\DatabaseInterface')
-            ->disableOriginalConstructor()
-            ->getMock();
-
-        $dbi->expects($this->once())
-            ->method('getTriggers')
-            ->with('db', 'tbl')
-            ->will($this->returnValue(1));
-
-        $this->object = $this->getMockBuilder('PhpMyAdmin\Plugins\Export\ExportHtmlword')
-            ->setMethods(['getTableDef', 'getTriggers', 'getTableDefStandIn'])
-            ->getMock();
-
-        $this->object->expects($this->at(0))
-            ->method('getTableDef')
-            ->with('db', 'tbl', false, false, false, false)
-            ->will($this->returnValue('dumpText1'));
-
-        $this->object->expects($this->once())
-            ->method('getTriggers')
-            ->with('db', 'tbl')
-            ->will($this->returnValue('dumpText2'));
-
-        $this->object->expects($this->at(2))
-            ->method('getTableDef')
-            ->with('db', 'tbl', false, false, false, true, [])
-            ->will($this->returnValue('dumpText3'));
-
-        $this->object->expects($this->once())
-            ->method('getTableDefStandIn')
-            ->with('db', 'tbl', "\n")
-            ->will($this->returnValue('dumpText4'));
-
-        $GLOBALS['dbi'] = $dbi;
-
         ob_start();
+        $this->dummyDbi->addSelectDb('test_db');
         $this->assertTrue(
             $this->object->exportStructure(
-                'db',
-                'tbl',
+                'test_db',
+                'test_table',
                 "\n",
-                "example.com",
-                "create_table",
-                "test"
+                'localhost',
+                'create_table',
+                'test'
             )
         );
+        $this->assertAllSelectsConsumed();
         $result = ob_get_clean();
 
         $this->assertEquals(
-            '<h2>Table structure for table tbl</h2>dumpText1',
+            '<h2>Table structure for table test_table</h2>'
+            . '<table width="100%" cellspacing="1"><tr class="print-category">'
+            . '<th class="print">Column</th><td class="print"><strong>Type</strong></td>'
+            . '<td class="print"><strong>Null</strong></td><td class="print"><strong>Default</strong></td></tr>'
+            . '<tr class="print-category"><td class="print"><em><strong>id</strong></em></td>'
+            . '<td class="print">int(11)</td><td class="print">No</td><td class="print">NULL</td></tr>'
+            . '<tr class="print-category"><td class="print">name</td><td class="print">varchar(20)</td>'
+            . '<td class="print">No</td><td class="print">NULL</td></tr><tr class="print-category">'
+            . '<td class="print">datetimefield</td><td class="print">datetime</td>'
+            . '<td class="print">No</td><td class="print">NULL</td></tr></table>',
             $result
         );
 
         ob_start();
         $this->assertTrue(
             $this->object->exportStructure(
-                'db',
-                'tbl',
+                'test_db',
+                'test_table',
                 "\n",
-                "example.com",
-                "triggers",
-                "test"
+                'localhost',
+                'triggers',
+                'test'
             )
         );
         $result = ob_get_clean();
 
         $this->assertEquals(
-            '<h2>Triggers tbl</h2>dumpText2',
+            '<h2>Triggers test_table</h2><table width="100%" cellspacing="1">'
+            . '<tr class="print-category"><th class="print">Name</th>'
+            . '<td class="print"><strong>Time</strong></td><td class="print"><strong>Event</strong></td>'
+            . '<td class="print"><strong>Definition</strong></td></tr><tr class="print-category">'
+            . '<td class="print">test_trigger</td><td class="print">AFTER</td>'
+            . '<td class="print">INSERT</td><td class="print">BEGIN END</td></tr></table>',
+            $result
+        );
+
+        ob_start();
+        $this->dummyDbi->addSelectDb('test_db');
+        $this->assertTrue(
+            $this->object->exportStructure(
+                'test_db',
+                'test_table',
+                "\n",
+                'localhost',
+                'create_view',
+                'test'
+            )
+        );
+        $this->assertAllSelectsConsumed();
+        $result = ob_get_clean();
+
+        $this->assertEquals(
+            '<h2>Structure for view test_table</h2>'
+            . '<table width="100%" cellspacing="1"><tr class="print-category">'
+            . '<th class="print">Column</th><td class="print"><strong>Type</strong></td>'
+            . '<td class="print"><strong>Null</strong></td><td class="print"><strong>Default</strong>'
+            . '</td></tr><tr class="print-category"><td class="print"><em><strong>id</strong></em></td>'
+            . '<td class="print">int(11)</td><td class="print">No</td><td class="print">NULL</td></tr>'
+            . '<tr class="print-category"><td class="print">name</td><td class="print">varchar(20)</td>'
+            . '<td class="print">No</td><td class="print">NULL</td></tr><tr class="print-category">'
+            . '<td class="print">datetimefield</td><td class="print">datetime</td>'
+            . '<td class="print">No</td><td class="print">NULL</td></tr></table>',
             $result
         );
 
         ob_start();
         $this->assertTrue(
             $this->object->exportStructure(
-                'db',
-                'tbl',
+                'test_db',
+                'test_table',
                 "\n",
-                "example.com",
-                "create_view",
-                "test"
+                'localhost',
+                'stand_in',
+                'test'
             )
         );
         $result = ob_get_clean();
 
         $this->assertEquals(
-            '<h2>Structure for view tbl</h2>dumpText3',
-            $result
-        );
-
-        ob_start();
-        $this->assertTrue(
-            $this->object->exportStructure(
-                'db',
-                'tbl',
-                "\n",
-                "example.com",
-                "stand_in",
-                "test"
-            )
-        );
-        $result = ob_get_clean();
-
-        $this->assertEquals(
-            '<h2>Stand-in structure for view tbl</h2>dumpText4',
+            '<h2>Stand-in structure for view test_table</h2>'
+            . '<table width="100%" cellspacing="1"><tr class="print-category">'
+            . '<th class="print">Column</th><td class="print"><strong>Type</strong></td>'
+            . '<td class="print"><strong>Null</strong></td><td class="print"><strong>Default</strong></td>'
+            . '</tr><tr class="print-category">'
+            . '<td class="print"><em><strong>id</strong></em></td><td class="print">int(11)</td>'
+            . '<td class="print">No</td><td class="print">NULL</td></tr><tr class="print-category">'
+            . '<td class="print">name</td><td class="print">varchar(20)</td><td class="print">No</td>'
+            . '<td class="print">NULL</td></tr><tr class="print-category">'
+            . '<td class="print">datetimefield</td><td class="print">datetime</td>'
+            . '<td class="print">No</td><td class="print">NULL</td></tr></table>',
             $result
         );
     }
 
-    /**
-     * Test for PhpMyAdmin\Plugins\Export\ExportHtmlword::formatOneColumnDefinition
-     *
-     * @return void
-     */
-    public function testFormatOneColumnDefinition()
+    public function testFormatOneColumnDefinition(): void
     {
-        $method = new ReflectionMethod(
-            'PhpMyAdmin\Plugins\Export\ExportHtmlword',
-            'formatOneColumnDefinition'
-        );
+        $method = new ReflectionMethod(ExportHtmlword::class, 'formatOneColumnDefinition');
         $method->setAccessible(true);
 
         $cols = [
@@ -907,9 +735,7 @@ class ExportHtmlwordTest extends PmaTestCase
             'Type' => 'set(abc)enum123',
         ];
 
-        $unique_keys = [
-            'field',
-        ];
+        $unique_keys = ['field'];
 
         $this->assertEquals(
             '<tr class="print-category"><td class="print"><em>' .
@@ -926,9 +752,7 @@ class ExportHtmlwordTest extends PmaTestCase
             'Default' => 'def',
         ];
 
-        $unique_keys = [
-            'field',
-        ];
+        $unique_keys = ['field'];
 
         $this->assertEquals(
             '<tr class="print-category"><td class="print">fields</td>' .
