@@ -4,7 +4,10 @@ declare(strict_types=1);
 
 namespace PhpMyAdmin\Tests\Plugins\Export;
 
+use PhpMyAdmin\ConfigStorage\Relation;
+use PhpMyAdmin\ConfigStorage\RelationParameters;
 use PhpMyAdmin\DatabaseInterface;
+use PhpMyAdmin\FieldMetadata;
 use PhpMyAdmin\Plugins\Export\ExportOdt;
 use PhpMyAdmin\Properties\Options\Groups\OptionsPropertyMainGroup;
 use PhpMyAdmin\Properties\Options\Groups\OptionsPropertyRootGroup;
@@ -12,14 +15,22 @@ use PhpMyAdmin\Properties\Options\Items\BoolPropertyItem;
 use PhpMyAdmin\Properties\Options\Items\RadioPropertyItem;
 use PhpMyAdmin\Properties\Options\Items\TextPropertyItem;
 use PhpMyAdmin\Properties\Plugins\ExportPluginProperties;
-use PhpMyAdmin\Relation;
 use PhpMyAdmin\Tests\AbstractTestCase;
+use PhpMyAdmin\Tests\Stubs\DummyResult;
 use ReflectionMethod;
-use ReflectionProperty;
 use stdClass;
+
+use function __;
 use function array_shift;
 
+use const MYSQLI_BLOB_FLAG;
+use const MYSQLI_NUM_FLAG;
+use const MYSQLI_TYPE_BLOB;
+use const MYSQLI_TYPE_DECIMAL;
+use const MYSQLI_TYPE_STRING;
+
 /**
+ * @covers \PhpMyAdmin\Plugins\Export\ExportOdt
  * @requires extension zip
  * @group medium
  */
@@ -34,8 +45,6 @@ class ExportOdtTest extends AbstractTestCase
     protected function setUp(): void
     {
         parent::setUp();
-        parent::defineVersionConstants();
-        parent::loadDefaultConfig();
         $GLOBALS['server'] = 0;
         $GLOBALS['output_kanji_conversion'] = false;
         $GLOBALS['output_charset_conversion'] = false;
@@ -45,7 +54,7 @@ class ExportOdtTest extends AbstractTestCase
         $GLOBALS['plugin_param'] = [];
         $GLOBALS['plugin_param']['export_type'] = 'table';
         $GLOBALS['plugin_param']['single_table'] = false;
-        $GLOBALS['cfgRelation']['relation'] = true;
+        $GLOBALS['cfg']['Server']['DisableIS'] = true;
         $this->object = new ExportOdt();
     }
 
@@ -62,20 +71,21 @@ class ExportOdtTest extends AbstractTestCase
     {
         $GLOBALS['plugin_param']['export_type'] = '';
         $GLOBALS['plugin_param']['single_table'] = false;
-        $GLOBALS['cfgRelation']['mimework'] = true;
+
+        $relationParameters = RelationParameters::fromArray([
+            'db' => 'db',
+            'relation' => 'relation',
+            'column_info' => 'column_info',
+            'relwork' => true,
+            'mimework' => true,
+        ]);
+        $_SESSION = ['relation' => [$GLOBALS['server'] => $relationParameters->toArray()]];
 
         $method = new ReflectionMethod(ExportOdt::class, 'setProperties');
         $method->setAccessible(true);
-        $method->invoke($this->object, null);
+        $properties = $method->invoke($this->object, null);
 
-        $attrProperties = new ReflectionProperty(ExportOdt::class, 'properties');
-        $attrProperties->setAccessible(true);
-        $properties = $attrProperties->getValue($this->object);
-
-        $this->assertInstanceOf(
-            ExportPluginProperties::class,
-            $properties
-        );
+        $this->assertInstanceOf(ExportPluginProperties::class, $properties);
 
         $this->assertEquals(
             'OpenDocument Text',
@@ -103,10 +113,7 @@ class ExportOdtTest extends AbstractTestCase
 
         $options = $properties->getOptions();
 
-        $this->assertInstanceOf(
-            OptionsPropertyRootGroup::class,
-            $options
-        );
+        $this->assertInstanceOf(OptionsPropertyRootGroup::class, $options);
 
         $this->assertEquals(
             'Format Specific Options',
@@ -117,10 +124,7 @@ class ExportOdtTest extends AbstractTestCase
 
         $generalOptions = array_shift($generalOptionsArray);
 
-        $this->assertInstanceOf(
-            OptionsPropertyMainGroup::class,
-            $generalOptions
-        );
+        $this->assertInstanceOf(OptionsPropertyMainGroup::class, $generalOptions);
 
         $this->assertEquals(
             'general_opts',
@@ -136,10 +140,7 @@ class ExportOdtTest extends AbstractTestCase
 
         $property = array_shift($generalProperties);
 
-        $this->assertInstanceOf(
-            RadioPropertyItem::class,
-            $property
-        );
+        $this->assertInstanceOf(RadioPropertyItem::class, $property);
 
         $this->assertEquals(
             'structure_or_data',
@@ -157,10 +158,7 @@ class ExportOdtTest extends AbstractTestCase
 
         $generalOptions = array_shift($generalOptionsArray);
 
-        $this->assertInstanceOf(
-            OptionsPropertyMainGroup::class,
-            $generalOptions
-        );
+        $this->assertInstanceOf(OptionsPropertyMainGroup::class, $generalOptions);
 
         $this->assertEquals(
             'structure',
@@ -181,10 +179,7 @@ class ExportOdtTest extends AbstractTestCase
 
         $property = array_shift($generalProperties);
 
-        $this->assertInstanceOf(
-            BoolPropertyItem::class,
-            $property
-        );
+        $this->assertInstanceOf(BoolPropertyItem::class, $property);
 
         $this->assertEquals(
             'relation',
@@ -198,10 +193,7 @@ class ExportOdtTest extends AbstractTestCase
 
         $property = array_shift($generalProperties);
 
-        $this->assertInstanceOf(
-            BoolPropertyItem::class,
-            $property
-        );
+        $this->assertInstanceOf(BoolPropertyItem::class, $property);
 
         $this->assertEquals(
             'comments',
@@ -215,10 +207,7 @@ class ExportOdtTest extends AbstractTestCase
 
         $property = array_shift($generalProperties);
 
-        $this->assertInstanceOf(
-            BoolPropertyItem::class,
-            $property
-        );
+        $this->assertInstanceOf(BoolPropertyItem::class, $property);
 
         $this->assertEquals(
             'mime',
@@ -233,10 +222,7 @@ class ExportOdtTest extends AbstractTestCase
         // hide structure
         $generalOptions = array_shift($generalOptionsArray);
 
-        $this->assertInstanceOf(
-            OptionsPropertyMainGroup::class,
-            $generalOptions
-        );
+        $this->assertInstanceOf(OptionsPropertyMainGroup::class, $generalOptions);
 
         $this->assertEquals(
             'data',
@@ -257,10 +243,7 @@ class ExportOdtTest extends AbstractTestCase
 
         $property = array_shift($generalProperties);
 
-        $this->assertInstanceOf(
-            BoolPropertyItem::class,
-            $property
-        );
+        $this->assertInstanceOf(BoolPropertyItem::class, $property);
 
         $this->assertEquals(
             'columns',
@@ -274,10 +257,7 @@ class ExportOdtTest extends AbstractTestCase
 
         $property = array_shift($generalProperties);
 
-        $this->assertInstanceOf(
-            TextPropertyItem::class,
-            $property
-        );
+        $this->assertInstanceOf(TextPropertyItem::class, $property);
 
         $this->assertEquals(
             'null',
@@ -297,10 +277,7 @@ class ExportOdtTest extends AbstractTestCase
 
         $generalOptionsArray = $options->getProperties();
 
-        $this->assertCount(
-            3,
-            $generalOptionsArray
-        );
+        $this->assertCount(3, $generalOptionsArray);
     }
 
     public function testExportHeader(): void
@@ -309,14 +286,8 @@ class ExportOdtTest extends AbstractTestCase
             $this->object->exportHeader()
         );
 
-        $this->assertStringContainsString(
-            '<office:document-content',
-            $GLOBALS['odt_buffer']
-        );
-        $this->assertStringContainsString(
-            'office:version',
-            $GLOBALS['odt_buffer']
-        );
+        $this->assertStringContainsString('<office:document-content', $GLOBALS['odt_buffer']);
+        $this->assertStringContainsString('office:version', $GLOBALS['odt_buffer']);
     }
 
     public function testExportFooter(): void
@@ -330,10 +301,7 @@ class ExportOdtTest extends AbstractTestCase
             $this->object->exportFooter()
         );
 
-        $this->assertStringContainsString(
-            'header',
-            $GLOBALS['odt_buffer']
-        );
+        $this->assertStringContainsString('header', $GLOBALS['odt_buffer']);
 
         $this->assertStringContainsString(
             '</office:text></office:body></office:document-content>',
@@ -349,15 +317,9 @@ class ExportOdtTest extends AbstractTestCase
             $this->object->exportDBHeader('d&b')
         );
 
-        $this->assertStringContainsString(
-            'header',
-            $GLOBALS['odt_buffer']
-        );
+        $this->assertStringContainsString('header', $GLOBALS['odt_buffer']);
 
-        $this->assertStringContainsString(
-            'Database d&amp;b</text:h>',
-            $GLOBALS['odt_buffer']
-        );
+        $this->assertStringContainsString('Database d&amp;b</text:h>', $GLOBALS['odt_buffer']);
     }
 
     public function testExportDBFooter(): void
@@ -382,68 +344,44 @@ class ExportOdtTest extends AbstractTestCase
 
         $flags = [];
         $a = new stdClass();
-        $a->type = '';
-        $flags[] = $a;
+        $flags[] = new FieldMetadata(-1, 0, $a);
 
         $a = new stdClass();
-        $a->type = '';
-        $a->blob = true;
-        $flags[] = $a;
+        $a->charsetnr = 63;
+        $flags[] = new FieldMetadata(MYSQLI_TYPE_BLOB, MYSQLI_BLOB_FLAG, $a);
 
-        $a = new stdClass();
-        $a->numeric = true;
-        $a->type = 'real';
-        $a->blob = false;
-        $flags[] = $a;
+        $flags[] = new FieldMetadata(MYSQLI_TYPE_DECIMAL, MYSQLI_NUM_FLAG, (object) []);
 
-        $a = new stdClass();
-        $a->type = 'timestamp';
-        $a->blob = false;
-        $a->numeric = false;
-        $flags[] = $a;
+        $flags[] = new FieldMetadata(MYSQLI_TYPE_STRING, 0, (object) []);
+
+        $resultStub = $this->createMock(DummyResult::class);
 
         $dbi->expects($this->once())
             ->method('getFieldsMeta')
-            ->with(true)
+            ->with($resultStub)
             ->will($this->returnValue($flags));
 
-        $dbi->expects($this->at(4))
-            ->method('fieldFlags')
-            ->will($this->returnValue('BINARYTEST'));
-
-        $dbi->expects($this->at(5))
-            ->method('fieldFlags')
-            ->will($this->returnValue('binary'));
-
         $dbi->expects($this->once())
             ->method('query')
             ->with('SELECT', DatabaseInterface::CONNECT_USER, DatabaseInterface::QUERY_UNBUFFERED)
-            ->will($this->returnValue(true));
+            ->will($this->returnValue($resultStub));
 
-        $dbi->expects($this->once())
+        $resultStub->expects($this->once())
             ->method('numFields')
-            ->with(true)
             ->will($this->returnValue(4));
 
-        $dbi->expects($this->at(7))
+        $resultStub->expects($this->exactly(2))
             ->method('fetchRow')
-            ->with(true)
-            ->will(
-                $this->returnValue(
-                    [
-                        null,
-                        'a<b',
-                        'a>b',
-                        'a&b',
-                    ]
-                )
+            ->willReturnOnConsecutiveCalls(
+                [
+                    null,
+                    'a<b',
+                    'a>b',
+                    'a&b',
+                ],
+                []
             );
 
-        $dbi->expects($this->at(8))
-            ->method('fetchRow')
-            ->with(true)
-            ->will($this->returnValue(null));
-
         $GLOBALS['dbi'] = $dbi;
         $GLOBALS['what'] = 'foo';
         $GLOBALS['foo_null'] = '&';
@@ -482,42 +420,34 @@ class ExportOdtTest extends AbstractTestCase
             ->getMock();
 
         $flags = [];
+        $a = new stdClass();
+        $a->name = 'fna\"me';
+        $a->length = 20;
+        $flags[] = new FieldMetadata(MYSQLI_TYPE_STRING, 0, $a);
+        $b = new stdClass();
+        $b->name = 'fnam/<e2';
+        $b->length = 20;
+        $flags[] = new FieldMetadata(MYSQLI_TYPE_STRING, 0, $b);
+
+        $resultStub = $this->createMock(DummyResult::class);
 
         $dbi->expects($this->once())
             ->method('getFieldsMeta')
-            ->with(true)
+            ->with($resultStub)
             ->will($this->returnValue($flags));
 
-        $dbi->expects($this->any())
-            ->method('fieldFlags')
-            ->will($this->returnValue('BINARYTEST'));
-
         $dbi->expects($this->once())
             ->method('query')
             ->with('SELECT', DatabaseInterface::CONNECT_USER, DatabaseInterface::QUERY_UNBUFFERED)
-            ->will($this->returnValue(true));
+            ->will($this->returnValue($resultStub));
 
-        $dbi->expects($this->once())
+        $resultStub->expects($this->once())
             ->method('numFields')
-            ->with(true)
             ->will($this->returnValue(2));
 
-        $dbi->expects($this->at(5))
-            ->method('fieldName')
-            ->will($this->returnValue('fna\"me'));
-
-        $dbi->expects($this->at(6))
-            ->method('fieldName')
-            ->will($this->returnValue('fnam/<e2'));
-
-        $dbi->expects($this->at(7))
+        $resultStub->expects($this->exactly(1))
             ->method('fetchRow')
-            ->with(true)
-            ->will(
-                $this->returnValue(
-                    null
-                )
-            );
+            ->will($this->returnValue([]));
 
         $GLOBALS['dbi'] = $dbi;
         $GLOBALS['what'] = 'foo';
@@ -552,29 +482,25 @@ class ExportOdtTest extends AbstractTestCase
 
         $flags = [];
 
+        $resultStub = $this->createMock(DummyResult::class);
+
         $dbi->expects($this->once())
             ->method('getFieldsMeta')
-            ->with(true)
+            ->with($resultStub)
             ->will($this->returnValue($flags));
 
         $dbi->expects($this->once())
             ->method('query')
             ->with('SELECT', DatabaseInterface::CONNECT_USER, DatabaseInterface::QUERY_UNBUFFERED)
-            ->will($this->returnValue(true));
+            ->will($this->returnValue($resultStub));
 
-        $dbi->expects($this->once())
+        $resultStub->expects($this->once())
             ->method('numFields')
-            ->with(true)
             ->will($this->returnValue(0));
 
-        $dbi->expects($this->once())
+        $resultStub->expects($this->once())
             ->method('fetchRow')
-            ->with(true)
-            ->will(
-                $this->returnValue(
-                    null
-                )
-            );
+            ->will($this->returnValue([]));
 
         $GLOBALS['dbi'] = $dbi;
         $GLOBALS['mediawiki_caption'] = true;
@@ -605,45 +531,36 @@ class ExportOdtTest extends AbstractTestCase
 
     public function testGetTableDefStandIn(): void
     {
-        $dbi = $this->getMockBuilder(DatabaseInterface::class)
-            ->disableOriginalConstructor()
-            ->getMock();
-
-        $dbi->expects($this->once())
-            ->method('getColumns')
-            ->with('db', 'v&w')
-            ->will($this->returnValue([1, 2]));
-
-        $GLOBALS['dbi'] = $dbi;
-
-        $this->object = $this->getMockBuilder(ExportOdt::class)
-            ->disableOriginalConstructor()
-            ->setMethods(['formatOneColumnDefinition'])
-            ->getMock();
-
-        $this->object->expects($this->at(0))
-            ->method('formatOneColumnDefinition')
-            ->with(1)
-            ->will($this->returnValue('c1'));
-
-        $this->object->expects($this->at(1))
-            ->method('formatOneColumnDefinition')
-            ->with(2)
-            ->will($this->returnValue('c2'));
-
+        $this->dummyDbi->addSelectDb('test_db');
         $this->assertSame(
-            $this->object->getTableDefStandIn('db', 'v&w', '#'),
+            $this->object->getTableDefStandIn('test_db', 'test_table', "\n"),
             ''
         );
+        $this->assertAllSelectsConsumed();
 
-        $this->assertStringContainsString(
-            '<table:table table:name="v&amp;w_data">',
-            $GLOBALS['odt_buffer']
-        );
-
-        $this->assertStringContainsString(
-            '</table:table-row>c1</table:table-row>c2</table:table-row>' .
-            '</table:table>',
+        $this->assertEquals(
+            '<table:table table:name="test_table_data">'
+            . '<table:table-column table:number-columns-repeated="4"/><table:table-row>'
+            . '<table:table-cell office:value-type="string"><text:p>Column</text:p>'
+            . '</table:table-cell><table:table-cell office:value-type="string"><text:p>Type</text:p>'
+            . '</table:table-cell><table:table-cell office:value-type="string"><text:p>Null</text:p>'
+            . '</table:table-cell><table:table-cell office:value-type="string"><text:p>Default</text:p>'
+            . '</table:table-cell></table:table-row><table:table-row>'
+            . '<table:table-cell office:value-type="string"><text:p>id</text:p></table:table-cell>'
+            . '<table:table-cell office:value-type="string"><text:p>int(11)</text:p></table:table-cell>'
+            . '<table:table-cell office:value-type="string"><text:p>No</text:p></table:table-cell>'
+            . '<table:table-cell office:value-type="string"><text:p>NULL</text:p></table:table-cell>'
+            . '</table:table-row><table:table-row>'
+            . '<table:table-cell office:value-type="string"><text:p>name</text:p></table:table-cell>'
+            . '<table:table-cell office:value-type="string"><text:p>varchar(20)</text:p></table:table-cell>'
+            . '<table:table-cell office:value-type="string"><text:p>No</text:p></table:table-cell>'
+            . '<table:table-cell office:value-type="string"><text:p>NULL</text:p></table:table-cell>'
+            . '</table:table-row><table:table-row>'
+            . '<table:table-cell office:value-type="string"><text:p>datetimefield</text:p></table:table-cell>'
+            . '<table:table-cell office:value-type="string"><text:p>datetime</text:p></table:table-cell>'
+            . '<table:table-cell office:value-type="string"><text:p>No</text:p></table:table-cell>'
+            . '<table:table-cell office:value-type="string"><text:p>NULL</text:p></table:table-cell>'
+            . '</table:table-row></table:table>',
             $GLOBALS['odt_buffer']
         );
     }
@@ -651,11 +568,13 @@ class ExportOdtTest extends AbstractTestCase
     public function testGetTableDef(): void
     {
         $this->object = $this->getMockBuilder(ExportOdt::class)
-            ->setMethods(['formatOneColumnDefinition'])
+            ->onlyMethods(['formatOneColumnDefinition'])
             ->getMock();
 
         // case 1
 
+        $resultStub = $this->createMock(DummyResult::class);
+
         $dbi = $this->getMockBuilder(DatabaseInterface::class)
             ->disableOriginalConstructor()
             ->getMock();
@@ -679,23 +598,17 @@ class ExportOdtTest extends AbstractTestCase
             ->with('database', '')
             ->will($this->returnValue([$columns]));
 
-        $dbi->expects($this->any())
-            ->method('query')
-            ->will($this->returnValue(true));
+        $dbi->expects($this->once())
+            ->method('tryQueryAsControlUser')
+            ->will($this->returnValue($resultStub));
 
-        $dbi->expects($this->any())
+        $resultStub->expects($this->once())
             ->method('numRows')
             ->will($this->returnValue(1));
 
-        $dbi->expects($this->any())
+        $resultStub->expects($this->once())
             ->method('fetchAssoc')
-            ->will(
-                $this->returnValue(
-                    [
-                        'comment' => ['fieldname' => 'testComment'],
-                    ]
-                )
-            );
+            ->will($this->returnValue(['comment' => 'testComment']));
 
         $GLOBALS['dbi'] = $dbi;
         $this->object->relation = new Relation($dbi);
@@ -705,16 +618,16 @@ class ExportOdtTest extends AbstractTestCase
             ->with(['Field' => 'fieldname'])
             ->will($this->returnValue(1));
 
-        $GLOBALS['cfgRelation']['relation'] = true;
-        $_SESSION['relation'][0] = [
-            'PMA_VERSION' => PMA_VERSION,
+        $_SESSION['relation'] = [];
+        $_SESSION['relation'][$GLOBALS['server']] = RelationParameters::fromArray([
             'relwork' => true,
             'commwork' => true,
             'mimework' => true,
             'db' => 'database',
             'relation' => 'rel',
             'column_info' => 'col',
-        ];
+        ])->toArray();
+
         $this->assertTrue(
             $this->object->getTableDef(
                 'database',
@@ -728,20 +641,17 @@ class ExportOdtTest extends AbstractTestCase
         );
 
         $this->assertStringContainsString(
-            '<table:table table:name="_structure"><table:table-column ' .
-            'table:number-columns-repeated="6"/>',
+            '<table:table table:name="_structure"><table:table-column table:number-columns-repeated="6"/>',
             $GLOBALS['odt_buffer']
         );
 
         $this->assertStringContainsString(
-            '<table:table-cell office:value-type="string"><text:p>Comments' .
-            '</text:p></table:table-cell>',
+            '<table:table-cell office:value-type="string"><text:p>Comments</text:p></table:table-cell>',
             $GLOBALS['odt_buffer']
         );
 
         $this->assertStringContainsString(
-            '<table:table-cell office:value-type="string"><text:p>Media type' .
-            '</text:p></table:table-cell>',
+            '<table:table-cell office:value-type="string"><text:p>Media type</text:p></table:table-cell>',
             $GLOBALS['odt_buffer']
         );
 
@@ -755,6 +665,8 @@ class ExportOdtTest extends AbstractTestCase
 
         // case 2
 
+        $resultStub = $this->createMock(DummyResult::class);
+
         $dbi = $this->getMockBuilder(DatabaseInterface::class)
             ->disableOriginalConstructor()
             ->getMock();
@@ -784,37 +696,30 @@ class ExportOdtTest extends AbstractTestCase
             ->with('database', '')
             ->will($this->returnValue([$columns]));
 
-        $dbi->expects($this->any())
-            ->method('query')
-            ->will($this->returnValue(true));
+        $dbi->expects($this->once())
+            ->method('tryQueryAsControlUser')
+            ->will($this->returnValue($resultStub));
 
-        $dbi->expects($this->any())
+        $resultStub->expects($this->once())
             ->method('numRows')
             ->will($this->returnValue(1));
 
-        $dbi->expects($this->any())
+        $resultStub->expects($this->once())
             ->method('fetchAssoc')
-            ->will(
-                $this->returnValue(
-                    [
-                        'comment' => ['field' => 'testComment'],
-                    ]
-                )
-            );
+            ->will($this->returnValue(['comment' => 'testComment']));
 
         $GLOBALS['dbi'] = $dbi;
         $this->object->relation = new Relation($dbi);
         $GLOBALS['odt_buffer'] = '';
-        $GLOBALS['cfgRelation']['relation'] = true;
-        $_SESSION['relation'][0] = [
-            'PMA_VERSION' => PMA_VERSION,
+        $_SESSION['relation'] = [];
+        $_SESSION['relation'][$GLOBALS['server']] = RelationParameters::fromArray([
             'relwork' => true,
             'commwork' => true,
             'mimework' => true,
             'db' => 'database',
             'relation' => 'rel',
             'column_info' => 'col',
-        ];
+        ])->toArray();
 
         $this->assertTrue(
             $this->object->getTableDef(
@@ -828,10 +733,7 @@ class ExportOdtTest extends AbstractTestCase
             )
         );
 
-        $this->assertStringContainsString(
-            '<text:p>ftable (ffield)</text:p>',
-            $GLOBALS['odt_buffer']
-        );
+        $this->assertStringContainsString('<text:p>ftable (ffield)</text:p>', $GLOBALS['odt_buffer']);
     }
 
     public function testGetTriggers(): void
@@ -862,95 +764,57 @@ class ExportOdtTest extends AbstractTestCase
 
         $this->assertSame($result, $GLOBALS['odt_buffer']);
 
-        $this->assertStringContainsString(
-            '<table:table table:name="ta&lt;ble_triggers">',
-            $result
-        );
+        $this->assertStringContainsString('<table:table table:name="ta&lt;ble_triggers">', $result);
 
-        $this->assertStringContainsString(
-            '<text:p>tna&quot;me</text:p>',
-            $result
-        );
+        $this->assertStringContainsString('<text:p>tna&quot;me</text:p>', $result);
 
-        $this->assertStringContainsString(
-            '<text:p>ac&gt;t</text:p>',
-            $result
-        );
+        $this->assertStringContainsString('<text:p>ac&gt;t</text:p>', $result);
 
-        $this->assertStringContainsString(
-            '<text:p>manip&amp;</text:p>',
-            $result
-        );
+        $this->assertStringContainsString('<text:p>manip&amp;</text:p>', $result);
 
-        $this->assertStringContainsString(
-            '<text:p>def</text:p>',
-            $result
-        );
+        $this->assertStringContainsString('<text:p>def</text:p>', $result);
     }
 
     public function testExportStructure(): void
     {
-        $dbi = $this->getMockBuilder(DatabaseInterface::class)
-            ->disableOriginalConstructor()
-            ->getMock();
-
-        $dbi->expects($this->once())
-            ->method('getTriggers')
-            ->with('db', 't&bl')
-            ->will($this->returnValue(1));
-
-        $this->object = $this->getMockBuilder(ExportOdt::class)
-            ->setMethods(['getTableDef', 'getTriggers', 'getTableDefStandIn'])
-            ->getMock();
-
-        $this->object->expects($this->at(0))
-            ->method('getTableDef')
-            ->with('db', 't&bl', "\n", 'example.com', false, false, false, false)
-            ->will($this->returnValue('dumpText1'));
-
-        $this->object->expects($this->once())
-            ->method('getTriggers')
-            ->with('db', 't&bl')
-            ->will($this->returnValue('dumpText2'));
-
-        $this->object->expects($this->at(2))
-            ->method('getTableDef')
-            ->with(
-                'db',
-                't&bl',
-                "\n",
-                'example.com',
-                false,
-                false,
-                false,
-                false,
-                true,
-                true
-            )
-            ->will($this->returnValue('dumpText3'));
-
-        $this->object->expects($this->once())
-            ->method('getTableDefStandIn')
-            ->with('db', 't&bl', "\n")
-            ->will($this->returnValue('dumpText4'));
-
-        $GLOBALS['dbi'] = $dbi;
-
         // case 1
+        $this->dummyDbi->addSelectDb('test_db');
         $this->assertTrue(
             $this->object->exportStructure(
-                'db',
-                't&bl',
+                'test_db',
+                'test_table',
                 "\n",
-                'example.com',
+                'localhost',
                 'create_table',
                 'test'
             )
         );
+        $this->assertAllSelectsConsumed();
 
-        $this->assertStringContainsString(
-            '<text:h text:outline-level="2" text:style-name="Heading_2" ' .
-            'text:is-list-header="true">Table structure for table t&amp;bl</text:h>',
+        $this->assertEquals(
+            '<text:h text:outline-level="2" text:style-name="Heading_2" text:is-list-header="true">'
+            . 'Table structure for table test_table</text:h><table:table table:name="test_table_structure">'
+            . '<table:table-column table:number-columns-repeated="4"/><table:table-row>'
+            . '<table:table-cell office:value-type="string"><text:p>Column</text:p></table:table-cell>'
+            . '<table:table-cell office:value-type="string"><text:p>Type</text:p></table:table-cell>'
+            . '<table:table-cell office:value-type="string"><text:p>Null</text:p></table:table-cell>'
+            . '<table:table-cell office:value-type="string"><text:p>Default</text:p></table:table-cell>'
+            . '</table:table-row><table:table-row>'
+            . '<table:table-cell office:value-type="string"><text:p>id</text:p></table:table-cell>'
+            . '<table:table-cell office:value-type="string"><text:p>int(11)</text:p></table:table-cell>'
+            . '<table:table-cell office:value-type="string"><text:p>No</text:p></table:table-cell>'
+            . '<table:table-cell office:value-type="string"><text:p>NULL</text:p></table:table-cell>'
+            . '</table:table-row><table:table-row>'
+            . '<table:table-cell office:value-type="string"><text:p>name</text:p></table:table-cell>'
+            . '<table:table-cell office:value-type="string"><text:p>varchar(20)</text:p></table:table-cell>'
+            . '<table:table-cell office:value-type="string"><text:p>No</text:p></table:table-cell>'
+            . '<table:table-cell office:value-type="string"><text:p>NULL</text:p></table:table-cell>'
+            . '</table:table-row><table:table-row>'
+            . '<table:table-cell office:value-type="string"><text:p>datetimefield</text:p></table:table-cell>'
+            . '<table:table-cell office:value-type="string"><text:p>datetime</text:p></table:table-cell>'
+            . '<table:table-cell office:value-type="string"><text:p>No</text:p></table:table-cell>'
+            . '<table:table-cell office:value-type="string"><text:p>NULL</text:p></table:table-cell>'
+            . '</table:table-row></table:table>',
             $GLOBALS['odt_buffer']
         );
 
@@ -959,67 +823,121 @@ class ExportOdtTest extends AbstractTestCase
 
         $this->assertTrue(
             $this->object->exportStructure(
-                'db',
-                't&bl',
+                'test_db',
+                'test_table',
                 "\n",
-                'example.com',
+                'localhost',
                 'triggers',
                 'test'
             )
         );
 
         $this->assertEquals(
-            '<text:h text:outline-level="2" text:style-name="Heading_2" ' .
-            'text:is-list-header="true">Triggers t&amp;bl</text:h>',
+            '<text:h text:outline-level="2" text:style-name="Heading_2" text:is-list-header="true">'
+            . 'Triggers test_table</text:h><table:table table:name="test_table_triggers">'
+            . '<table:table-column table:number-columns-repeated="4"/><table:table-row>'
+            . '<table:table-cell office:value-type="string"><text:p>Name</text:p></table:table-cell>'
+            . '<table:table-cell office:value-type="string"><text:p>Time</text:p></table:table-cell>'
+            . '<table:table-cell office:value-type="string"><text:p>Event</text:p></table:table-cell>'
+            . '<table:table-cell office:value-type="string"><text:p>Definition</text:p></table:table-cell>'
+            . '</table:table-row><table:table-row>'
+            . '<table:table-cell office:value-type="string"><text:p>test_trigger</text:p></table:table-cell>'
+            . '<table:table-cell office:value-type="string"><text:p>AFTER</text:p></table:table-cell>'
+            . '<table:table-cell office:value-type="string"><text:p>INSERT</text:p></table:table-cell>'
+            . '<table:table-cell office:value-type="string"><text:p>BEGIN END</text:p></table:table-cell>'
+            . '</table:table-row></table:table>',
             $GLOBALS['odt_buffer']
         );
 
         // case 3
         $GLOBALS['odt_buffer'] = '';
 
+        $this->dummyDbi->addSelectDb('test_db');
         $this->assertTrue(
             $this->object->exportStructure(
-                'db',
-                't&bl',
+                'test_db',
+                'test_table',
                 "\n",
-                'example.com',
+                'localhost',
                 'create_view',
                 'test'
             )
         );
+        $this->assertAllSelectsConsumed();
 
         $this->assertEquals(
-            '<text:h text:outline-level="2" text:style-name="Heading_2" ' .
-            'text:is-list-header="true">Structure for view t&amp;bl</text:h>',
+            '<text:h text:outline-level="2" text:style-name="Heading_2" text:is-list-header="true">'
+            . 'Structure for view test_table</text:h><table:table table:name="test_table_structure">'
+            . '<table:table-column table:number-columns-repeated="4"/><table:table-row>'
+            . '<table:table-cell office:value-type="string"><text:p>Column</text:p></table:table-cell>'
+            . '<table:table-cell office:value-type="string"><text:p>Type</text:p></table:table-cell>'
+            . '<table:table-cell office:value-type="string"><text:p>Null</text:p></table:table-cell>'
+            . '<table:table-cell office:value-type="string"><text:p>Default</text:p></table:table-cell>'
+            . '</table:table-row><table:table-row>'
+            . '<table:table-cell office:value-type="string"><text:p>id</text:p></table:table-cell>'
+            . '<table:table-cell office:value-type="string"><text:p>int(11)</text:p></table:table-cell>'
+            . '<table:table-cell office:value-type="string"><text:p>No</text:p></table:table-cell>'
+            . '<table:table-cell office:value-type="string"><text:p>NULL</text:p></table:table-cell>'
+            . '</table:table-row><table:table-row>'
+            . '<table:table-cell office:value-type="string"><text:p>name</text:p></table:table-cell>'
+            . '<table:table-cell office:value-type="string"><text:p>varchar(20)</text:p></table:table-cell>'
+            . '<table:table-cell office:value-type="string"><text:p>No</text:p></table:table-cell>'
+            . '<table:table-cell office:value-type="string"><text:p>NULL</text:p></table:table-cell>'
+            . '</table:table-row><table:table-row>'
+            . '<table:table-cell office:value-type="string"><text:p>datetimefield</text:p></table:table-cell>'
+            . '<table:table-cell office:value-type="string"><text:p>datetime</text:p></table:table-cell>'
+            . '<table:table-cell office:value-type="string"><text:p>No</text:p></table:table-cell>'
+            . '<table:table-cell office:value-type="string"><text:p>NULL</text:p></table:table-cell>'
+            . '</table:table-row></table:table>',
             $GLOBALS['odt_buffer']
         );
 
         // case 4
+        $this->dummyDbi->addSelectDb('test_db');
         $GLOBALS['odt_buffer'] = '';
         $this->assertTrue(
             $this->object->exportStructure(
-                'db',
-                't&bl',
+                'test_db',
+                'test_table',
                 "\n",
-                'example.com',
+                'localhost',
                 'stand_in',
                 'test'
             )
         );
+        $this->assertAllSelectsConsumed();
 
         $this->assertEquals(
-            '<text:h text:outline-level="2" text:style-name="Heading_2" text:is' .
-            '-list-header="true">Stand-in structure for view t&amp;bl</text:h>',
+            '<text:h text:outline-level="2" text:style-name="Heading_2" text:is-list-header="true">'
+            . 'Stand-in structure for view test_table</text:h><table:table table:name="test_table_data">'
+            . '<table:table-column table:number-columns-repeated="4"/><table:table-row>'
+            . '<table:table-cell office:value-type="string"><text:p>Column</text:p></table:table-cell>'
+            . '<table:table-cell office:value-type="string"><text:p>Type</text:p></table:table-cell>'
+            . '<table:table-cell office:value-type="string"><text:p>Null</text:p></table:table-cell>'
+            . '<table:table-cell office:value-type="string"><text:p>Default</text:p></table:table-cell>'
+            . '</table:table-row><table:table-row>'
+            . '<table:table-cell office:value-type="string"><text:p>id</text:p></table:table-cell>'
+            . '<table:table-cell office:value-type="string"><text:p>int(11)</text:p></table:table-cell>'
+            . '<table:table-cell office:value-type="string"><text:p>No</text:p></table:table-cell>'
+            . '<table:table-cell office:value-type="string"><text:p>NULL</text:p></table:table-cell>'
+            . '</table:table-row><table:table-row>'
+            . '<table:table-cell office:value-type="string"><text:p>name</text:p></table:table-cell>'
+            . '<table:table-cell office:value-type="string"><text:p>varchar(20)</text:p></table:table-cell>'
+            . '<table:table-cell office:value-type="string"><text:p>No</text:p></table:table-cell>'
+            . '<table:table-cell office:value-type="string"><text:p>NULL</text:p></table:table-cell>'
+            . '</table:table-row><table:table-row>'
+            . '<table:table-cell office:value-type="string"><text:p>datetimefield</text:p></table:table-cell>'
+            . '<table:table-cell office:value-type="string"><text:p>datetime</text:p></table:table-cell>'
+            . '<table:table-cell office:value-type="string"><text:p>No</text:p></table:table-cell>'
+            . '<table:table-cell office:value-type="string"><text:p>NULL</text:p></table:table-cell>'
+            . '</table:table-row></table:table>',
             $GLOBALS['odt_buffer']
         );
     }
 
     public function testFormatOneColumnDefinition(): void
     {
-        $method = new ReflectionMethod(
-            ExportOdt::class,
-            'formatOneColumnDefinition'
-        );
+        $method = new ReflectionMethod(ExportOdt::class, 'formatOneColumnDefinition');
         $method->setAccessible(true);
 
         $cols = [
