@@ -7,6 +7,9 @@ namespace PhpMyAdmin\Tests\Plugins\Export\Helpers;
 use PhpMyAdmin\Plugins\Export\Helpers\TableProperty;
 use PhpMyAdmin\Tests\AbstractTestCase;
 
+/**
+ * @covers \PhpMyAdmin\Plugins\Export\Helpers\TableProperty
+ */
 class TablePropertyTest extends AbstractTestCase
 {
     /** @var TableProperty */
@@ -41,35 +44,17 @@ class TablePropertyTest extends AbstractTestCase
 
     public function testConstructor(): void
     {
-        $this->assertEquals(
-            'name',
-            $this->object->name
-        );
+        $this->assertEquals('name', $this->object->name);
 
-        $this->assertEquals(
-            'int',
-            $this->object->type
-        );
+        $this->assertEquals('int', $this->object->type);
 
-        $this->assertEquals(
-            1,
-            $this->object->nullable
-        );
+        $this->assertEquals(1, $this->object->nullable);
 
-        $this->assertEquals(
-            'PRI',
-            $this->object->key
-        );
+        $this->assertEquals('PRI', $this->object->key);
 
-        $this->assertEquals(
-            '0',
-            $this->object->defaultValue
-        );
+        $this->assertEquals('0', $this->object->defaultValue);
 
-        $this->assertEquals(
-            'mysql',
-            $this->object->ext
-        );
+        $this->assertEquals('mysql', $this->object->ext);
     }
 
     public function testGetPureType(): void
@@ -375,8 +360,7 @@ class TablePropertyTest extends AbstractTestCase
         $this->assertEquals(
             'NameintInt32intfalsetrue',
             $this->object->format(
-                '#ucfirstName##dotNetPrimitiveType##dotNetObjectType##type#' .
-                '#notNull##unique#'
+                '#ucfirstName##dotNetPrimitiveType##dotNetObjectType##type##notNull##unique#'
             )
         );
     }
