@@ -7,9 +7,12 @@ namespace PhpMyAdmin\Tests\Plugins\Import;
 use PhpMyAdmin\File;
 use PhpMyAdmin\Plugins\Import\ImportOds;
 use PhpMyAdmin\Tests\AbstractTestCase;
+
+use function __;
 use function str_repeat;
 
 /**
+ * @covers \PhpMyAdmin\Plugins\Import\ImportOds
  * @requires extension zip
  */
 class ImportOdsTest extends AbstractTestCase
@@ -20,13 +23,10 @@ class ImportOdsTest extends AbstractTestCase
     /**
      * Sets up the fixture, for example, opens a network connection.
      * This method is called before a test is executed.
-     *
-     * @access protected
      */
     protected function setUp(): void
     {
         parent::setUp();
-        parent::loadDefaultConfig();
         $GLOBALS['server'] = 0;
         $GLOBALS['plugin_param'] = 'csv';
         $this->object = new ImportOds();
@@ -51,8 +51,6 @@ class ImportOdsTest extends AbstractTestCase
     /**
      * Tears down the fixture, for example, closes a network connection.
      * This method is called after a test is executed.
-     *
-     * @access protected
      */
     protected function tearDown(): void
     {
@@ -107,17 +105,12 @@ class ImportOdsTest extends AbstractTestCase
         $this->object->doImport($importHandle);
 
         $this->assertStringContainsString(
-            'CREATE DATABASE IF NOT EXISTS `ODS_DB` DEFAULT CHARACTER SET '
-            . 'utf8 COLLATE utf8_general_ci',
+            'CREATE DATABASE IF NOT EXISTS `ODS_DB` DEFAULT CHARACTER SET utf8 COLLATE utf8_general_ci',
             $sql_query
         );
+        $this->assertStringContainsString('CREATE TABLE IF NOT EXISTS `ODS_DB`.`pma_bookmark`', $sql_query);
         $this->assertStringContainsString(
-            'CREATE TABLE IF NOT EXISTS `ODS_DB`.`pma_bookmark`',
-            $sql_query
-        );
-        $this->assertStringContainsString(
-            'INSERT INTO `ODS_DB`.`pma_bookmark` (`A`, `B`, `C`, `D`) VALUES '
-            . "(1, 'dbbase', NULL, 'ddd');",
+            'INSERT INTO `ODS_DB`.`pma_bookmark` (`A`, `B`, `C`, `D`) VALUES (1, \'dbbase\', NULL, \'ddd\');',
             $sql_query
         );
 
@@ -126,27 +119,13 @@ class ImportOdsTest extends AbstractTestCase
             'The following structures have either been created or altered.',
             $import_notice
         );
-        $this->assertStringContainsString(
-            'Go to database: `ODS_DB`',
-            $import_notice
-        );
-        $this->assertStringContainsString(
-            'Edit settings for `ODS_DB`',
-            $import_notice
-        );
-        $this->assertStringContainsString(
-            'Go to table: `pma_bookmark`',
-            $import_notice
-        );
-        $this->assertStringContainsString(
-            'Edit settings for `pma_bookmark`',
-            $import_notice
-        );
+        $this->assertStringContainsString('Go to database: `ODS_DB`', $import_notice);
+        $this->assertStringContainsString('Edit settings for `ODS_DB`', $import_notice);
+        $this->assertStringContainsString('Go to table: `pma_bookmark`', $import_notice);
+        $this->assertStringContainsString('Edit settings for `pma_bookmark`', $import_notice);
 
         //asset that the import process is finished
-        $this->assertTrue(
-            $GLOBALS['finished']
-        );
+        $this->assertTrue($GLOBALS['finished']);
     }
 
     public function dataProviderOdsEmptyRows(): array
@@ -162,6 +141,7 @@ class ImportOdsTest extends AbstractTestCase
      *
      * @group medium
      * @dataProvider dataProviderOdsEmptyRows
+     * @requires extension simplexml
      */
     public function testDoImportDataset2(bool $odsEmptyRowsMode): void
     {
@@ -182,14 +162,10 @@ class ImportOdsTest extends AbstractTestCase
 
         // The process could probably detect that all the values for columns V to BL are empty
         // That would make the empty columns not needed and would create a cleaner structure
-        $nulls = '';
-        $nullCells = '';
-        $nullCellNames = '';
 
         $endOfSql = ');;';
 
         if (! $odsEmptyRowsMode) {
-            $nulls = '';
             $fullCols = 'NULL' . str_repeat(', NULL', 18);// 19 empty cells
             $endOfSql = '),' . "\n" . ' (' . $fullCols . '),' . "\n" . ' (' . $fullCols . ');;';
         }
@@ -205,7 +181,7 @@ class ImportOdsTest extends AbstractTestCase
             . ' `Wirkstoff` varchar(10), `verkuerztHaltbar` varchar(21), `kuehlkette` varchar(7),'
             . ' `Gebinde` varchar(71), `Verbrauchsnachweis` varchar(7), `Genehmigungspflichtig` varchar(7),'
             . ' `Gefahrstoff` varchar(11), `GefahrArbeitsbereich` varchar(14), `Verwendungszweck` varchar(10),'
-            . ' `Verbrauch` varchar(10), `showLagerbestand` varchar(7)' . $nullCells . ') '
+            . ' `Verbrauch` varchar(10), `showLagerbestand` varchar(7)) '
             . 'DEFAULT CHARACTER SET utf8 COLLATE utf8_general_ci;;'
             . 'CREATE TABLE IF NOT EXISTS `ODS_DB`.`Feuille 1` (`value` varchar(19)) '
             . 'DEFAULT CHARACTER SET utf8 COLLATE utf8_general_ci;;'
@@ -213,36 +189,28 @@ class ImportOdsTest extends AbstractTestCase
             . '`Artikelnummer`, `Name`, `keywords`, `EK_Preis`, `Preis`, `Details`, `addInfo`, `Einheit`,'
             . ' `Wirkstoff`, `verkuerztHaltbar`, `kuehlkette`, `Gebinde`, `Verbrauchsnachweis`,'
             . ' `Genehmigungspflichtig`, `Gefahrstoff`, `GefahrArbeitsbereich`, `Verwendungszweck`,'
-            . ' `Verbrauch`, `showLagerbestand`' . $nullCellNames . ') VALUES ('
+            . ' `Verbrauch`, `showLagerbestand`) VALUES ('
             . 'NULL, NULL, \'Schlüsselwörter\', \'Einkaufspreis (Netto)\', \'VK-Preis (Orientierung)\', NULL,'
             . ' \'Hintergrundinformation\', \'VPE\', NULL, \'verkürzte Haltbarkeit\', \'ja/nein\','
             . ' \'Stück,Rolle,Pack,Flasche,Sack,Eimer,Karton,Palette,Beutel,Kanister,Paar\', \'ja/nein\','
-            . ' \'ja/nein\', \'GHS01-GHS09\', \'Arbeitsbereich\', NULL, NULL, \'ja/nein\''
-            . $nulls . '),' . "\n"
+            . ' \'ja/nein\', \'GHS01-GHS09\', \'Arbeitsbereich\', NULL, NULL, \'ja/nein\'),' . "\n"
             . ' (\'1005\', \'Beatmungsfilter\', NULL, \'0.85\', \'1,2\', NULL, NULL, \'5\', NULL, NULL, \'nein\','
-            . ' \'Stück\', \'nein\', \'nein\', NULL, NULL, NULL, NULL, \'ja\'' . $nulls . '),' . "\n"
+            . ' \'Stück\', \'nein\', \'nein\', NULL, NULL, NULL, NULL, \'ja\'),' . "\n"
             . ' (\'04-3-06\', \'Absaugkatheter, CH06 grün\', NULL, \'0.13\', \'0,13\', NULL, NULL, \'1\','
             . ' NULL, NULL,'
-            . ' NULL, \'Stück\', \'nein\', \'nein\', NULL, NULL, NULL, NULL, \'ja\''
-            . $nulls . '),' . "\n"
+            . ' NULL, \'Stück\', \'nein\', \'nein\', NULL, NULL, NULL, NULL, \'ja\'),' . "\n"
             . ' (\'04-3-10\', \'Absaugkatheter, CH10 schwarz\', NULL, \'0.13\', \'0,13\', NULL, NULL, \'1\','
-            . ' NULL, NULL, NULL, \'Stück\', \'nein\', \'nein\', NULL, NULL, NULL, NULL, \'ja\''
-             . $nulls . '),' . "\n"
+            . ' NULL, NULL, NULL, \'Stück\', \'nein\', \'nein\', NULL, NULL, NULL, NULL, \'ja\'),' . "\n"
             . ' (\'04-3-18\', \'Absaugkatheter, CH18 rot\', NULL, \'0.13\', \'0,13\', NULL, NULL, \'1\','
-            . ' NULL, NULL, NULL, \'Stück\', \'nein\', \'nein\', NULL, NULL, NULL, NULL, \'ja\''
-             . $nulls . '),' . "\n"
+            . ' NULL, NULL, NULL, \'Stück\', \'nein\', \'nein\', NULL, NULL, NULL, NULL, \'ja\'),' . "\n"
             . ' (\'06-38\', \'Bakterienfilter\', NULL, \'1.25\', \'1,25\', NULL, NULL, \'1\', NULL, NULL, NULL,'
-            . ' \'Stück\', \'nein\', \'nein\', NULL, NULL, NULL, NULL, \'ja\''
-            . $nulls . '),' . "\n"
+            . ' \'Stück\', \'nein\', \'nein\', NULL, NULL, NULL, NULL, \'ja\'),' . "\n"
             . ' (\'05-453\', \'Blockerspritze für Larynxtubus, Erwachsen\', NULL, \'2.6\', \'2,6\', NULL, NULL,'
-            . ' \'1\', NULL, NULL, NULL, \'Stück\', \'nein\', \'nein\', NULL, NULL, NULL, NULL, \'ja\''
-             . $nulls . '),' . "\n"
+            . ' \'1\', NULL, NULL, NULL, \'Stück\', \'nein\', \'nein\', NULL, NULL, NULL, NULL, \'ja\'),' . "\n"
             . ' (\'04-402\', \'Absaugschlauch mit Fingertip für Accuvac\', NULL, \'1.7\', \'1,7\', NULL, NULL,'
-            . ' \'1\', NULL, NULL, NULL, \'Stück\', \'nein\', \'nein\', NULL, NULL, NULL, NULL, \'ja\''
-             . $nulls . '),' . "\n"
+            . ' \'1\', NULL, NULL, NULL, \'Stück\', \'nein\', \'nein\', NULL, NULL, NULL, NULL, \'ja\'),' . "\n"
             . ' (\'02-580\', \'Einmalbeatmungsbeutel, Erwachsen\', NULL, \'8.9\', \'8,9\', NULL, NULL,'
             . ' \'1\', NULL, NULL, NULL, \'Stück\', \'nein\', \'nein\', NULL, NULL, NULL, NULL, \'ja\''
-             . $nulls
              . $endOfSql
              . 'INSERT INTO `ODS_DB`.`Feuille 1` (`value`) VALUES ('
              . '\'test@example.org\'),' . "\n"
@@ -266,26 +234,12 @@ class ImportOdsTest extends AbstractTestCase
             'The following structures have either been created or altered.',
             $import_notice
         );
-        $this->assertStringContainsString(
-            'Go to database: `ODS_DB`',
-            $import_notice
-        );
-        $this->assertStringContainsString(
-            'Edit settings for `ODS_DB`',
-            $import_notice
-        );
-        $this->assertStringContainsString(
-            'Go to table: `Shop`',
-            $import_notice
-        );
-        $this->assertStringContainsString(
-            'Edit settings for `Shop`',
-            $import_notice
-        );
+        $this->assertStringContainsString('Go to database: `ODS_DB`', $import_notice);
+        $this->assertStringContainsString('Edit settings for `ODS_DB`', $import_notice);
+        $this->assertStringContainsString('Go to table: `Shop`', $import_notice);
+        $this->assertStringContainsString('Edit settings for `Shop`', $import_notice);
 
         //asset that the import process is finished
-        $this->assertTrue(
-            $GLOBALS['finished']
-        );
+        $this->assertTrue($GLOBALS['finished']);
     }
 }
