@@ -1,52 +1,39 @@
 <?php
-/* vim: set expandtab sw=4 ts=4 sts=4: */
-/**
- * tests for PhpMyAdmin\Properties\Options\Groups\OptionsPropertyMainGroup class
- *
- * @package PhpMyAdmin-test
- */
+
 declare(strict_types=1);
 
 namespace PhpMyAdmin\Tests\Properties\Options\Groups;
 
 use PhpMyAdmin\Properties\Options\Groups\OptionsPropertyMainGroup;
-use PHPUnit\Framework\TestCase;
+use PhpMyAdmin\Tests\AbstractTestCase;
 
 /**
- * tests for PhpMyAdmin\Properties\Options\Groups\OptionsPropertyMainGroup class
- *
- * @package PhpMyAdmin-test
+ * @covers \PhpMyAdmin\Properties\Options\Groups\OptionsPropertyMainGroup
  */
-class OptionsPropertyMainGroupTest extends TestCase
+class OptionsPropertyMainGroupTest extends AbstractTestCase
 {
+    /** @var OptionsPropertyMainGroup */
     protected $object;
 
     /**
      * Configures global environment.
-     *
-     * @return void
      */
     protected function setUp(): void
     {
+        parent::setUp();
         $this->object = new OptionsPropertyMainGroup();
     }
 
     /**
      * tearDown for test cases
-     *
-     * @return void
      */
     protected function tearDown(): void
     {
+        parent::tearDown();
         unset($this->object);
     }
 
-    /**
-     * Test for PhpMyAdmin\Properties\Options\Groups\OptionsPropertyMainGroup::getItemType
-     *
-     * @return void
-     */
-    public function testGetItemType()
+    public function testGetItemType(): void
     {
         $this->assertEquals(
             'main',
