@@ -1,48 +1,42 @@
 <?php
-/* vim: set expandtab sw=4 ts=4 sts=4: */
-/**
- * Test class for Theme.
- *
- * @package PhpMyAdmin-test
- */
+
 declare(strict_types=1);
 
 namespace PhpMyAdmin\Tests;
 
-use PhpMyAdmin\Config;
-use PhpMyAdmin\Tests\PmaTestCase;
 use PhpMyAdmin\Theme;
+use PhpMyAdmin\ThemeManager;
+
+use function filemtime;
+
+use const DIRECTORY_SEPARATOR;
+use const TEST_PATH;
 
 /**
- * Test class for Theme.
- *
- * @package PhpMyAdmin-test
+ * @covers \PhpMyAdmin\Theme
  */
-class ThemeTest extends PmaTestCase
+class ThemeTest extends AbstractTestCase
 {
-    /**
-     * @var Theme
-     */
+    /** @var Theme */
     protected $object;
 
-    /**
-     * @var Theme backup for session theme
-     */
+    /** @var Theme backup for session theme */
     protected $backup;
 
     /**
      * Sets up the fixture, for example, opens a network connection.
      * This method is called before a test is executed.
-     *
-     * @return void
      */
     protected function setUp(): void
     {
+        global $theme;
+
+        parent::setUp();
+        parent::setTheme();
         $this->object = new Theme();
-        $this->backup = $GLOBALS['PMA_Theme'];
-        $GLOBALS['PMA_Theme'] = $this->object;
-        $GLOBALS['PMA_Config'] = new Config();
-        $GLOBALS['PMA_Config']->enableBc();
+        $this->backup = $theme;
+        $theme = $this->object;
+        parent::setGlobalConfig();
         $GLOBALS['text_dir'] = 'ltr';
         $GLOBALS['server'] = '99';
     }
@@ -50,21 +44,21 @@ class ThemeTest extends PmaTestCase
     /**
      * Tears down the fixture, for example, closes a network connection.
      * This method is called after a test is executed.
-     *
-     * @return void
      */
     protected function tearDown(): void
     {
-        $GLOBALS['PMA_Theme'] = $this->backup;
+        global $theme;
+
+        parent::tearDown();
+        $theme = $this->backup;
     }
 
     /**
      * Test for Theme::loadInfo
      *
-     * @return void
      * @group medium
      */
-    public function testCheckImgPathNotExisted()
+    public function testCheckImgPathNotExisted(): void
     {
         $this->object->setPath('path/to/nowhere');
         $this->assertFalse($this->object->loadInfo());
@@ -72,10 +66,8 @@ class ThemeTest extends PmaTestCase
 
     /**
      * Test for Theme::loadInfo
-     *
-     * @return void
      */
-    public function testCheckImgPathIncorrect()
+    public function testCheckImgPathIncorrect(): void
     {
         $this->object->setPath(ROOT_PATH . 'test/classes/_data/incorrect_theme');
         $this->assertFalse(
@@ -86,23 +78,19 @@ class ThemeTest extends PmaTestCase
 
     /**
      * Test for Theme::getName, getVersion
-     *
-     * @return void
      */
-    public function testCheckImgPathFull()
+    public function testCheckImgPathFull(): void
     {
-        $this->object->setFsPath(ROOT_PATH . 'test/classes/_data/gen_version_info/');
+        $this->object->setFsPath(TEST_PATH . 'test/classes/_data/gen_version_info/');
         $this->assertTrue($this->object->loadInfo());
         $this->assertEquals('Test Theme', $this->object->getName());
-        $this->assertEquals('5.0', $this->object->getVersion());
+        $this->assertEquals('5.1', $this->object->getVersion());
     }
 
     /**
      * Test for Theme::loadInfo
-     *
-     * @return void
      */
-    public function testLoadInfo()
+    public function testLoadInfo(): void
     {
         $this->object->setFsPath(ROOT_PATH . 'themes/original/');
         $infofile = $this->object->getFsPath() . 'theme.json';
@@ -110,42 +98,47 @@ class ThemeTest extends PmaTestCase
 
         $this->assertEquals(
             filemtime($infofile),
-            $this->object->mtime_info
+            $this->object->mtimeInfo
         );
 
         $this->object->setPath(ROOT_PATH . 'themes/original');
-        $this->object->mtime_info = filemtime($infofile);
+        $this->object->mtimeInfo = (int) filemtime($infofile);
         $this->assertTrue($this->object->loadInfo());
         $this->assertEquals('Original', $this->object->getName());
     }
 
     /**
      * Test for Theme::load
-     *
-     * @return void
      */
-    public function testLoad()
+    public function testLoad(): void
     {
-        $newTheme = Theme::load('./themes/original', ROOT_PATH . 'themes/original');
+        $newTheme = Theme::load(
+            ThemeManager::getThemesDir() . 'original',
+            ThemeManager::getThemesFsDir() . 'original' . DIRECTORY_SEPARATOR,
+            'original'
+        );
         $this->assertNotNull($newTheme);
+        $this->assertInstanceOf(Theme::class, $newTheme);
     }
 
     /**
      * Test for Theme::load
-     *
-     * @return void
      */
-    public function testLoadNotExisted()
+    public function testLoadNonExistent(): void
     {
-        $this->assertFalse(Theme::load('/path/to/nowhere', '/path/to/nowhere'));
+        $this->assertNull(
+            Theme::load(
+                ThemeManager::getThemesDir() . 'nonexistent',
+                ThemeManager::getThemesFsDir() . 'nonexistent' . DIRECTORY_SEPARATOR,
+                'nonexistent'
+            )
+        );
     }
 
     /**
      * Test fir Theme::checkImgPath
-     *
-     * @return void
      */
-    public function testCheckImgPathFallback()
+    public function testCheckImgPathFallback(): void
     {
         $this->object->setPath('path/to/nowhere');
         $this->assertTrue($this->object->checkImgPath());
@@ -153,10 +146,8 @@ class ThemeTest extends PmaTestCase
 
     /**
      * Test for Theme::checkImgPath
-     *
-     * @return void
      */
-    public function testCheckImgPath()
+    public function testCheckImgPath(): void
     {
         $this->object->setPath(ROOT_PATH . 'themes/original');
         $this->assertTrue($this->object->checkImgPath());
@@ -164,10 +155,8 @@ class ThemeTest extends PmaTestCase
 
     /**
      * Test for Theme::getPath
-     *
-     * @return void
      */
-    public function testGetSetPath()
+    public function testGetSetPath(): void
     {
         $this->assertEmpty($this->object->getPath());
         $this->object->setPath(ROOT_PATH . 'themes/original');
@@ -178,11 +167,9 @@ class ThemeTest extends PmaTestCase
     /**
      * Test for Theme::checkVersion
      *
-     * @return void
-     *
      * @depends testLoadInfo
      */
-    public function testGetSetCheckVersion()
+    public function testGetSetCheckVersion(): void
     {
         $this->assertEquals(
             '0.0.0.0',
@@ -190,19 +177,17 @@ class ThemeTest extends PmaTestCase
             'Version 0.0.0.0 by default'
         );
 
-        $this->object->setVersion("1.2.3.4");
+        $this->object->setVersion('1.2.3.4');
         $this->assertEquals('1.2.3.4', $this->object->getVersion());
 
-        $this->assertFalse($this->object->checkVersion("0.0.1.1"));
-        $this->assertTrue($this->object->checkVersion("2.0.1.1"));
+        $this->assertFalse($this->object->checkVersion('0.0.1.1'));
+        $this->assertTrue($this->object->checkVersion('2.0.1.1'));
     }
 
     /**
      * Test for Theme::getName
-     *
-     * @return void
      */
-    public function testGetSetName()
+    public function testGetSetName(): void
     {
         $this->assertEmpty($this->object->getName(), 'Name is empty by default');
         $this->object->setName('New Theme Name');
@@ -212,10 +197,8 @@ class ThemeTest extends PmaTestCase
 
     /**
      * Test for Theme::getId
-     *
-     * @return void
      */
-    public function testGetSetId()
+    public function testGetSetId(): void
     {
         $this->assertEmpty($this->object->getId(), 'ID is empty by default');
         $this->object->setId('NewID');
@@ -225,10 +208,8 @@ class ThemeTest extends PmaTestCase
 
     /**
      * Test for Theme::getImgPath
-     *
-     * @return void
      */
-    public function testGetSetImgPath()
+    public function testGetSetImgPath(): void
     {
         $this->assertEmpty(
             $this->object->getImgPath(),
@@ -239,39 +220,16 @@ class ThemeTest extends PmaTestCase
         $this->assertEquals('/new/path', $this->object->getImgPath());
     }
 
-    /**
-     * Test for getPrintPreview().
-     *
-     * @return void
-     */
-    public function testGetPrintPreview()
-    {
-        $this->assertStringContainsString(
-            '<h2>' . "\n" . '         (0.0.0.0)',
-            $this->object->getPrintPreview()
-        );
-        $this->assertStringContainsString(
-            'name="" href="index.php?set_theme=&amp;server=99&amp;lang=en">',
-            $this->object->getPrintPreview()
-        );
-        $this->assertStringContainsString(
-            'No preview available.',
-            $this->object->getPrintPreview()
-        );
-    }
-
     /**
      * Test for getImgPath
      *
-     * @param string $file     file name for image
-     * @param string $fallback fallback image
-     * @param string $output   expected output
-     *
-     * @return void
+     * @param string|null $file     file name for image
+     * @param string|null $fallback fallback image
+     * @param string      $output   expected output
      *
      * @dataProvider providerForGetImgPath
      */
-    public function testGetImgPath($file, $fallback, $output): void
+    public function testGetImgPath(?string $file, ?string $fallback, string $output): void
     {
         $this->assertEquals(
             $this->object->getImgPath($file, $fallback),
@@ -284,7 +242,7 @@ class ThemeTest extends PmaTestCase
      *
      * @return array
      */
-    public function providerForGetImgPath()
+    public function providerForGetImgPath(): array
     {
         return [
             [
