@@ -4,23 +4,25 @@ declare(strict_types=1);
 
 namespace PhpMyAdmin\Tests;
 
+use PhpMyAdmin\Cache;
+use PhpMyAdmin\ConfigStorage\RelationParameters;
 use PhpMyAdmin\DatabaseInterface;
+use PhpMyAdmin\Tests\Stubs\DummyResult;
 use PhpMyAdmin\Tracker;
 use PhpMyAdmin\Util;
 use ReflectionMethod;
-use ReflectionProperty;
 
+/**
+ * @covers \PhpMyAdmin\Tracker
+ */
 class TrackerTest extends AbstractTestCase
 {
     /**
      * Setup function for test cases
-     *
-     * @access protected
      */
     protected function setUp(): void
     {
         parent::setUp();
-        parent::defineVersionConstants();
         /**
          * SET these to avoid undefined index error
          */
@@ -32,11 +34,12 @@ class TrackerTest extends AbstractTestCase
         $GLOBALS['cfg']['Server']['tracking_version_auto_create'] = '';
         $GLOBALS['cfg']['Server']['DisableIS'] = false;
 
-        $_SESSION['relation'][$GLOBALS['server']] = [
-            'PMA_VERSION' => PMA_VERSION,
+        $_SESSION['relation'] = [];
+        $_SESSION['relation'][$GLOBALS['server']] = RelationParameters::fromArray([
             'db' => 'pmadb',
+            'trackingwork' => true,
             'tracking' => 'tracking',
-        ];
+        ])->toArray();
 
         $dbi = $this->getMockBuilder(DatabaseInterface::class)
             ->disableOriginalConstructor()
@@ -50,12 +53,12 @@ class TrackerTest extends AbstractTestCase
      */
     public function testEnabled(): void
     {
-        $reflection = new ReflectionProperty(Tracker::class, 'enabled');
-        $reflection->setAccessible(true);
-
+        $this->assertFalse(
+            Cache::has(Tracker::TRACKER_ENABLED_CACHE_KEY)
+        );
         Tracker::enable();
         $this->assertTrue(
-            $reflection->getValue()
+            Cache::get(Tracker::TRACKER_ENABLED_CACHE_KEY)
         );
     }
 
@@ -64,9 +67,9 @@ class TrackerTest extends AbstractTestCase
      */
     public function testIsActive(): void
     {
-        $attr = new ReflectionProperty(Tracker::class, 'enabled');
-        $attr->setAccessible(true);
-        $attr->setValue(false);
+        $this->assertFalse(
+            Cache::has(Tracker::TRACKER_ENABLED_CACHE_KEY)
+        );
 
         $this->assertFalse(
             Tracker::isActive()
@@ -74,21 +77,19 @@ class TrackerTest extends AbstractTestCase
 
         Tracker::enable();
 
-        $_SESSION['relation'][$GLOBALS['server']] = [
-            'PMA_VERSION' => PMA_VERSION,
-            'trackingwork' => false,
-        ];
+        $_SESSION['relation'] = [];
+        $_SESSION['relation'][$GLOBALS['server']] = RelationParameters::fromArray([])->toArray();
 
         $this->assertFalse(
             Tracker::isActive()
         );
 
-        $_SESSION['relation'][$GLOBALS['server']] = [
-            'PMA_VERSION' => PMA_VERSION,
+        $_SESSION['relation'] = [];
+        $_SESSION['relation'][$GLOBALS['server']] = RelationParameters::fromArray([
             'trackingwork' => true,
             'db' => 'pmadb',
             'tracking' => 'tracking',
-        ];
+        ])->toArray();
 
         $this->assertTrue(
             Tracker::isActive()
@@ -139,9 +140,9 @@ class TrackerTest extends AbstractTestCase
      */
     public function testIsTracked(): void
     {
-        $attr = new ReflectionProperty(Tracker::class, 'enabled');
-        $attr->setAccessible(true);
-        $attr->setValue(false);
+        $this->assertFalse(
+            Cache::has(Tracker::TRACKER_ENABLED_CACHE_KEY)
+        );
 
         $this->assertFalse(
             Tracker::isTracked('', '')
@@ -149,14 +150,19 @@ class TrackerTest extends AbstractTestCase
 
         Tracker::enable();
 
-        $_SESSION['relation'][$GLOBALS['server']]['PMA_VERSION'] = PMA_VERSION;
-        $_SESSION['relation'][$GLOBALS['server']]['trackingwork'] = false;
+        $_SESSION['relation'] = [];
+        $_SESSION['relation'][$GLOBALS['server']] = RelationParameters::fromArray([])->toArray();
 
         $this->assertFalse(
             Tracker::isTracked('', '')
         );
 
-        $_SESSION['relation'][$GLOBALS['server']]['trackingwork'] = true;
+        $_SESSION['relation'] = [];
+        $_SESSION['relation'][$GLOBALS['server']] = RelationParameters::fromArray([
+            'trackingwork' => true,
+            'db' => 'pmadb',
+            'tracking' => 'tracking',
+        ])->toArray();
 
         $this->assertTrue(
             Tracker::isTracked('pma_test_db', 'pma_test_table')
@@ -190,6 +196,8 @@ class TrackerTest extends AbstractTestCase
         $GLOBALS['cfg']['Server']['tracking_add_drop_view'] = true;
         $GLOBALS['cfg']['Server']['user'] = 'pma_test_user';
 
+        $resultStub = $this->createMock(DummyResult::class);
+
         $dbi = $this->getMockBuilder(DatabaseInterface::class)
             ->disableOriginalConstructor()
             ->getMock();
@@ -234,51 +242,10 @@ class TrackerTest extends AbstractTestCase
                 ['USE `pma_test`'],
                 ['SHOW CREATE TABLE `pma_test`.`pma_tbl`']
             )
-            ->willReturnOnConsecutiveCalls(
-                'res',
-                'res',
-                'res'
-            );
-
-        $date = Util::date('Y-m-d H:i:s');
-
-        $expectedMainQuery = '/*NOTRACK*/' .
-        "\nINSERT INTO `pmadb`.`tracking` (db_name, table_name, version, date_created, date_updated," .
-        " schema_snapshot, schema_sql, data_sql, tracking ) values (
-        'pma_test',
-        'pma_tbl',
-        '1',
-        '" . $date . "',
-        '" . $date . "',
-        'a:2:{s:7:\"COLUMNS\";a:2:{" .
-        'i:0;a:3:{s:5:"Field";s:6:"field1";s:4:"Type";s:7:"int(11)";' .
-        's:3:"Key";s:3:"PRI";}' .
-        'i:1;a:3:{s:5:"Field";s:6:"field2";s:4:"Type";s:4:"text";' .
-        's:3:"Key";s:0:"";}}' .
-        's:7:"INDEXES";a:1:{' .
-        'i:0;a:3:{s:5:"Table";s:7:"pma_tbl";s:5:"Field";s:6:"field1";' .
-        "s:3:\"Key\";s:7:\"PRIMARY\";}}}',
-        '# log " . $date . ' pma_test_user' .
-        "\nDROP VIEW IF EXISTS `pma_tbl`;" .
-        "\n# log " . $date . ' pma_test_user' .
-        "\n\n;" .
-        "\n',
-        '" .
-        "\n',
-        '11' )";
-
-        $queryResults = [
-            [
-                $expectedMainQuery,
-                DatabaseInterface::CONNECT_CONTROL,
-                0,
-                false,
-                'executed',
-            ],
-        ];
+            ->willReturnOnConsecutiveCalls($resultStub, $resultStub, $resultStub);
 
         $dbi->expects($this->any())->method('query')
-            ->will($this->returnValueMap($queryResults));
+            ->will($this->returnValue($resultStub));
 
         $dbi->expects($this->any())->method('escapeString')
             ->will($this->returnArgument(0));
@@ -286,10 +253,7 @@ class TrackerTest extends AbstractTestCase
             ->will($this->returnValue([]));
 
         $GLOBALS['dbi'] = $dbi;
-        $this->assertEquals(
-            'executed',
-            Tracker::createVersion('pma_test', 'pma_tbl', '1', '11', true)
-        );
+        $this->assertTrue(Tracker::createVersion('pma_test', 'pma_tbl', '1', '11', true));
     }
 
     /**
@@ -297,6 +261,8 @@ class TrackerTest extends AbstractTestCase
      */
     public function testDeleteTracking(): void
     {
+        $resultStub = $this->createMock(DummyResult::class);
+
         $dbi = $this->getMockBuilder(DatabaseInterface::class)
             ->disableOriginalConstructor()
             ->getMock();
@@ -307,17 +273,14 @@ class TrackerTest extends AbstractTestCase
             . " AND `table_name` = 'testtable'";
 
         $dbi->expects($this->exactly(1))
-            ->method('query')
+            ->method('queryAsControlUser')
             ->with($sql_query)
-            ->will($this->returnValue('executed'));
+            ->will($this->returnValue($resultStub));
         $dbi->expects($this->any())->method('escapeString')
             ->will($this->returnArgument(0));
 
         $GLOBALS['dbi'] = $dbi;
-        $this->assertEquals(
-            Tracker::deleteTracking('testdb', 'testtable'),
-            'executed'
-        );
+        $this->assertTrue(Tracker::deleteTracking('testdb', 'testtable'));
     }
 
     /**
@@ -329,40 +292,28 @@ class TrackerTest extends AbstractTestCase
         $GLOBALS['cfg']['Server']['tracking_add_drop_view'] = true;
         $GLOBALS['cfg']['Server']['user'] = 'pma_test_user';
 
+        $resultStub = $this->createMock(DummyResult::class);
+
         $dbi = $this->getMockBuilder(DatabaseInterface::class)
             ->disableOriginalConstructor()
             ->getMock();
 
-        $date = Util::date('Y-m-d H:i:s');
-
-        $expectedMainQuery = '/*NOTRACK*/' .
-        "\nINSERT INTO `pmadb`.`tracking` (db_name, table_name, version, date_created, date_updated," .
-        " schema_snapshot, schema_sql, data_sql, tracking ) values (
-        'pma_test',
-        '',
-        '1',
-        '" . $date . "',
-        '" . $date . "',
-        '',
-        '# log " . $date . ' pma_test_user' .
-        "\nSHOW DATABASES',
-        '" .
-        "\n',
-        'CREATE DATABASE,ALTER DATABASE,DROP DATABASE' )";
+        $expectedMainQuery = '/*NOTRACK*/' . "\n" . 'INSERT INTO `pmadb`.`tracking` (db_name, table_name, version,'
+            . ' date_created, date_updated, schema_snapshot, schema_sql, data_sql, tracking)'
+            . ' values (\'pma_test\', \'\', \'1\', \'%d-%d-%d %d:%d:%d\', \'%d-%d-%d %d:%d:%d\','
+            . ' \'\', \'# log %d-%d-%d %d:%d:%d pma_test_user' . "\n" . 'SHOW DATABASES\', \'' . "\n"
+            . '\', \'CREATE DATABASE,ALTER DATABASE,DROP DATABASE\')';
 
         $dbi->expects($this->exactly(1))
-            ->method('query')
-            ->with($expectedMainQuery, DatabaseInterface::CONNECT_CONTROL, 0, false)
-            ->will($this->returnValue('executed'));
+            ->method('queryAsControlUser')
+            ->with($this->matches($expectedMainQuery))
+            ->will($this->returnValue($resultStub));
 
         $dbi->expects($this->any())->method('escapeString')
             ->will($this->returnArgument(0));
 
         $GLOBALS['dbi'] = $dbi;
-        $this->assertEquals(
-            'executed',
-            Tracker::createDatabaseVersion('pma_test', '1', 'SHOW DATABASES')
-        );
+        $this->assertTrue(Tracker::createDatabaseVersion('pma_test', '1', 'SHOW DATABASES'));
     }
 
     /**
@@ -386,44 +337,35 @@ class TrackerTest extends AbstractTestCase
             ->disableOriginalConstructor()
             ->getMock();
 
-        $sql_query = ' UPDATE `pmadb`.`tracking` SET `tracking_active` = ' .
-        "'" . $new_state . "' " .
-        " WHERE `db_name` = '" . $dbname . "' " .
-        " AND `table_name` = '" . $tablename . "' " .
-        " AND `version` = '" . $version . "' ";
+        $resultStub = $this->createMock(DummyResult::class);
+
+        $sql_query = 'UPDATE `pmadb`.`tracking` SET `tracking_active` = ' .
+        "'" . $new_state . "'" .
+        " WHERE `db_name` = '" . $dbname . "'" .
+        " AND `table_name` = '" . $tablename . "'" .
+        " AND `version` = '" . $version . "'";
 
         $dbi->expects($this->exactly(1))
-            ->method('query')
-            ->with($sql_query, DatabaseInterface::CONNECT_CONTROL, 0, false)
-            ->will($this->returnValue('executed'));
+            ->method('queryAsControlUser')
+            ->with($sql_query)
+            ->will($this->returnValue($resultStub));
 
         $dbi->expects($this->any())->method('escapeString')
             ->will($this->returnArgument(0));
 
         $GLOBALS['dbi'] = $dbi;
 
-        $result = null;
-
         if ($type === null) {
             $method = new ReflectionMethod(Tracker::class, 'changeTracking');
             $method->setAccessible(true);
-            $result = $method->invoke(
-                null,
-                $dbname,
-                $tablename,
-                $version,
-                $new_state
-            );
+            $method->invoke(null, $dbname, $tablename, $version, $new_state);
         } elseif ($type === 'activate') {
-            $result = Tracker::activateTracking($dbname, $tablename, $version);
+            Tracker::activateTracking($dbname, $tablename, $version);
         } elseif ($type === 'deactivate') {
-            $result = Tracker::deactivateTracking($dbname, $tablename, $version);
+            Tracker::deactivateTracking($dbname, $tablename, $version);
         }
 
-        $this->assertEquals(
-            'executed',
-            $result
-        );
+        // What's the success criteria? What is the expected result?
     }
 
     /**
@@ -439,13 +381,13 @@ class TrackerTest extends AbstractTestCase
             ->disableOriginalConstructor()
             ->getMock();
 
-        $sql_query_1 = ' UPDATE `pmadb`.`tracking`' .
-        " SET `schema_sql` = '# new_data_processed' " .
-        " WHERE `db_name` = 'pma_db' " .
-        " AND `table_name` = 'pma_table' " .
-        " AND `version` = '1.0' ";
+        $sql_query_1 = 'UPDATE `pmadb`.`tracking`' .
+        " SET `schema_sql` = '# new_data_processed'" .
+        " WHERE `db_name` = 'pma_db'" .
+        " AND `table_name` = 'pma_table'" .
+        " AND `version` = '1.0'";
 
-        $date  = Util::date('Y-m-d H:i:s');
+        $date = Util::date('Y-m-d H:i:s');
 
         $new_data = [
             [
@@ -458,30 +400,27 @@ class TrackerTest extends AbstractTestCase
             ],
         ];
 
-        $sql_query_2 = ' UPDATE `pmadb`.`tracking`' .
+        $sql_query_2 = 'UPDATE `pmadb`.`tracking`' .
         " SET `data_sql` = '# log " . $date . " user1test_statement1\n" .
-        '# log ' . $date . " user2test_statement2\n' " .
-        " WHERE `db_name` = 'pma_db' " .
-        " AND `table_name` = 'pma_table' " .
-        " AND `version` = '1.0' ";
+        '# log ' . $date . " user2test_statement2\n'" .
+        " WHERE `db_name` = 'pma_db'" .
+        " AND `table_name` = 'pma_table'" .
+        " AND `version` = '1.0'";
 
-        $dbi->method('query')
+        $resultStub1 = $this->createMock(DummyResult::class);
+        $resultStub2 = $this->createMock(DummyResult::class);
+
+        $dbi->method('queryAsControlUser')
             ->will(
                 $this->returnValueMap(
                     [
                         [
                             $sql_query_1,
-                            DatabaseInterface::CONNECT_CONTROL,
-                            0,
-                            false,
-                            'executed_1',
+                            $resultStub1,
                         ],
                         [
                             $sql_query_2,
-                            DatabaseInterface::CONNECT_CONTROL,
-                            0,
-                            false,
-                            'executed_2',
+                            $resultStub2,
                         ],
                     ]
                 )
@@ -539,17 +478,18 @@ class TrackerTest extends AbstractTestCase
      */
     public function testGetTrackedData(array $fetchArrayReturn, array $expectedArray): void
     {
+        $resultStub = $this->createMock(DummyResult::class);
+
         $dbi = $this->getMockBuilder(DatabaseInterface::class)
             ->disableOriginalConstructor()
             ->getMock();
 
         $dbi->expects($this->once())
-            ->method('query')
-            ->will($this->returnValue('executed_1'));
+            ->method('queryAsControlUser')
+            ->will($this->returnValue($resultStub));
 
-        $dbi->expects($this->once())
+        $resultStub->expects($this->once())
             ->method('fetchAssoc')
-            ->with('executed_1')
             ->will($this->returnValue($fetchArrayReturn));
 
         $dbi->expects($this->any())
@@ -576,10 +516,7 @@ class TrackerTest extends AbstractTestCase
         $GLOBALS['dbi'] = $dbi;
         $result = Tracker::getTrackedData("pma'db", "pma'table", '1.0');
 
-        $this->assertEquals(
-            $expectedArray,
-            $result
-        );
+        $this->assertEquals($expectedArray, $result);
     }
 
     /**
@@ -695,36 +632,21 @@ class TrackerTest extends AbstractTestCase
     ): void {
         $result = Tracker::parseQuery($query);
 
-        $this->assertEquals(
-            $type,
-            $result['type']
-        );
+        $this->assertEquals($type, $result['type']);
 
-        $this->assertEquals(
-            $identifier,
-            $result['identifier']
-        );
+        $this->assertEquals($identifier, $result['identifier']);
 
-        $this->assertEquals(
-            $tablename,
-            $result['tablename']
-        );
+        $this->assertEquals($tablename, $result['tablename']);
 
         if ($db) {
-            $this->assertEquals(
-                $db,
-                $GLOBALS['db']
-            );
+            $this->assertEquals($db, $GLOBALS['db']);
         }
 
         if (! $tablename_after_rename) {
             return;
         }
 
-        $this->assertEquals(
-            $result['tablename_after_rename'],
-            $tablename_after_rename
-        );
+        $this->assertEquals($result['tablename_after_rename'], $tablename_after_rename);
     }
 
     /**
@@ -741,7 +663,7 @@ class TrackerTest extends AbstractTestCase
         // db (optional)
         // table name after rename (optional)
         $query = [];
-        /** TODO: Should test fail when USE is in conjunction with * identifiers?
+        /* TODO: Should test fail when USE is in conjunction with * identifiers?
         $query[] = array(
             " - USE db1;\n- CREATE VIEW db1.v AS SELECT * FROM t;",
             "DDL",
@@ -800,49 +722,49 @@ class TrackerTest extends AbstractTestCase
             'CREATE TABLE',
             't1',
         ];
-        $query[] =  [
+        $query[] = [
             'ALTER TABLE db1.t1 ADD c2 TEXT;',
             'DDL',
             'ALTER TABLE',
             't1',
         ];
-        $query[] =  [
+        $query[] = [
             'DROP TABLE db1.t1',
             'DDL',
             'DROP TABLE',
             't1',
         ];
-        $query[] =  [
+        $query[] = [
             'DROP TABLE IF EXISTS db1.t1',
             'DDL',
             'DROP TABLE',
             't1',
         ];
-        $query[] =  [
+        $query[] = [
             'CREATE INDEX ind ON db1.t1 (c2(10));',
             'DDL',
             'CREATE INDEX',
             't1',
         ];
-        $query[] =  [
+        $query[] = [
             'CREATE UNIQUE INDEX ind ON db1.t1 (c2(10));',
             'DDL',
             'CREATE INDEX',
             't1',
         ];
-        $query[] =  [
+        $query[] = [
             'CREATE SPATIAL INDEX ind ON db1.t1 (c2(10));',
             'DDL',
             'CREATE INDEX',
             't1',
         ];
-        $query[] =  [
+        $query[] = [
             'DROP INDEX ind ON db1.t1;',
             'DDL',
             'DROP INDEX',
             't1',
         ];
-        $query[] =  [
+        $query[] = [
             'RENAME TABLE db1.t1 TO db1.t2',
             'DDL',
             'RENAME TABLE',
@@ -850,25 +772,25 @@ class TrackerTest extends AbstractTestCase
             '',
             't2',
         ];
-        $query[] =  [
+        $query[] = [
             'UPDATE db1.t1 SET a = 2',
             'DML',
             'UPDATE',
             't1',
         ];
-        $query[] =  [
+        $query[] = [
             'INSERT INTO db1.t1 (a, b, c) VALUES(1, 2, 3)',
             'DML',
             'INSERT',
             't1',
         ];
-        $query[] =  [
+        $query[] = [
             'DELETE FROM db1.t1',
             'DML',
             'DELETE',
             't1',
         ];
-        $query[] =  [
+        $query[] = [
             'TRUNCATE db1.t1',
             'DML',
             'TRUNCATE',
