@@ -1,7 +1,4 @@
 <?php
-/**
- * Tests for Types.php
- */
 
 declare(strict_types=1);
 
@@ -10,7 +7,7 @@ namespace PhpMyAdmin\Tests;
 use PhpMyAdmin\Types;
 
 /**
- * Testcase for MySQL types handling.
+ * @covers \PhpMyAdmin\Types
  */
 class TypesTest extends AbstractTestCase
 {
@@ -90,6 +87,7 @@ class TypesTest extends AbstractTestCase
                 'LIKE',
                 'LIKE %...%',
                 'NOT LIKE',
+                'NOT LIKE %...%',
                 '=',
                 '!=',
                 'REGEXP',
@@ -122,6 +120,7 @@ class TypesTest extends AbstractTestCase
                 'LIKE',
                 'LIKE %...%',
                 'NOT LIKE',
+                'NOT LIKE %...%',
                 'IN (...)',
                 'NOT IN (...)',
                 'BETWEEN',
@@ -131,6 +130,26 @@ class TypesTest extends AbstractTestCase
         );
     }
 
+    /**
+     * Test for getUUIDOperators
+     */
+    public function testGetUUIDOperators(): void
+    {
+        $this->assertEquals(
+            [
+                '=',
+                '!=',
+                'LIKE',
+                'LIKE %...%',
+                'NOT LIKE',
+                'NOT LIKE %...%',
+                'IN (...)',
+                'NOT IN (...)',
+            ],
+            $this->object->getUUIDOperators()
+        );
+    }
+
     /**
      * Test for getting type operators
      *
@@ -171,6 +190,7 @@ class TypesTest extends AbstractTestCase
                     'LIKE',
                     'LIKE %...%',
                     'NOT LIKE',
+                    'NOT LIKE %...%',
                     '=',
                     '!=',
                     'REGEXP',
@@ -194,6 +214,36 @@ class TypesTest extends AbstractTestCase
                     ],
                 ],
             ],
+            [
+                'UUID',
+                false,
+                [
+                    '=',
+                    '!=',
+                    'LIKE',
+                    'LIKE %...%',
+                    'NOT LIKE',
+                    'NOT LIKE %...%',
+                    'IN (...)',
+                    'NOT IN (...)',
+                ],
+            ],
+            [
+                'UUID',
+                true,
+                [
+                    '=',
+                    '!=',
+                    'LIKE',
+                    'LIKE %...%',
+                    'NOT LIKE',
+                    'NOT LIKE %...%',
+                    'IN (...)',
+                    'NOT IN (...)',
+                    'IS NULL',
+                    'IS NOT NULL',
+                ],
+            ],
         ];
     }
 
@@ -231,8 +281,7 @@ class TypesTest extends AbstractTestCase
                 'enum',
                 false,
                 '=',
-                '<option value="=" selected="selected">=</option>'
-                . '<option value="!=">!=</option>',
+                '<option value="=" selected="selected">=</option><option value="!=">!=</option>',
             ],
         ];
     }
@@ -310,6 +359,9 @@ class TypesTest extends AbstractTestCase
             ['MULTILINESTRING'],
             ['MULTIPOLYGON'],
             ['GEOMETRYCOLLECTION'],
+            ['JSON'],
+            ['INET6'],
+            ['UUID'],
         ];
     }
 
@@ -418,58 +470,58 @@ class TypesTest extends AbstractTestCase
             [
                 'NUMBER',
                 [
-                    '0' => 'ABS',
-                    '1' => 'ACOS',
-                    '2' => 'ASCII',
-                    '3' => 'ASIN',
-                    '4' => 'ATAN',
-                    '5' => 'BIT_LENGTH',
-                    '6' => 'BIT_COUNT',
-                    '7' => 'CEILING',
-                    '8' => 'CHAR_LENGTH',
-                    '9' => 'CONNECTION_ID',
-                    '10' => 'COS',
-                    '11' => 'COT',
-                    '12' => 'CRC32',
-                    '13' => 'DAYOFMONTH',
-                    '14' => 'DAYOFWEEK',
-                    '15' => 'DAYOFYEAR',
-                    '16' => 'DEGREES',
-                    '17' => 'EXP',
-                    '18' => 'FLOOR',
-                    '19' => 'HOUR',
-                    '20' => 'INET6_ATON',
-                    '21' => 'INET_ATON',
-                    '22' => 'LENGTH',
-                    '23' => 'LN',
-                    '24' => 'LOG',
-                    '25' => 'LOG2',
-                    '26' => 'LOG10',
-                    '27' => 'MICROSECOND',
-                    '28' => 'MINUTE',
-                    '29' => 'MONTH',
-                    '30' => 'OCT',
-                    '31' => 'ORD',
-                    '32' => 'PI',
-                    '33' => 'QUARTER',
-                    '34' => 'RADIANS',
-                    '35' => 'RAND',
-                    '36' => 'ROUND',
-                    '37' => 'SECOND',
-                    '38' => 'SIGN',
-                    '39' => 'SIN',
-                    '40' => 'SQRT',
-                    '41' => 'TAN',
-                    '42' => 'TO_DAYS',
-                    '43' => 'TO_SECONDS',
-                    '44' => 'TIME_TO_SEC',
-                    '45' => 'UNCOMPRESSED_LENGTH',
-                    '46' => 'UNIX_TIMESTAMP',
-                    '47' => 'UUID_SHORT',
-                    '48' => 'WEEK',
-                    '49' => 'WEEKDAY',
-                    '50' => 'WEEKOFYEAR',
-                    '51' => 'YEARWEEK',
+                    'ABS',
+                    'ACOS',
+                    'ASCII',
+                    'ASIN',
+                    'ATAN',
+                    'BIT_LENGTH',
+                    'BIT_COUNT',
+                    'CEILING',
+                    'CHAR_LENGTH',
+                    'CONNECTION_ID',
+                    'COS',
+                    'COT',
+                    'CRC32',
+                    'DAYOFMONTH',
+                    'DAYOFWEEK',
+                    'DAYOFYEAR',
+                    'DEGREES',
+                    'EXP',
+                    'FLOOR',
+                    'HOUR',
+                    'INET6_ATON',
+                    'INET_ATON',
+                    'LENGTH',
+                    'LN',
+                    'LOG',
+                    'LOG2',
+                    'LOG10',
+                    'MICROSECOND',
+                    'MINUTE',
+                    'MONTH',
+                    'OCT',
+                    'ORD',
+                    'PI',
+                    'QUARTER',
+                    'RADIANS',
+                    'RAND',
+                    'ROUND',
+                    'SECOND',
+                    'SIGN',
+                    'SIN',
+                    'SQRT',
+                    'TAN',
+                    'TO_DAYS',
+                    'TO_SECONDS',
+                    'TIME_TO_SEC',
+                    'UNCOMPRESSED_LENGTH',
+                    'UNIX_TIMESTAMP',
+                    'UUID_SHORT',
+                    'WEEK',
+                    'WEEKDAY',
+                    'WEEKOFYEAR',
+                    'YEARWEEK',
                 ],
             ],
             [
@@ -682,7 +734,7 @@ class TypesTest extends AbstractTestCase
                 1 => 'VARCHAR',
                 2 => 'TEXT',
                 3 => 'DATE',
-                'Numeric' =>  [
+                'Numeric' => [
                     'TINYINT',
                     'SMALLINT',
                     'MEDIUMINT',
@@ -698,14 +750,14 @@ class TypesTest extends AbstractTestCase
                     'BOOLEAN',
                     'SERIAL',
                 ],
-                'Date and time' =>  [
+                'Date and time' => [
                     'DATE',
                     'DATETIME',
                     'TIMESTAMP',
                     'TIME',
                     'YEAR',
                 ],
-                'String' =>  [
+                'String' => [
                     'CHAR',
                     'VARCHAR',
                     '-',
@@ -725,7 +777,7 @@ class TypesTest extends AbstractTestCase
                     'ENUM',
                     'SET',
                 ],
-                'Spatial' =>  [
+                'Spatial' => [
                     'GEOMETRY',
                     'POINT',
                     'LINESTRING',
@@ -779,6 +831,14 @@ class TypesTest extends AbstractTestCase
                 'SET',
                 'CHAR',
             ],
+            [
+                'JSON',
+                'JSON',
+            ],
+            [
+                'UUID',
+                'UUID',
+            ],
             [
                 'UNKNOWN',
                 '',
