@@ -1,16 +1,11 @@
 <?php
-/**
- * Selenium TestCase for creating and deleting databases
- */
 
 declare(strict_types=1);
 
 namespace PhpMyAdmin\Tests\Selenium;
 
 /**
- * CreateDropDatabaseTest class
- *
- * @group      selenium
+ * @coversNothing
  */
 class CreateDropDatabaseTest extends TestBase
 {
@@ -32,9 +27,7 @@ class CreateDropDatabaseTest extends TestBase
      */
     public function testCreateDropDatabase(): void
     {
-        $this->dbQuery(
-            'DROP DATABASE IF EXISTS `' . $this->databaseName . '`;'
-        );
+        $this->dbQuery('DROP DATABASE IF EXISTS `' . $this->databaseName . '`;');
 
         $this->waitForElement('partialLinkText', 'Databases')->click();
         $this->waitAjax();
@@ -70,26 +63,21 @@ class CreateDropDatabaseTest extends TestBase
 
         $this->scrollToBottom();
 
-        $dbElement = $this->byCssSelector(
-            "input[name='selected_dbs[]'][value='" . $this->databaseName . "']"
-        );
+        $dbElement = $this->byCssSelector("input[name='selected_dbs[]'][value='" . $this->databaseName . "']");
         $this->scrollToElement($dbElement, 0, 20);
         $dbElement->click();
 
-        $multSubmit = $this->byCssSelector('button.mult_submit');
+        $multSubmit = $this->byCssSelector('#bulkActionDropButton');
         $this->scrollToElement($multSubmit);
         $multSubmit->click();
-        $this->byCssSelector('button.submitOK')->click();
+        $this->byCssSelector('#dropDatabaseModalDropButton')->click();
 
         $this->waitForElementNotPresent(
             'cssSelector',
             "input[name='selected_dbs[]'][value='" . $this->databaseName . "']"
         );
 
-        $this->waitForElement(
-            'cssSelector',
-            'span.ajax_notification .alert-success'
-        );
+        $this->waitForElement('cssSelector', 'span.ajax_notification .alert-success');
 
         $this->dbQuery(
             'SHOW DATABASES LIKE \'' . $this->databaseName . '\';',
