@@ -1,20 +1,16 @@
 <?php
-/**
- * Selenium TestCase for table related tests
- */
 
 declare(strict_types=1);
 
 namespace PhpMyAdmin\Tests\Selenium\Database;
 
 use PhpMyAdmin\Tests\Selenium\TestBase;
+
 use function sleep;
 use function str_replace;
 
 /**
- * ProceduresTest class
- *
- * @group      selenium
+ * @coversNothing
  */
 class ProceduresTest extends TestBase
 {
@@ -65,14 +61,14 @@ class ProceduresTest extends TestBase
         $this->dbQuery(
             'SELECT @@GLOBAL.SQL_MODE as globalsqm;',
             function () use (&$sqlMode): void {
-                $optionsSelector = '//a[contains(., "+ Options")]';
+                $optionsSelector = '//button[contains(., "Extra options")]';
                 $fullTextSelector = '//label[contains(., "Full texts")]';
                 $this->assertTrue($this->isElementPresent('xpath', $optionsSelector));
                 $this->byXPath($optionsSelector)->click();
                 $this->waitForElement('xpath', $fullTextSelector);
                 sleep(2);// Wait for the animation to display the box
                 $this->byXPath($fullTextSelector)->click();
-                $this->byCssSelector('.slide-wrapper .tblFooters input[type=submit]')->click();
+                $this->byCssSelector('.collapse .tblFooters input[type=submit]')->click();
                 $this->waitAjax();
                 sleep(2);// Waitfor the new results
                 $this->assertTrue($this->isElementPresent('className', 'table_results'));
@@ -90,14 +86,13 @@ class ProceduresTest extends TestBase
     protected function tearDown(): void
     {
         if ($this->originalSqlMode !== '') {
-            $this->dbQuery(
-                "SET GLOBAL sql_mode = '" . $this->originalSqlMode . "';"
-            );
+            $this->dbQuery("SET GLOBAL sql_mode = '" . $this->originalSqlMode . "';");
             $this->assertEquals(
                 $this->originalSqlMode,
                 $this->getSqlMode()
             );
         }
+
         parent::tearDown();
     }
 
@@ -124,7 +119,7 @@ class ProceduresTest extends TestBase
         $this->waitForElement('partialLinkText', 'Routines')->click();
         $this->waitAjax();
 
-        $this->waitForElement('partialLinkText', 'Add routine')->click();
+        $this->waitForElement('partialLinkText', 'Create new routine')->click();
 
         $this->waitForElement('className', 'rte_form');
 
@@ -137,7 +132,7 @@ class ProceduresTest extends TestBase
         );
         $this->byName('item_param_length[0]')->sendKeys('20');
 
-        $this->byCssSelector("input[value='Add parameter']")->click();
+        $this->byId('addRoutineParameterButton')->click();
 
         $this->selectByLabel(
             $this->byName('item_param_dir[1]'),
@@ -154,12 +149,11 @@ class ProceduresTest extends TestBase
             'READS SQL DATA'
         );
 
-        $this->byXPath("//button[contains(., 'Go')]")->click();
+        $this->byCssSelector('div.ui-dialog-buttonset button:nth-child(1)')->click();
 
         $this->waitForElement(
             'xpath',
-            "//div[@class='alert alert-success' and contains(., "
-            . "'Routine `test_procedure` has been created')]"
+            '//div[@class=\'alert alert-success\' and contains(., \'Routine `test_procedure` has been created\')]'
         );
 
         $this->dbQuery(
@@ -184,22 +178,18 @@ class ProceduresTest extends TestBase
         $this->waitForElement('partialLinkText', 'Routines')->click();
         $this->waitAjax();
 
-        $this->waitForElement(
-            'xpath',
-            "//legend[contains(., 'Routines')]"
-        );
+        $this->waitForElement('id', 'checkAllCheckbox');
 
         $this->byPartialLinkText('Edit')->click();
         $this->waitForElement('className', 'rte_form');
         $this->byName('item_param_length[0]')->clear();
         $this->byName('item_param_length[0]')->sendKeys('30');
 
-        $this->byXPath("//button[contains(., 'Go')]")->click();
+        $this->byCssSelector('div.ui-dialog-buttonset button:nth-child(1)')->click();
 
         $this->waitForElement(
             'xpath',
-            "//div[@class='alert alert-success' and contains(., "
-            . "'Routine `test_procedure` has been modified')]"
+            '//div[@class=\'alert alert-success\' and contains(., \'Routine `test_procedure` has been modified\')]'
         );
 
         $this->executeProcedure('test_procedure', 14);
@@ -216,16 +206,10 @@ class ProceduresTest extends TestBase
         $this->waitForElement('partialLinkText', 'Routines')->click();
         $this->waitAjax();
 
-        $this->waitForElement(
-            'xpath',
-            "//legend[contains(., 'Routines')]"
-        );
+        $this->waitForElement('id', 'checkAllCheckbox');
 
         $this->byPartialLinkText('Drop')->click();
-        $this->waitForElement(
-            'cssSelector',
-            'button.submitOK'
-        )->click();
+        $this->waitForElement('cssSelector', 'button.submitOK')->click();
 
         $this->waitAjaxMessage();
 
@@ -251,10 +235,7 @@ class ProceduresTest extends TestBase
         $this->byCssSelector('div.ui-dialog-buttonset button:nth-child(1)')->click();
 
         $this->waitAjax();
-        $this->waitForElement(
-            'cssSelector',
-            'span#PMA_slidingMessage table tbody'
-        );
+        $this->waitForElement('cssSelector', 'span#PMA_slidingMessage table tbody');
         $this->waitUntilElementIsVisible('cssSelector', 'span#PMA_slidingMessage', 30);
         sleep(2);// Give more chances to the JS effect to finish
         $head = $this->byCssSelector('span#PMA_slidingMessage table tbody')->getText();
